@@ -39,9 +39,7 @@
 #include <com/sun/star/uno/XComponentContext.hpp>
 
 
-#ifndef __SGI_STL_VECTOR
 #include <vector>
-#endif
 
 using namespace com::sun::star;
 
@@ -123,8 +121,8 @@ void SAL_CALL IndexedPropertyValuesContainer::insertByIndex( sal_Int32 nIndex, c
                 sal_Int32 i(0);
                 while(i < nIndex)
                 {
-                    i++;
-                    aItr++;
+                    ++i;
+                    ++aItr;
                 }
             }
             else
@@ -133,8 +131,8 @@ void SAL_CALL IndexedPropertyValuesContainer::insertByIndex( sal_Int32 nIndex, c
                 sal_Int32 i(nSize - 1);
                 while(i > nIndex)
                 {
-                    i--;
-                    aItr--;
+                    --i;
+                    --aItr;
                 }
             }
             maProperties.insert(aItr, aProps);
@@ -158,8 +156,8 @@ void SAL_CALL IndexedPropertyValuesContainer::removeByIndex( sal_Int32 nIndex )
             sal_Int32 i(0);
             while(i < nIndex)
             {
-                i++;
-                aItr++;
+                ++i;
+                ++aItr;
             }
         }
         else
@@ -168,8 +166,8 @@ void SAL_CALL IndexedPropertyValuesContainer::removeByIndex( sal_Int32 nIndex )
             sal_Int32 i(nSize - 1);
             while(i > nIndex)
             {
-                i--;
-                aItr--;
+                --i;
+                --aItr;
             }
         }
         maProperties.erase(aItr);
