@@ -33,12 +33,12 @@
 
 //========================================================================
 
-SV_IMPL_VARARR( SfxUINT32s, UINT32 );
+SV_IMPL_VARARR( SfxUINT32s, sal_uInt32 );
 
 //========================================================================
 
-/*	Die folgenden Makros extrahieren Teilbereiche aus einem UINT32 Wert.
-    Diese UINT32-Werte werden anstelle der einzelnen Werte gestreamt,
+/*	Die folgenden Makros extrahieren Teilbereiche aus einem sal_uInt32 Wert.
+    Diese sal_uInt32-Werte werden anstelle der einzelnen Werte gestreamt,
     um Calls zu sparen.
 */
 
@@ -53,33 +53,33 @@ SV_IMPL_VARARR( SfxUINT32s, UINT32 );
 
 //-------------------------------------------------------------------------
 
-/*	Die folgenden Makros setzen Teilbereiche zu einem UINT32 Wert zusammen.
-    Diese UINT32-Werte werden anstelle der einzelnen Werte gestreamt,
+/*	Die folgenden Makros setzen Teilbereiche zu einem sal_uInt32 Wert zusammen.
+    Diese sal_uInt32-Werte werden anstelle der einzelnen Werte gestreamt,
     um Calls zu sparen.
 */
 
 #define SFX_REC_MINI_HEADER(nPreTag,nStartPos,nEndPos) \
-                    ( UINT32(nPreTag) | \
-                      UINT32(nEndPos-nStartPos-SFX_REC_HEADERSIZE_MINI) << 8 )
+                    ( sal_uInt32(nPreTag) | \
+                      sal_uInt32(nEndPos-nStartPos-SFX_REC_HEADERSIZE_MINI) << 8 )
 
 #define SFX_REC_HEADER(nRecType,nContentTag,nContentVer) \
-                    ( UINT32(nRecType) | \
-                      ( UINT32(nContentVer) << 8 ) | \
-                      ( UINT32(nContentTag) << 16 ) )
+                    ( sal_uInt32(nRecType) | \
+                      ( sal_uInt32(nContentVer) << 8 ) | \
+                      ( sal_uInt32(nContentTag) << 16 ) )
 
 #define SFX_REC_CONTENT_HEADER(nContentVer,n1StStartPos,nCurStartPos) \
-                    ( UINT32(nContentVer) | \
-                      UINT32( nCurStartPos - n1StStartPos ) << 8 )
+                    ( sal_uInt32(nContentVer) | \
+                      sal_uInt32( nCurStartPos - n1StStartPos ) << 8 )
 
 //=========================================================================
 
-UINT32 SfxMiniRecordWriter::Close
+sal_uInt32 SfxMiniRecordWriter::Close
 (
-    bool         bSeekToEndOfRec    /*  TRUE (default)
+    bool         bSeekToEndOfRec    /*  true (default)
                                         Der Stream wird an das Ende des Records
                                         positioniert.
 
-                                        FALSE
+                                        false
                                         Der Stream wird an den Anfang des
                                         Contents (also hinter den Header)
                                         positioniert.
@@ -96,9 +96,9 @@ UINT32 SfxMiniRecordWriter::Close
 
     [R"uckgabewert]
 
-    UINT32		!= 0
+    sal_uInt32		!= 0
                 Position im Stream, die direkt hinter dem Record liegt.
-                'bSeekToEndOfRecord==TRUE'
+                'bSeekToEndOfRecord==sal_True'
                 => R"uckgabewert == aktuelle Stream-Position nach Aufruf
 
                 == 0
@@ -110,7 +110,7 @@ UINT32 SfxMiniRecordWriter::Close
     if ( !_bHeaderOk )
     {
         // Header an den Anfang des Records schreiben
-        UINT32 nEndPos = _pStream->Tell();
+        sal_uInt32 nEndPos = _pStream->Tell();
         _pStream->Seek( _nStartPos );
         *_pStream << SFX_REC_MINI_HEADER( _nPreTag, _nStartPos, nEndPos );
 
@@ -119,26 +119,9 @@ UINT32 SfxMiniRecordWriter::Close
             _pStream->Seek( nEndPos );
 
         // Header wurde JETZT geschrieben
-        _bHeaderOk = TRUE;
+        _bHeaderOk = true;
         return nEndPos;
     }
-#ifdef DBG_UTIL
-    // mu\s Fix-Size-Record gepr"uft werden?
-    else if ( SFX_BOOL_DONTCARE == _bHeaderOk )
-    {
-        // Header auslesen, um Soll-Gr"o\se zu bestimmen
-        UINT32 nEndPos = _pStream->Tell();
-        _pStream->Seek( _nStartPos );
-        UINT32 nHeader;
-        *_pStream >> nHeader;
-        _pStream->Seek( nEndPos );
-
-        // Soll-Gr"o\se mit Ist-Gr"o\se vergleichen
-        DBG_ASSERT( nEndPos - SFX_REC_OFS(nHeader) == _nStartPos + sizeof(UINT32),
-                    "fixed record size incorrect" );
-        DbgOutf( "SfxFileRec: written record until %ul", nEndPos );
-    }
-#endif
 
     // Record war bereits geschlossen
     return 0;
@@ -146,7 +129,7 @@ UINT32 SfxMiniRecordWriter::Close
 
 //=========================================================================
 
-USHORT SfxMiniRecordReader::ScanRecordType
+sal_uInt16 SfxMiniRecordReader::ScanRecordType
 (
     SvStream*	pStream 		/*	<SvStream> an dessen aktueller Position
                                     ein Record liegt, dessen Typ erkannt werden
@@ -176,7 +159,7 @@ USHORT SfxMiniRecordReader::ScanRecordType
 
     [R"uckgabewert]
 
-    USHORT							SFX_REC_TYPE_EOR
+    sal_uInt16							SFX_REC_TYPE_EOR
                                     An der aktuellen Position des Streams
                                     steht eine End-Of-Records-Kennung.
 
@@ -225,7 +208,7 @@ USHORT SfxMiniRecordReader::ScanRecordType
     *pStream >> nHeader;
 
     // k"onnte es sich um einen extended-Record handeln?
-    USHORT nPreTag = sal::static_int_cast< USHORT >(SFX_REC_PRE(nHeader));
+    sal_uInt16 nPreTag = sal::static_int_cast< sal_uInt16 >(SFX_REC_PRE(nHeader));
     if ( SFX_REC_PRETAG_EXT == nPreTag )
     {
         // die n"achsten 4 Bytes als extended-Header lesen
@@ -235,7 +218,7 @@ USHORT SfxMiniRecordReader::ScanRecordType
         pStream->SeekRel(-8);
 
         // liegt eine g"ultige Record-Kennung vor?
-        USHORT nType = sal::static_int_cast< USHORT >(SFX_REC_TYP(nHeader));
+        sal_uInt16 nType = sal::static_int_cast< sal_uInt16 >(SFX_REC_TYP(nHeader));
         if ( nType >= SFX_REC_TYPE_FIRST && nType <= SFX_REC_TYPE_LAST )
             // entsprechenden extended-Record-Typ zur"uckliefern
             return nType;
@@ -252,7 +235,7 @@ USHORT SfxMiniRecordReader::ScanRecordType
         return nPreTag;
 
     // liegt ein Drawin-Engine-Record vor?
-    if ( nHeader == UINT32(*"DRMD") || nHeader == UINT32(*"DRVW") )
+    if ( nHeader == sal_uInt32(*"DRMD") || nHeader == sal_uInt32(*"DRVW") )
         return SFX_REC_TYPE_DRAWENG;
 
     // alle anderen sind grunds"atzlich g"ultige Mini-Records
@@ -261,13 +244,13 @@ USHORT SfxMiniRecordReader::ScanRecordType
 
 //-------------------------------------------------------------------------
 
-bool SfxMiniRecordReader::SetHeader_Impl( UINT32 nHeader )
+bool SfxMiniRecordReader::SetHeader_Impl( sal_uInt32 nHeader )
 
 /*	[Beschreibung]
 
     Interne Methode zum nachtr"aglichen Verarbeiten eines extern gelesenen
     Headers. Falls der Header eine End-Of-Records-Kennung darstellt,
-    wird am Stream ein Errorcode gesetzt und FALSE zur"uckgeliefert. Im
+    wird am Stream ein Errorcode gesetzt und sal_False zur"uckgeliefert. Im
     Fehlerfall wird der Stream jedoch nicht auf den Record-Anfang zur"uck-
     gesetzt.
 */
@@ -277,7 +260,7 @@ bool SfxMiniRecordReader::SetHeader_Impl( UINT32 nHeader )
 
     // Record-Ende und Pre-Tag aus dem Header ermitteln
     _nEofRec = _pStream->Tell() + SFX_REC_OFS(nHeader);
-    _nPreTag = sal::static_int_cast< BYTE >(SFX_REC_PRE(nHeader));
+    _nPreTag = sal::static_int_cast< sal_uInt8 >(SFX_REC_PRE(nHeader));
 
     // wenn End-Of-Record-Kennung, dann Fehler
     if ( _nPreTag == SFX_REC_PRETAG_EOR )
@@ -310,12 +293,12 @@ SfxMiniRecordReader::SfxMiniRecordReader
 */
 
 :	_pStream( pStream ),
-    _bSkipped( FALSE )
+    _bSkipped( sal_False )
 {
     // Header einlesen
-    UINT32 nStartPos = pStream->Tell(); // um im Fehlerfall zur"uck zu-seeken
+    sal_uInt32 nStartPos = pStream->Tell(); // um im Fehlerfall zur"uck zu-seeken
     DBG( DbgOutf( "SfxFileRec: reading record at %ul", nStartPos ) );
-    UINT32 nHeader;
+    sal_uInt32 nHeader;
     *pStream >> nHeader;
 
     // Headerdaten extrahieren
@@ -338,7 +321,7 @@ SfxMiniRecordReader::SfxMiniRecordReader
                                         Position sich ein <SfxMiniRecord>
                                         befindet.
                                     */
-    BYTE			nTag			//	Pre-Tag des gew"unschten Records
+    sal_uInt8			nTag			//	Pre-Tag des gew"unschten Records
 )
 
 /*	[Beschreibung]
@@ -351,13 +334,13 @@ SfxMiniRecordReader::SfxMiniRecordReader
 
     Wird das Ende des Streams oder die Kennung SFX_REC_PRETAG_EOR
     erreicht, bevor ein Record mit dem ge"unschten Pre-Tag gefunden wird,
-    ist die erzeugte Instanz ung"ultig ('IsValid() == FALSE'). Ein ent-
+    ist die erzeugte Instanz ung"ultig ('IsValid() == sal_False'). Ein ent-
     sprechender Error-Code (ERRCODE_IO_EOF bzw. ERRCODE_IO_WRONGFORMAT)
     ist dann am Stream gesetzt, dessen Position ist dann au\serdem unver-
     "andert.
 
     Bei 'nTag==SFX_FILEREC_PRETAG_EOR' wird nicht versucht, einen Record
-    zu lesen, es wird sofort 'IsValid()' auf FALSE gesetzt und kein Error-Code
+    zu lesen, es wird sofort 'IsValid()' auf sal_False gesetzt und kein Error-Code
     am Stream gesetzt. Dies ist dauzu gedacht, ohne 'new' und 'delete'
     abw"rtskompatibel SfxMiniRecords einbauen zu k"onnen. Siehe dazu
     <SfxItemSet::Load()>.
@@ -385,14 +368,14 @@ SfxMiniRecordReader::SfxMiniRecordReader
     }
 
     // StartPos merken, um im Fehlerfall zur"uck-seeken zu k"onnen
-    UINT32 nStartPos = pStream->Tell();
+    sal_uInt32 nStartPos = pStream->Tell();
 
     // passenden Record suchen
-    while(TRUE)
+    while(sal_True)
     {
         // Header lesen
         DBG( DbgOutf( "SfxFileRec: searching record at %ul", pStream->Tell() ) );
-        UINT32 nHeader;
+        sal_uInt32 nHeader;
         *pStream >> nHeader;
 
         // Headerdaten von Basisklasse extrahieren lassen
@@ -424,10 +407,10 @@ SfxMiniRecordReader::SfxMiniRecordReader
 
 SfxSingleRecordWriter::SfxSingleRecordWriter
 (
-    BYTE			nRecordType,	// f"ur Subklassen
+    sal_uInt8			nRecordType,	// f"ur Subklassen
     SvStream*		pStream,		// Stream, in dem der Record angelegt wird
-    UINT16			nContentTag,	// Inhalts-Art-Kennung
-    BYTE			nContentVer 	// Inhalts-Versions-Kennung
+    sal_uInt16			nContentTag,	// Inhalts-Art-Kennung
+    sal_uInt8			nContentVer 	// Inhalts-Versions-Kennung
 )
 
 /*	[Beschreibung]
@@ -446,8 +429,8 @@ SfxSingleRecordWriter::SfxSingleRecordWriter
 SfxSingleRecordWriter::SfxSingleRecordWriter
 (
     SvStream*		pStream,		// Stream, in dem der Record angelegt wird
-    UINT16			nContentTag,	// Inhalts-Art-Kennung
-    BYTE			nContentVer 	// Inhalts-Versions-Kennung
+    sal_uInt16			nContentTag,	// Inhalts-Art-Kennung
+    sal_uInt8			nContentVer 	// Inhalts-Versions-Kennung
 )
 
 /*	[Beschreibung]
@@ -468,9 +451,9 @@ SfxSingleRecordWriter::SfxSingleRecordWriter
 SfxSingleRecordWriter::SfxSingleRecordWriter
 (
     SvStream*		pStream,		// Stream, in dem der Record angelegt wird
-    UINT16			nContentTag,	// Inhalts-Art-Kennung
-    BYTE			nContentVer,	// Inhalts-Versions-Kennung
-    UINT32			nContentSize	// Gr"o\se des Inhalts in Bytes
+    sal_uInt16			nContentTag,	// Inhalts-Art-Kennung
+    sal_uInt8			nContentVer,	// Inhalts-Versions-Kennung
+    sal_uInt32			nContentSize	// Gr"o\se des Inhalts in Bytes
 )
 
 /*  [Beschreibung]
@@ -488,7 +471,7 @@ SfxSingleRecordWriter::SfxSingleRecordWriter
 
 //=========================================================================
 
-inline bool SfxSingleRecordReader::ReadHeader_Impl( USHORT nTypes )
+inline bool SfxSingleRecordReader::ReadHeader_Impl( sal_uInt16 nTypes )
 
 /*  [Beschreibung]
 
@@ -502,7 +485,7 @@ inline bool SfxSingleRecordReader::ReadHeader_Impl( USHORT nTypes )
     bool bRet;
 
     // Basisklassen-Header einlesen
-    UINT32 nHeader=0;
+    sal_uInt32 nHeader=0;
     *_pStream >> nHeader;
     if ( !SetHeader_Impl( nHeader ) )
         bRet = false;
@@ -510,11 +493,11 @@ inline bool SfxSingleRecordReader::ReadHeader_Impl( USHORT nTypes )
     {
         // eigenen Header einlesen
         *_pStream >> nHeader;
-        _nRecordVer = sal::static_int_cast< BYTE >(SFX_REC_VER(nHeader));
-        _nRecordTag = sal::static_int_cast< UINT16 >(SFX_REC_TAG(nHeader));
+        _nRecordVer = sal::static_int_cast< sal_uInt8 >(SFX_REC_VER(nHeader));
+        _nRecordTag = sal::static_int_cast< sal_uInt16 >(SFX_REC_TAG(nHeader));
 
         // falscher Record-Typ?
-        _nRecordType = sal::static_int_cast< BYTE >(SFX_REC_TYP(nHeader));
+        _nRecordType = sal::static_int_cast< sal_uInt8 >(SFX_REC_TYP(nHeader));
         bRet = 0 != ( nTypes & _nRecordType);
     }
     return bRet;
@@ -527,7 +510,7 @@ SfxSingleRecordReader::SfxSingleRecordReader( SvStream *pStream )
 {
     // Startposition merken, um im Fehlerfall zur"uck-seeken zu k"onnen
     #ifdef DBG_UTIL
-    UINT32 nStartPos = pStream->Tell();
+    sal_uInt32 nStartPos = pStream->Tell();
     DBG( DbgOutf( "SfxFileRec: reading record at %ul", nStartPos ) );
     #endif
 
@@ -545,10 +528,10 @@ SfxSingleRecordReader::SfxSingleRecordReader( SvStream *pStream )
 
 //-------------------------------------------------------------------------
 
-SfxSingleRecordReader::SfxSingleRecordReader( SvStream *pStream, USHORT nTag )
+SfxSingleRecordReader::SfxSingleRecordReader( SvStream *pStream, sal_uInt16 nTag )
 {
     // StartPos merken, um im Fehlerfall zur"uck-seeken zu k"onnen
-    UINT32 nStartPos = pStream->Tell();
+    sal_uInt32 nStartPos = pStream->Tell();
 
     // richtigen Record suchen, ggf. Error-Code setzen und zur"uck-seeken
     Construct_Impl( pStream );
@@ -564,8 +547,8 @@ SfxSingleRecordReader::SfxSingleRecordReader( SvStream *pStream, USHORT nTag )
 
 bool SfxSingleRecordReader::FindHeader_Impl
 (
-    UINT16		nTypes, 	// arithm. Veroderung erlaubter Record-Typen
-    UINT16		nTag		// zu findende Record-Art-Kennung
+    sal_uInt16		nTypes, 	// arithm. Veroderung erlaubter Record-Typen
+    sal_uInt16		nTag		// zu findende Record-Art-Kennung
 )
 
 /*	[Beschreibung]
@@ -575,18 +558,18 @@ bool SfxSingleRecordReader::FindHeader_Impl
     gekennzeichnet ist.
 
     Kann ein solcher Record nicht gefunden werden, wird am Stream ein
-    Errorcode gesetzt, zur"uck-geseekt und FALSE zur"uckgeliefert.
+    Errorcode gesetzt, zur"uck-geseekt und sal_False zur"uckgeliefert.
 */
 
 {
     // StartPos merken, um im Fehlerfall zur"uck-seeken zu k"onnen
-    UINT32 nStartPos = _pStream->Tell();
+    sal_uInt32 nStartPos = _pStream->Tell();
 
     // richtigen Record suchen
     while ( !_pStream->IsEof() )
     {
         // Header lesen
-        UINT32 nHeader;
+        sal_uInt32 nHeader;
         DBG( DbgOutf( "SfxFileRec: searching record at %ul", _pStream->Tell() ) );
         *_pStream >> nHeader;
         if ( !SetHeader_Impl( nHeader ) )
@@ -598,17 +581,17 @@ bool SfxSingleRecordReader::FindHeader_Impl
         {
             // Extended Header lesen
             *_pStream >> nHeader;
-            _nRecordTag = sal::static_int_cast< UINT16 >(SFX_REC_TAG(nHeader));
+            _nRecordTag = sal::static_int_cast< sal_uInt16 >(SFX_REC_TAG(nHeader));
 
             // richtigen Record gefunden?
             if ( _nRecordTag == nTag )
             {
                 // gefundener Record-Typ passend?
-                _nRecordType = sal::static_int_cast< BYTE >(
+                _nRecordType = sal::static_int_cast< sal_uInt8 >(
                     SFX_REC_TYP(nHeader));
                 if ( nTypes & _nRecordType )
                     // ==> gefunden
-                    return TRUE;
+                    return sal_True;
 
                 // error => Such-Schleife abbrechen
                 break;
@@ -623,18 +606,18 @@ bool SfxSingleRecordReader::FindHeader_Impl
     // Fehler setzen und zur"uck-seeken
     _pStream->SetError( ERRCODE_IO_WRONGFORMAT );
     _pStream->Seek( nStartPos );
-    return FALSE;
+    return sal_False;
 }
 
 //=========================================================================
 
 SfxMultiFixRecordWriter::SfxMultiFixRecordWriter
 (
-    BYTE			nRecordType,	// Subklassen Record-Kennung
+    sal_uInt8			nRecordType,	// Subklassen Record-Kennung
     SvStream*		pStream,		// Stream, in dem der Record angelegt wird
-    UINT16			nContentTag,	// Content-Art-Kennung
-    BYTE			nContentVer,	// Content-Versions-Kennung
-    UINT32			              	// Gr"o\se jedes einzelnen Contents in Bytes
+    sal_uInt16			nContentTag,	// Content-Art-Kennung
+    sal_uInt8			nContentVer,	// Content-Versions-Kennung
+    sal_uInt32			              	// Gr"o\se jedes einzelnen Contents in Bytes
 )
 
 /*  [Beschreibung]
@@ -654,9 +637,9 @@ SfxMultiFixRecordWriter::SfxMultiFixRecordWriter
 SfxMultiFixRecordWriter::SfxMultiFixRecordWriter
 (
     SvStream*		pStream,		// Stream, in dem der Record angelegt wird
-    UINT16			nContentTag,	// Content-Art-Kennung
-    BYTE			nContentVer,	// Content-Versions-Kennung
-    UINT32			             	// Gr"o\se jedes einzelnen Contents in Bytes
+    sal_uInt16			nContentTag,	// Content-Art-Kennung
+    sal_uInt8			nContentVer,	// Content-Versions-Kennung
+    sal_uInt32			             	// Gr"o\se jedes einzelnen Contents in Bytes
 )
 
 /*  [Beschreibung]
@@ -675,7 +658,7 @@ SfxMultiFixRecordWriter::SfxMultiFixRecordWriter
 
 //------------------------------------------------------------------------
 
-UINT32 SfxMultiFixRecordWriter::Close( bool bSeekToEndOfRec )
+sal_uInt32 SfxMultiFixRecordWriter::Close( bool bSeekToEndOfRec )
 
 //	siehe <SfxMiniRecordWriter>
 
@@ -684,7 +667,7 @@ UINT32 SfxMultiFixRecordWriter::Close( bool bSeekToEndOfRec )
     if ( !_bHeaderOk )
     {
         // Position hinter Record merken, um sie restaurieren zu k"onnen
-        UINT32 nEndPos = SfxSingleRecordWriter::Close( FALSE );
+        sal_uInt32 nEndPos = SfxSingleRecordWriter::Close( sal_False );
 
         // gegen"uber SfxSingleRecord erweiterten Header schreiben
         *_pStream << _nContentCount;
@@ -704,10 +687,10 @@ UINT32 SfxMultiFixRecordWriter::Close( bool bSeekToEndOfRec )
 
 SfxMultiVarRecordWriter::SfxMultiVarRecordWriter
 (
-    BYTE			nRecordType,	// Record-Kennung der Subklasse
+    sal_uInt8			nRecordType,	// Record-Kennung der Subklasse
     SvStream*       pStream,        // Stream, in dem der Record angelegt wird
-    UINT16			nRecordTag, 	// Gesamt-Art-Kennung
-    BYTE			nRecordVer		// Gesamt-Versions-Kennung
+    sal_uInt16			nRecordTag, 	// Gesamt-Art-Kennung
+    sal_uInt8			nRecordVer		// Gesamt-Versions-Kennung
 )
 
 /*  [Beschreibung]
@@ -725,8 +708,8 @@ SfxMultiVarRecordWriter::SfxMultiVarRecordWriter
 SfxMultiVarRecordWriter::SfxMultiVarRecordWriter
 (
     SvStream*       pStream,        // Stream, in dem der Record angelegt wird
-    UINT16			nRecordTag, 	// Gesamt-Art-Kennung
-    BYTE			nRecordVer		// Gesamt-Versions-Kennung
+    sal_uInt16			nRecordTag, 	// Gesamt-Art-Kennung
+    sal_uInt8			nRecordVer		// Gesamt-Versions-Kennung
 )
 
 /*  [Beschreibung]
@@ -800,7 +783,7 @@ void SfxMultiVarRecordWriter::NewContent()
 
 //-------------------------------------------------------------------------
 
-UINT32 SfxMultiVarRecordWriter::Close( bool bSeekToEndOfRec )
+sal_uInt32 SfxMultiVarRecordWriter::Close( bool bSeekToEndOfRec )
 
 // siehe <SfxMiniRecordWriter>
 
@@ -813,24 +796,24 @@ UINT32 SfxMultiVarRecordWriter::Close( bool bSeekToEndOfRec )
             FlushContent_Impl();
 
         // Content-Offset-Tabelle schreiben
-        UINT32 nContentOfsPos = _pStream->Tell();
+        sal_uInt32 nContentOfsPos = _pStream->Tell();
         //! darf man das so einr"ucken?
         #if defined(OSL_LITENDIAN)
             _pStream->Write( _aContentOfs.GetData(),
-                             sizeof(UINT32)*_nContentCount );
+                             sizeof(sal_uInt32)*_nContentCount );
         #else
-            for ( USHORT n = 0; n < _nContentCount; ++n )
-                *_pStream << UINT32(_aContentOfs[n]);
+            for ( sal_uInt16 n = 0; n < _nContentCount; ++n )
+                *_pStream << sal_uInt32(_aContentOfs[n]);
         #endif
 
         // SfxMultiFixRecordWriter::Close() "uberspringen!
-        UINT32 nEndPos = SfxSingleRecordWriter::Close( FALSE );
+        sal_uInt32 nEndPos = SfxSingleRecordWriter::Close( sal_False );
 
         // eigenen Header schreiben
         *_pStream << _nContentCount;
         if ( SFX_REC_TYPE_VARSIZE_RELOC == _nPreTag ||
              SFX_REC_TYPE_MIXTAGS_RELOC == _nPreTag )
-            *_pStream << static_cast<UINT32>(nContentOfsPos - ( _pStream->Tell() + sizeof(UINT32) ));
+            *_pStream << static_cast<sal_uInt32>(nContentOfsPos - ( _pStream->Tell() + sizeof(sal_uInt32) ));
         else
             *_pStream << nContentOfsPos;
 
@@ -848,8 +831,8 @@ UINT32 SfxMultiVarRecordWriter::Close( bool bSeekToEndOfRec )
 
 void SfxMultiMixRecordWriter::NewContent
 (
-    UINT16		nContentTag,	// Kennung f"ur die Art des Contents
-    BYTE		nContentVer 	// Kennung f"ur die Version des Contents
+    sal_uInt16		nContentTag,	// Kennung f"ur die Art des Contents
+    sal_uInt8		nContentVer 	// Kennung f"ur die Version des Contents
 )
 
 /*	[Beschreibung]
@@ -892,18 +875,18 @@ bool SfxMultiRecordReader::ReadHeader_Impl()
     if ( _nRecordType != SFX_REC_TYPE_FIXSIZE )
     {
         // Tabelle aus dem Stream einlesen
-        UINT32 nContentPos = _pStream->Tell();
+        sal_uInt32 nContentPos = _pStream->Tell();
         if ( _nRecordType == SFX_REC_TYPE_VARSIZE_RELOC ||
              _nRecordType == SFX_REC_TYPE_MIXTAGS_RELOC )
             _pStream->SeekRel( + _nContentSize );
         else
             _pStream->Seek( _nContentSize );
-        _pContentOfs = new UINT32[_nContentCount];
+        _pContentOfs = new sal_uInt32[_nContentCount];
         //! darf man jetzt so einr"ucken
         #if defined(OSL_LITENDIAN)
-            _pStream->Read( _pContentOfs, sizeof(UINT32)*_nContentCount );
+            _pStream->Read( _pContentOfs, sizeof(sal_uInt32)*_nContentCount );
         #else
-            for ( USHORT n = 0; n < _nContentCount; ++n )
+            for ( sal_uInt16 n = 0; n < _nContentCount; ++n )
                 *_pStream >> _pContentOfs[n];
         #endif
         _pStream->Seek( nContentPos );
@@ -935,7 +918,7 @@ SfxMultiRecordReader::SfxMultiRecordReader( SvStream *pStream )
 
 //-------------------------------------------------------------------------
 
-SfxMultiRecordReader::SfxMultiRecordReader( SvStream *pStream, UINT16 nTag )
+SfxMultiRecordReader::SfxMultiRecordReader( SvStream *pStream, sal_uInt16 nTag )
 :	_nContentNo(0)
 {
     // Position im Stream merken, um im Fehlerfall zur"uck-seeken zu k"onnen
@@ -972,8 +955,8 @@ bool SfxMultiRecordReader::GetContent()
     auf den Anfang des ersten Contents im Record und liest ggf. dessen
     Header ein.
 
-    Liegt laut Record-Header kein Content mehr vor, wird FALSE zur"uck-
-    gegeben. Trotz einem TRUE-Returnwert kann am Stream ein Fehlercode
+    Liegt laut Record-Header kein Content mehr vor, wird sal_False zur"uck-
+    gegeben. Trotz einem sal_True-Returnwert kann am Stream ein Fehlercode
     gesetzt sein, z.B. falls er unvorhergesehenerweise (kaputtes File)
     zuende ist.
 */
@@ -983,10 +966,10 @@ bool SfxMultiRecordReader::GetContent()
     if ( _nContentNo < _nContentCount )
     {
         // den Stream an den Anfang des Contents positionieren
-        UINT32 nOffset = _nRecordType == SFX_REC_TYPE_FIXSIZE
+        sal_uInt32 nOffset = _nRecordType == SFX_REC_TYPE_FIXSIZE
                     ? _nContentNo * _nContentSize
                     : SFX_REC_CONTENT_OFS(_pContentOfs[_nContentNo]);
-        UINT32 nNewPos = _nStartPos + nOffset;
+        sal_uInt32 nNewPos = _nStartPos + nOffset;
         DBG_ASSERT( nNewPos >= _pStream->Tell(), "SfxMultiRecordReader::GetContent() - New position before current, to much data red!" );
 
         // #99366#: correct stream pos in every case;
@@ -1001,17 +984,17 @@ bool SfxMultiRecordReader::GetContent()
         if ( _nRecordType == SFX_REC_TYPE_MIXTAGS ||
              _nRecordType == SFX_REC_TYPE_MIXTAGS_RELOC )
         {
-            _nContentVer = sal::static_int_cast< BYTE >(
+            _nContentVer = sal::static_int_cast< sal_uInt8 >(
                 SFX_REC_CONTENT_VER(_pContentOfs[_nContentNo]));
             *_pStream >> _nContentTag;
         }
 
         // ContentNo weiterz"ahlen
         ++_nContentNo;
-        return TRUE;
+        return sal_True;
     }
 
-    return FALSE;
+    return sal_False;
 }
 
 
