@@ -37,14 +37,6 @@
 #include <svl/brdcst.hxx>
 #include <svl/smplhint.hxx>
 #include "poolio.hxx"
-#include <algorithm>
-
-// STATIC DATA -----------------------------------------------------------
-
-
-//========================================================================
-
-SV_IMPL_PTRARR( SfxPoolVersionArr_Impl, SfxPoolVersion_Impl* );
 
 //========================================================================
 
@@ -63,7 +55,7 @@ void SfxItemPool::RemoveSfxItemPoolUser(SfxItemPoolUser& rOldUser)
     }
 }
 
-const SfxPoolItem* SfxItemPool::GetPoolDefaultItem( USHORT nWhich ) const
+const SfxPoolItem* SfxItemPool::GetPoolDefaultItem( sal_uInt16 nWhich ) const
 {
     DBG_CHKTHIS(SfxItemPool, 0);
     const SfxPoolItem* pRet;
@@ -81,15 +73,15 @@ const SfxPoolItem* SfxItemPool::GetPoolDefaultItem( USHORT nWhich ) const
 
 // -----------------------------------------------------------------------
 
-inline bool SfxItemPool::IsItemFlag_Impl( USHORT nPos, USHORT nFlag ) const
+inline bool SfxItemPool::IsItemFlag_Impl( sal_uInt16 nPos, sal_uInt16 nFlag ) const
 {
-    USHORT nItemFlag = pItemInfos[nPos]._nFlags;
+    sal_uInt16 nItemFlag = pItemInfos[nPos]._nFlags;
     return nFlag == (nItemFlag & nFlag);
 }
 
 // -----------------------------------------------------------------------
 
-bool SfxItemPool::IsItemFlag( USHORT nWhich, USHORT nFlag ) const
+bool SfxItemPool::IsItemFlag( sal_uInt16 nWhich, sal_uInt16 nFlag ) const
 {
     for ( const SfxItemPool *pPool = this; pPool; pPool = pPool->pSecondary )
     {
@@ -97,7 +89,7 @@ bool SfxItemPool::IsItemFlag( USHORT nWhich, USHORT nFlag ) const
             return pPool->IsItemFlag_Impl( pPool->GetIndex_Impl(nWhich), nFlag);
     }
     DBG_ASSERT( !IsWhich(nWhich), "unknown which-id" );
-    return FALSE;
+    return sal_False;
 }
 
 // -----------------------------------------------------------------------
@@ -114,8 +106,8 @@ SfxItemPool::SfxItemPool
 (
     UniString const &	rName,          /* Name des Pools zur Idetifikation
                                            im File-Format */
-    USHORT              nStartWhich,    /* erste Which-Id des Pools */
-    USHORT              nEndWhich,      /* letzte Which-Id des Pools */
+    sal_uInt16              nStartWhich,    /* erste Which-Id des Pools */
+    sal_uInt16              nEndWhich,      /* letzte Which-Id des Pools */
 #ifdef TF_POOLABLE
     const SfxItemInfo*  pInfos,         /* SID-Map und Item-Flags */
 #endif
@@ -123,7 +115,7 @@ SfxItemPool::SfxItemPool
                                            wird direkt vom Pool referenziert,
                                            jedoch kein Eigent"umer"ubergang */
 #ifndef TF_POOLABLE
-    USHORT*             pSlotIdArray,   /* Zuordnung von Slot-Ids zu Which-Ids */
+    sal_uInt16*             pSlotIdArray,   /* Zuordnung von Slot-Ids zu Which-Ids */
 #endif
     bool                bLoadRefCounts  /* Ref-Counts mitladen oder auf 1 setzen */
 )
@@ -155,8 +147,8 @@ SfxItemPool::SfxItemPool
     [Querverweise]
 
     <SfxItemPool::SetDefaults(SfxItemPool**)>
-    <SfxItemPool::ReleaseDefaults(SfxPoolItem**,USHORT,BOOL)>
-    <SfxItemPool::ReldaseDefaults(BOOL)>
+    <SfxItemPool::ReleaseDefaults(SfxPoolItem**,sal_uInt16,sal_Bool)>
+    <SfxItemPool::ReldaseDefaults(sal_Bool)>
 */
 
 :   aName(rName),
@@ -181,7 +173,7 @@ SfxItemPool::SfxItemPool
 
     pImp->eDefMetric = SFX_MAPUNIT_TWIP;
     pImp->nVersion = 0;
-    pImp->bStreaming = FALSE;
+    pImp->bStreaming = sal_False;
     pImp->nLoadingVersion = 0;
     pImp->nInitRefCount = 1;
     pImp->nVerStart = nStart;
@@ -202,10 +194,10 @@ SfxItemPool::SfxItemPool
 SfxItemPool::SfxItemPool
 (
     const SfxItemPool&  rPool,                  //  von dieser Instanz kopieren
-    BOOL                bCloneStaticDefaults    /*  TRUE
+    sal_Bool                bCloneStaticDefaults    /*  sal_True
                                                     statische Defaults kopieren
 
-                                                    FALSE
+                                                    sal_False
                                                     statische Defaults
                                                     "ubernehehmen */
 )
@@ -240,7 +232,7 @@ SfxItemPool::SfxItemPool
     DBG_CTOR(SfxItemPool, 0);
     pImp->eDefMetric = rPool.pImp->eDefMetric;
     pImp->nVersion = rPool.pImp->nVersion;
-    pImp->bStreaming = FALSE;
+    pImp->bStreaming = sal_False;
     pImp->nLoadingVersion = 0;
     pImp->nInitRefCount = 1;
     pImp->nVerStart = rPool.pImp->nVerStart;
@@ -255,7 +247,7 @@ SfxItemPool::SfxItemPool
     if ( bCloneStaticDefaults )
     {
         SfxPoolItem **ppDefaults = new SfxPoolItem*[nEnd-nStart+1];
-        for ( USHORT n = 0; n <= nEnd - nStart; ++n )
+        for ( sal_uInt16 n = 0; n <= nEnd - nStart; ++n )
         {
             (*( ppDefaults + n )) = (*( rPool.ppStaticDefaults + n ))->Clone(this);
             (*( ppDefaults + n ))->SetKind( SFX_ITEMS_STATICDEFAULT );
@@ -267,20 +259,19 @@ SfxItemPool::SfxItemPool
         SetDefaults( rPool.ppStaticDefaults );
 
     // Pool Defaults kopieren
-    for ( USHORT n = 0; n <= nEnd - nStart; ++n )
+    for ( sal_uInt16 n = 0; n <= nEnd - nStart; ++n )
         if ( (*( rPool.ppPoolDefaults + n )) )
         {
             (*( ppPoolDefaults + n )) = (*( rPool.ppPoolDefaults + n ))->Clone(this);
             (*( ppPoolDefaults + n ))->SetKind( SFX_ITEMS_POOLDEFAULT );
         }
 
-    // Version-Map kopieren
-    USHORT nVerCount = rPool.pImp->aVersions.Count();
-    for ( USHORT nVer = 0; nVer < nVerCount; ++nVer )
+    // Copy Version-Map
+    for ( size_t nVer = 0; nVer < rPool.pImp->aVersions.size(); ++nVer )
     {
-        const SfxPoolVersion_Impl *pOld = rPool.pImp->aVersions.GetObject(nVer);
-        const SfxPoolVersion_Impl *pNew = new SfxPoolVersion_Impl( *pOld );
-        pImp->aVersions.Insert( pNew, nVer );
+        const SfxPoolVersion_ImplPtr pOld = rPool.pImp->aVersions[nVer];
+        SfxPoolVersion_ImplPtr pNew = SfxPoolVersion_ImplPtr( new SfxPoolVersion_Impl( *pOld ) );
+        pImp->aVersions.push_back( pNew );
     }
 
     // Verkettung wiederherstellen
@@ -303,7 +294,7 @@ void SfxItemPool::SetDefaults( SfxPoolItem **pDefaults )
         DBG_ASSERT( (*ppStaticDefaults)->GetRefCount() == 0 ||
                     IsDefaultItem( (*ppStaticDefaults) ),
                     "das sind keine statics" );
-        for ( USHORT n = 0; n <= nEnd - nStart; ++n )
+        for ( sal_uInt16 n = 0; n <= nEnd - nStart; ++n )
         {
             SFX_ASSERT( (*( ppStaticDefaults + n ))->Which() == n + nStart,
                         n + nStart, "static defaults not sorted" );
@@ -317,11 +308,11 @@ void SfxItemPool::SetDefaults( SfxPoolItem **pDefaults )
 
 void SfxItemPool::ReleaseDefaults
 (
-    BOOL    bDelete     /*  TRUE
+    sal_Bool    bDelete     /*  sal_True
                             l"oscht sowohl das Array als auch die einzelnen
                             statischen Defaults
 
-                            FALSE
+                            sal_False
                             l"oscht weder das Array noch die einzelnen
                             statischen Defaults */
 )
@@ -340,7 +331,7 @@ void SfxItemPool::ReleaseDefaults
     ReleaseDefaults( ppStaticDefaults, nEnd - nStart + 1, bDelete );
 
     // KSO (22.10.98): ppStaticDefaults zeigt auf geloeschten Speicher,
-    // wenn bDelete == TRUE.
+    // wenn bDelete == sal_True.
     if ( bDelete )
         ppStaticDefaults = 0;
 }
@@ -351,13 +342,13 @@ void SfxItemPool::ReleaseDefaults
 (
     SfxPoolItem**   pDefaults,  /*  freizugebende statische Defaults */
 
-    USHORT          nCount,     /*  Anzahl der statischen Defaults */
+    sal_uInt16          nCount,     /*  Anzahl der statischen Defaults */
 
-    BOOL            bDelete     /*  TRUE
+    sal_Bool            bDelete     /*  sal_True
                                     l"oscht sowohl das Array als auch die
                                     einzelnen statischen Defaults
 
-                                    FALSE
+                                    sal_False
                                     l"oscht weder das Array noch die
                                     einzelnen statischen Defaults */
 )
@@ -375,7 +366,7 @@ void SfxItemPool::ReleaseDefaults
 {
     DBG_ASSERT( pDefaults, "erst wollen, dann nichts geben..." );
 
-    for ( USHORT n = 0; n < nCount; ++n )
+    for ( sal_uInt16 n = 0; n < nCount; ++n )
     {
         SFX_ASSERT( IsStaticDefaultItem( *(pDefaults+n) ),
                     n, "das ist kein static-default" );
@@ -407,7 +398,7 @@ void SfxItemPool::Free(SfxItemPool* pPool)
     {
         // tell all the registered SfxItemPoolUsers that the pool is in destruction
         SfxItemPoolUserVector aListCopy(pPool->maSfxItemPoolUsers.begin(), pPool->maSfxItemPoolUsers.end());
-        for(SfxItemPoolUserVector::iterator aIterator = aListCopy.begin(); aIterator != aListCopy.end(); aIterator++)
+        for(SfxItemPoolUserVector::iterator aIterator = aListCopy.begin(); aIterator != aListCopy.end(); ++aIterator)
         {
             SfxItemPoolUser* pSfxItemPoolUser = *aIterator;
             DBG_ASSERT(pSfxItemPoolUser, "corrupt SfxItemPoolUser list (!)");
@@ -439,13 +430,13 @@ void SfxItemPool::SetSecondaryPool( SfxItemPool *pPool )
             if ( pImp->ppPoolItems && pSecondary->pImp->ppPoolItems )
             {
                 // hat der master SetItems?
-                BOOL bHasSetItems = FALSE;
-                for ( USHORT i = 0; !bHasSetItems && i < nEnd-nStart; ++i )
+                sal_Bool bHasSetItems = sal_False;
+                for ( sal_uInt16 i = 0; !bHasSetItems && i < nEnd-nStart; ++i )
                     bHasSetItems = ppStaticDefaults[i]->ISA(SfxSetItem);
 
                 // abgehaengte Pools muessen leer sein
-                BOOL bOK = bHasSetItems;
-                for ( USHORT n = 0;
+                sal_Bool bOK = bHasSetItems;
+                for ( sal_uInt16 n = 0;
                       bOK && n <= pSecondary->nEnd - pSecondary->nStart;
                       ++n )
                 {
@@ -453,13 +444,12 @@ void SfxItemPool::SetSecondaryPool( SfxItemPool *pPool )
                                                 pSecondary->pImp->ppPoolItems + n;
                     if ( *ppItemArr )
                     {
-                        SfxPoolItem** ppHtArr =
-                                        (SfxPoolItem**)(*ppItemArr)->GetData();
-                        for( USHORT i = (*ppItemArr)->Count(); i; ++ppHtArr, --i )
+                        SfxPoolItemArrayBase_Impl::iterator ppHtArr =	(*ppItemArr)->begin();
+                        for( size_t i = (*ppItemArr)->size(); i; ++ppHtArr, --i )
                             if ( !(*ppHtArr) )
                             {
-                                DBG_ERROR( "old secondary pool must be empty" );
-                                bOK = FALSE;
+                                OSL_FAIL( "old secondary pool must be empty" );
+                                bOK = sal_False;
                                 break;
                             }
                     }
@@ -485,7 +475,7 @@ void SfxItemPool::SetSecondaryPool( SfxItemPool *pPool )
 
 // -----------------------------------------------------------------------
 
-SfxMapUnit SfxItemPool::GetMetric( USHORT ) const
+SfxMapUnit SfxItemPool::GetMetric( sal_uInt16 ) const
 {
     DBG_CHKTHIS(SfxItemPool, 0);
 
@@ -564,7 +554,7 @@ void SfxItemPool::Delete()
     SfxPoolItemArray_Impl** ppItemArr = pImp->ppPoolItems;
     SfxPoolItem** ppDefaultItem = ppPoolDefaults;
     SfxPoolItem** ppStaticDefaultItem = ppStaticDefaults;
-    USHORT nArrCnt;
+    sal_uInt16 nArrCnt;
 
     //Erst die SetItems abraeumen
     HACK( "fuer Image, dort gibt es derzeit keine Statics - Bug" )
@@ -581,8 +571,8 @@ void SfxItemPool::Delete()
             {
                 if ( *ppItemArr )
                 {
-                    SfxPoolItem** ppHtArr = (SfxPoolItem**)(*ppItemArr)->GetData();
-                    for ( USHORT n = (*ppItemArr)->Count(); n; --n, ++ppHtArr )
+                    SfxPoolItemArrayBase_Impl::iterator ppHtArr = (*ppItemArr)->begin();
+                    for ( size_t n = (*ppItemArr)->size(); n; --n, ++ppHtArr )
                         if (*ppHtArr)
                         {
 #ifdef DBG_UTIL
@@ -613,8 +603,8 @@ void SfxItemPool::Delete()
     {
         if ( *ppItemArr )
         {
-            SfxPoolItem** ppHtArr = (SfxPoolItem**)(*ppItemArr)->GetData();
-            for ( USHORT n = (*ppItemArr)->Count(); n; --n, ++ppHtArr )
+            SfxPoolItemArrayBase_Impl::iterator ppHtArr = (*ppItemArr)->begin();
+            for ( size_t n = (*ppItemArr)->size(); n; --n, ++ppHtArr )
                 if (*ppHtArr)
                 {
 #ifdef DBG_UTIL
@@ -648,7 +638,7 @@ void SfxItemPool::Cleanup()
     SfxPoolItemArray_Impl** ppItemArr = pImp->ppPoolItems;
     SfxPoolItem** ppDefaultItem = ppPoolDefaults;
     SfxPoolItem** ppStaticDefaultItem = ppStaticDefaults;
-    USHORT nArrCnt;
+    sal_uInt16 nArrCnt;
 
     HACK( "fuer Image, dort gibt es derzeit keine Statics - Bug" )
     if ( ppStaticDefaults ) //HACK fuer Image, dort gibt es keine Statics!!
@@ -662,8 +652,8 @@ void SfxItemPool::Cleanup()
                  ((*ppDefaultItem && (*ppDefaultItem)->ISA(SfxSetItem)) ||
                   (*ppStaticDefaultItem)->ISA(SfxSetItem)) )
             {
-                SfxPoolItem** ppHtArr = (SfxPoolItem**)(*ppItemArr)->GetData();
-                for ( USHORT n = (*ppItemArr)->Count(); n; --n, ++ppHtArr )
+                SfxPoolItemArrayBase_Impl::iterator ppHtArr = (*ppItemArr)->begin();
+                for ( size_t n = (*ppItemArr)->size(); n; --n, ++ppHtArr )
                     if ( *ppHtArr && !(*ppHtArr)->GetRefCount() )
                     {
                          DELETEZ(*ppHtArr);
@@ -680,8 +670,8 @@ void SfxItemPool::Cleanup()
     {
         if ( *ppItemArr )
         {
-            SfxPoolItem** ppHtArr = (SfxPoolItem**)(*ppItemArr)->GetData();
-            for ( USHORT n = (*ppItemArr)->Count(); n; --n, ++ppHtArr )
+            SfxPoolItemArrayBase_Impl::iterator ppHtArr = (*ppItemArr)->begin();
+            for ( size_t n = (*ppItemArr)->size(); n; --n, ++ppHtArr )
                 if ( *ppHtArr && !(*ppHtArr)->GetRefCount() )
                     DELETEZ( *ppHtArr );
         }
@@ -718,7 +708,7 @@ void SfxItemPool::SetPoolDefaultItem(const SfxPoolItem &rItem)
  * Resets the default of the given <Which-Id> back to the static default.
  * If a pool default exists it is removed.
  */
-void SfxItemPool::ResetPoolDefaultItem( USHORT nWhichId )
+void SfxItemPool::ResetPoolDefaultItem( sal_uInt16 nWhichId )
 {
     DBG_CHKTHIS(SfxItemPool, 0);
     if ( IsInRange(nWhichId) )
@@ -741,7 +731,7 @@ void SfxItemPool::ResetPoolDefaultItem( USHORT nWhichId )
 
 // -----------------------------------------------------------------------
 
-const SfxPoolItem& SfxItemPool::Put( const SfxPoolItem& rItem, USHORT nWhich )
+const SfxPoolItem& SfxItemPool::Put( const SfxPoolItem& rItem, sal_uInt16 nWhich )
 {
     DBG_ASSERT( !rItem.ISA(SfxSetItem) ||
                 0 != &((const SfxSetItem&)rItem).GetItemSet(),
@@ -752,16 +742,16 @@ const SfxPoolItem& SfxItemPool::Put( const SfxPoolItem& rItem, USHORT nWhich )
         nWhich = rItem.Which();
 
     // richtigen Secondary-Pool finden
-    BOOL bSID = nWhich > SFX_WHICH_MAX;
+    sal_Bool bSID = nWhich > SFX_WHICH_MAX;
     if ( !bSID && !IsInRange(nWhich) )
     {
         if ( pSecondary )
             return pSecondary->Put( rItem, nWhich );
-        DBG_ERROR( "unknown Which-Id - cannot put item" );
+        OSL_FAIL( "unknown Which-Id - cannot put item" );
     }
 
     // SID oder nicht poolable (neue Definition)?
-    USHORT nIndex = bSID ? USHRT_MAX : GetIndex_Impl(nWhich);
+    sal_uInt16 nIndex = bSID ? USHRT_MAX : GetIndex_Impl(nWhich);
     if ( USHRT_MAX == nIndex ||
          IsItemFlag_Impl( nIndex, SFX_ITEM_NOT_POOLABLE ) )
     {
@@ -781,15 +771,16 @@ const SfxPoolItem& SfxItemPool::Put( const SfxPoolItem& rItem, USHORT nWhich )
     if( !*ppItemArr )
         *ppItemArr = new SfxPoolItemArray_Impl;
 
-    SfxPoolItem **ppFree = 0;
-    SfxPoolItem** ppHtArray = (SfxPoolItem**)(*ppItemArr)->GetData();
+    SfxPoolItemArrayBase_Impl::iterator ppFree;
+    sal_Bool ppFreeIsSet = sal_False;
+    SfxPoolItemArrayBase_Impl::iterator ppHtArray = (*ppItemArr)->begin();
     if ( IsItemFlag_Impl( nIndex, SFX_ITEM_POOLABLE ) )
     {
         // wenn es ueberhaupt gepoolt ist, koennte es schon drin sein
         if ( IsPooledItem(&rItem) )
         {
             // 1. Schleife: teste ob der Pointer vorhanden ist.
-            for( USHORT n = (*ppItemArr)->Count(); n; ++ppHtArray, --n )
+            for( size_t n = (*ppItemArr)->size(); n; ++ppHtArray, --n )
                 if( &rItem == (*ppHtArray) )
                 {
                     AddRef( **ppHtArray );
@@ -798,8 +789,8 @@ const SfxPoolItem& SfxItemPool::Put( const SfxPoolItem& rItem, USHORT nWhich )
         }
 
         // 2. Schleife: dann muessen eben die Attribute verglichen werden
-        USHORT n;
-        for ( n = (*ppItemArr)->Count(), ppHtArray = (SfxPoolItem**)(*ppItemArr)->GetData();
+        size_t n;
+        for ( n = (*ppItemArr)->size(), ppHtArray = (*ppItemArr)->begin();
               n; ++ppHtArray, --n )
         {
             if ( *ppHtArray )
@@ -811,22 +802,26 @@ const SfxPoolItem& SfxItemPool::Put( const SfxPoolItem& rItem, USHORT nWhich )
                 }
             }
             else
-                if ( !ppFree )
+                if ( ppFreeIsSet == sal_False )
+                {
                     ppFree = ppHtArray;
+                    ppFreeIsSet = sal_True;
+                }
         }
     }
     else
     {
         // freien Platz suchen
-        SfxPoolItem** ppHtArr;
-        USHORT n, nCount = (*ppItemArr)->Count();
+        SfxPoolItemArrayBase_Impl::iterator ppHtArr;
+        size_t n, nCount = (*ppItemArr)->size();
         for ( n = (*ppItemArr)->nFirstFree,
-                  ppHtArr = (SfxPoolItem**)(*ppItemArr)->GetData() + n;
+                  ppHtArr = (*ppItemArr)->begin() + n;
               n < nCount;
               ++ppHtArr, ++n )
             if ( !*ppHtArr )
             {
                 ppFree = ppHtArr;
+                ppFreeIsSet = sal_True;
                 break;
             }
 
@@ -852,9 +847,9 @@ const SfxPoolItem& SfxItemPool::Put( const SfxPoolItem& rItem, USHORT nWhich )
 #endif
 #endif
     AddRef( *pNewItem, pImp->nInitRefCount );
-    const SfxPoolItem* pTemp = pNewItem;
-    if ( !ppFree )
-        (*ppItemArr)->Insert( pTemp, (*ppItemArr)->Count() );
+    SfxPoolItem* pTemp = pNewItem;
+    if ( ppFreeIsSet == sal_False )
+        (*ppItemArr)->push_back( pTemp );
     else
     {
         DBG_ASSERT( *ppFree == 0, "using surrogate in use" );
@@ -877,8 +872,8 @@ void SfxItemPool::Remove( const SfxPoolItem& rItem )
                 "wo kommt denn hier ein Pool-Default her" );
 
     // richtigen Secondary-Pool finden
-    const USHORT nWhich = rItem.Which();
-    BOOL bSID = nWhich > SFX_WHICH_MAX;
+    const sal_uInt16 nWhich = rItem.Which();
+    sal_Bool bSID = nWhich > SFX_WHICH_MAX;
     if ( !bSID && !IsInRange(nWhich) )
     {
         if ( pSecondary )
@@ -886,11 +881,11 @@ void SfxItemPool::Remove( const SfxPoolItem& rItem )
             pSecondary->Remove( rItem );
             return;
         }
-        DBG_ERROR( "unknown Which-Id - cannot remove item" );
+        OSL_FAIL( "unknown Which-Id - cannot remove item" );
     }
 
     // SID oder nicht poolable (neue Definition)?
-    USHORT nIndex = bSID ? USHRT_MAX : GetIndex_Impl(nWhich);
+    sal_uInt16 nIndex = bSID ? USHRT_MAX : GetIndex_Impl(nWhich);
     if ( bSID || IsItemFlag_Impl( nIndex, SFX_ITEM_NOT_POOLABLE ) )
     {
         SFX_ASSERT( USHRT_MAX != nIndex ||
@@ -914,8 +909,8 @@ void SfxItemPool::Remove( const SfxPoolItem& rItem )
     // Item im eigenen Pool suchen
     SfxPoolItemArray_Impl** ppItemArr = (pImp->ppPoolItems + nIndex);
     SFX_ASSERT( *ppItemArr, rItem.Which(), "removing Item not in Pool" );
-    SfxPoolItem** ppHtArr = (SfxPoolItem**)(*ppItemArr)->GetData();
-    for( USHORT n = (*ppItemArr)->Count(); n; ++ppHtArr, --n )
+    SfxPoolItemArrayBase_Impl::iterator ppHtArr = (*ppItemArr)->begin();
+    for( size_t n = (*ppItemArr)->size(); n; ++ppHtArr, --n )
         if( *ppHtArr == &rItem )
         {
             if ( (*ppHtArr)->GetRefCount() ) //!
@@ -927,7 +922,7 @@ void SfxItemPool::Remove( const SfxPoolItem& rItem )
             }
 
             // ggf. kleinstmoegliche freie Position merken
-            USHORT nPos = (*ppItemArr)->Count() - n;
+            size_t nPos = (*ppItemArr)->size() - n;
             if ( (*ppItemArr)->nFirstFree > nPos )
                 (*ppItemArr)->nFirstFree = nPos;
 
@@ -945,7 +940,7 @@ void SfxItemPool::Remove( const SfxPoolItem& rItem )
 
 // -----------------------------------------------------------------------
 
-const SfxPoolItem& SfxItemPool::GetDefaultItem( USHORT nWhich ) const
+const SfxPoolItem& SfxItemPool::GetDefaultItem( sal_uInt16 nWhich ) const
 {
     DBG_CHKTHIS(SfxItemPool, 0);
 
@@ -957,7 +952,7 @@ const SfxPoolItem& SfxItemPool::GetDefaultItem( USHORT nWhich ) const
     }
 
     DBG_ASSERT( ppStaticDefaults, "no defaults known - dont ask me for defaults" );
-    USHORT nPos = GetIndex_Impl(nWhich);
+    sal_uInt16 nPos = GetIndex_Impl(nWhich);
     SfxPoolItem *pDefault = *(ppPoolDefaults + nPos);
     if ( pDefault )
         return *pDefault;
@@ -985,17 +980,17 @@ void SfxItemPool::FreezeIdRanges()
 
 // -----------------------------------------------------------------------
 
-void SfxItemPool::FillItemIdRanges_Impl( USHORT*& pWhichRanges ) const
+void SfxItemPool::FillItemIdRanges_Impl( sal_uInt16*& pWhichRanges ) const
 {
     DBG_CHKTHIS(SfxItemPool, 0);
     DBG_ASSERT( !_pPoolRanges, "GetFrozenRanges() would be faster!" );
 
     const SfxItemPool *pPool;
-    USHORT nLevel = 0;
+    sal_uInt16 nLevel = 0;
     for( pPool = this; pPool; pPool = pPool->pSecondary )
         ++nLevel;
 
-    pWhichRanges = new USHORT[ 2*nLevel + 1 ];
+    pWhichRanges = new sal_uInt16[ 2*nLevel + 1 ];
 
     nLevel = 0;
     for( pPool = this; pPool; pPool = pPool->pSecondary )
@@ -1008,24 +1003,24 @@ void SfxItemPool::FillItemIdRanges_Impl( USHORT*& pWhichRanges ) const
 
 // -----------------------------------------------------------------------
 
-const SfxPoolItem *SfxItemPool::GetItem(USHORT nWhich, USHORT nOfst) const
+const SfxPoolItem *SfxItemPool::GetItem2(sal_uInt16 nWhich, sal_uInt32 nOfst) const
 {
     DBG_CHKTHIS(SfxItemPool, 0);
 
     if ( !IsInRange(nWhich) )
     {
         if ( pSecondary )
-            return pSecondary->GetItem( nWhich, nOfst );
+            return pSecondary->GetItem2( nWhich, nOfst );
         SFX_ASSERT( 0, nWhich, "unknown Which-Id - cannot resolve surrogate" );
         return 0;
     }
 
     // dflt-Attribut?
-    if ( nOfst == SFX_ITEMS_STATICDEFAULT )
+    if ( nOfst == SFX_ITEMS_DEFAULT )
         return *(ppStaticDefaults + GetIndex_Impl(nWhich));
 
     SfxPoolItemArray_Impl* pItemArr = *(pImp->ppPoolItems + GetIndex_Impl(nWhich));
-    if( pItemArr && nOfst < pItemArr->Count() )
+    if( pItemArr && nOfst < pItemArr->size() )
         return (*pItemArr)[nOfst];
 
     return 0;
@@ -1033,41 +1028,41 @@ const SfxPoolItem *SfxItemPool::GetItem(USHORT nWhich, USHORT nOfst) const
 
 // -----------------------------------------------------------------------
 
-USHORT SfxItemPool::GetItemCount(USHORT nWhich) const
+sal_uInt32 SfxItemPool::GetItemCount2(sal_uInt16 nWhich) const
 {
     DBG_CHKTHIS(SfxItemPool, 0);
 
     if ( !IsInRange(nWhich) )
     {
         if ( pSecondary )
-            return pSecondary->GetItemCount( nWhich );
+            return pSecondary->GetItemCount2( nWhich );
         SFX_ASSERT( 0, nWhich, "unknown Which-Id - cannot resolve surrogate" );
         return 0;
     }
 
     SfxPoolItemArray_Impl* pItemArr = *(pImp->ppPoolItems + GetIndex_Impl(nWhich));
     if  ( pItemArr )
-        return pItemArr->Count();
+        return pItemArr->size();
     return 0;
 }
 
 // -----------------------------------------------------------------------
 
-USHORT SfxItemPool::GetWhich( USHORT nSlotId, BOOL bDeep ) const
+sal_uInt16 SfxItemPool::GetWhich( sal_uInt16 nSlotId, sal_Bool bDeep ) const
 {
     if ( !IsSlot(nSlotId) )
         return nSlotId;
 
 #ifdef TF_POOLABLE
-    USHORT nCount = nEnd - nStart + 1;
-    for ( USHORT nOfs = 0; nOfs < nCount; ++nOfs )
+    sal_uInt16 nCount = nEnd - nStart + 1;
+    for ( sal_uInt16 nOfs = 0; nOfs < nCount; ++nOfs )
         if ( pItemInfos[nOfs]._nSID == nSlotId )
             return nOfs + nStart;
 #else
     if ( pSlotIds )
     {
-        USHORT nCount = nEnd - nStart + 1;
-        for ( USHORT nOfs = 0; nOfs < nCount; ++nOfs )
+        sal_uInt16 nCount = nEnd - nStart + 1;
+        for ( sal_uInt16 nOfs = 0; nOfs < nCount; ++nOfs )
             if ( pSlotIds[nOfs] == nSlotId )
                 return nOfs + nStart;
     }
@@ -1079,7 +1074,7 @@ USHORT SfxItemPool::GetWhich( USHORT nSlotId, BOOL bDeep ) const
 
 // -----------------------------------------------------------------------
 
-USHORT SfxItemPool::GetSlotId( USHORT nWhich, BOOL bDeep ) const
+sal_uInt16 SfxItemPool::GetSlotId( sal_uInt16 nWhich, sal_Bool bDeep ) const
 {
     if ( !IsWhich(nWhich) )
         return nWhich;
@@ -1093,7 +1088,7 @@ USHORT SfxItemPool::GetSlotId( USHORT nWhich, BOOL bDeep ) const
     }
 #ifdef TF_POOLABLE
 
-    USHORT nSID = pItemInfos[nWhich - nStart]._nSID;
+    sal_uInt16 nSID = pItemInfos[nWhich - nStart]._nSID;
     return nSID ? nSID : nWhich;
 #else
     else if ( pSlotIds )
@@ -1104,21 +1099,21 @@ USHORT SfxItemPool::GetSlotId( USHORT nWhich, BOOL bDeep ) const
 
 // -----------------------------------------------------------------------
 
-USHORT SfxItemPool::GetTrueWhich( USHORT nSlotId, BOOL bDeep ) const
+sal_uInt16 SfxItemPool::GetTrueWhich( sal_uInt16 nSlotId, sal_Bool bDeep ) const
 {
     if ( !IsSlot(nSlotId) )
         return 0;
 
 #ifdef TF_POOLABLE
-    USHORT nCount = nEnd - nStart + 1;
-    for ( USHORT nOfs = 0; nOfs < nCount; ++nOfs )
+    sal_uInt16 nCount = nEnd - nStart + 1;
+    for ( sal_uInt16 nOfs = 0; nOfs < nCount; ++nOfs )
         if ( pItemInfos[nOfs]._nSID == nSlotId )
             return nOfs + nStart;
 #else
     if ( pSlotIds )
     {
-        USHORT nCount = nEnd - nStart + 1;
-        for ( USHORT nOfs = 0; nOfs < nCount; ++nOfs )
+        sal_uInt16 nCount = nEnd - nStart + 1;
+        for ( sal_uInt16 nOfs = 0; nOfs < nCount; ++nOfs )
             if ( pSlotIds[nOfs] == nSlotId )
                 return nOfs + nStart;
     }
@@ -1130,7 +1125,7 @@ USHORT SfxItemPool::GetTrueWhich( USHORT nSlotId, BOOL bDeep ) const
 
 // -----------------------------------------------------------------------
 
-USHORT SfxItemPool::GetTrueSlotId( USHORT nWhich, BOOL bDeep ) const
+sal_uInt16 SfxItemPool::GetTrueSlotId( sal_uInt16 nWhich, sal_Bool bDeep ) const
 {
     if ( !IsWhich(nWhich) )
         return 0;
@@ -1152,7 +1147,7 @@ USHORT SfxItemPool::GetTrueSlotId( USHORT nWhich, BOOL bDeep ) const
 #endif
 }
 // -----------------------------------------------------------------------
-void SfxItemPool::SetFileFormatVersion( USHORT nFileFormatVersion )
+void SfxItemPool::SetFileFormatVersion( sal_uInt16 nFileFormatVersion )
 
 /*  [Description]
 
