@@ -37,10 +37,10 @@
 #include <com/sun/star/lang/XComponent.hpp>
 
 #include <svtools/accessibilityoptions.hxx>
-#include <apearcfg.hxx>
+#include <svtools/apearcfg.hxx>
 #include <svtools/menuoptions.hxx>
 #include <svtools/colorcfg.hxx>
-#include <fontsubstconfig.hxx>
+#include <svtools/fontsubstconfig.hxx>
 #include <svtools/helpopt.hxx>
 #include <svtools/printoptions.hxx>
 #include <unotools/options.hxx>
@@ -65,7 +65,7 @@ ItemHolder2::ItemHolder2()
     {
         css::uno::Reference< css::lang::XMultiServiceFactory > xSMGR = ::comphelper::getProcessServiceFactory();
         css::uno::Reference< css::lang::XComponent > xCfg(
-            xSMGR->createInstance(::rtl::OUString::createFromAscii("com.sun.star.configuration.ConfigurationProvider")),
+            xSMGR->createInstance(::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationProvider" ))),
             css::uno::UNO_QUERY);
         if (xCfg.is())
             xCfg->addEventListener(static_cast< css::lang::XEventListener* >(this));
@@ -86,7 +86,7 @@ ItemHolder2::ItemHolder2()
             sMsg += ::rtl::OString(rEx.Message.getStr(),
                         rEx.Message.getLength(),
                         RTL_TEXTENCODING_ASCII_US);
-            DBG_ERROR(sMsg.getStr());
+            OSL_FAIL(sMsg.getStr());
         }
     }
 #else
