@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,8 +31,11 @@
 
 
 #include "winmtf.hxx"
+#include <basegfx/matrix/b2dhommatrix.hxx>
+#include <basegfx/polygon/b2dpolypolygontools.hxx>
 #include <vcl/metaact.hxx>
 #include <vcl/graphictools.hxx>
+#include <vcl/canvastools.hxx>
 #include <vcl/metric.hxx>
 #include <rtl/tencinfo.h>
 
@@ -42,103 +46,56 @@
 #define EMFP_DEBUG(x)
 //#define EMFP_DEBUG(x) x
 
-void WinMtfClipPath::ImpUpdateType()
+void WinMtfClipPath::intersectClipRect( const Rectangle& rRect )
 {
-    if ( !aPolyPoly.Count() )
-        eType = EMPTY;
-    else if ( aPolyPoly.IsRect() )
-        eType = RECTANGLE;
-    else
-        eType = COMPLEX;
-
-    bNeedsUpdate = sal_True;
+    maClip.intersectRange(
+        vcl::unotools::b2DRectangleFromRectangle(rRect));
 }
 
-void WinMtfClipPath::IntersectClipRect( const Rectangle& rRect )
+void WinMtfClipPath::excludeClipRect( const Rectangle& rRect )
 {
-    if ( !aPolyPoly.Count() )
-        aPolyPoly = Polygon( rRect );
-    else if ( nDepth < WIN_MTF_MAX_CLIP_DEPTH )
+    maClip.subtractRange(
+        vcl::unotools::b2DRectangleFromRectangle(rRect));
+}
+
+void WinMtfClipPath::setClipPath( const PolyPolygon& rPolyPolygon, sal_Int32 nClippingMode )
+{
+    const basegfx::B2DPolyPolygon& rB2DPoly=rPolyPolygon.getB2DPolyPolygon();
+    switch ( nClippingMode )
     {
-        Polygon aPolygon( rRect );
-        PolyPolygon aIntersection;
-        PolyPolygon aPolyPolyRect( aPolygon );
-        aPolyPoly.GetIntersection( aPolyPolyRect, aIntersection );
-        aPolyPoly = aIntersection;
-        nDepth++;
+        case RGN_OR :
+            maClip.unionPolyPolygon(rB2DPoly);
+            break;
+        case RGN_XOR :
+            maClip.xorPolyPolygon(rB2DPoly);
+            break;
+        case RGN_DIFF :
+            maClip.subtractPolyPolygon(rB2DPoly);
+            break;
+        case RGN_AND :
+            maClip.intersectPolyPolygon(rB2DPoly);
+            break;
+        case RGN_COPY :
+            maClip = basegfx::tools::B2DClipState(rB2DPoly);
+            break;
     }
-    ImpUpdateType();
 }
 
-void WinMtfClipPath::ExcludeClipRect( const Rectangle& rRect )
+void WinMtfClipPath::moveClipRegion( const Size& rSize )
 {
-    if ( aPolyPoly.Count() && ( nDepth < WIN_MTF_MAX_CLIP_DEPTH ) )
-    {
-        Polygon aPolygon( rRect );
-        PolyPolygon aPolyPolyRect( aPolygon );
-        PolyPolygon aDifference;
-        aPolyPoly.GetDifference( aPolyPolyRect, aDifference );
-        aPolyPoly = aDifference;
-        nDepth++;
-    }
-    ImpUpdateType();
+    // what a weird concept. emulate, don't want this in B2DClipState
+    // API
+    basegfx::B2DPolyPolygon aCurrClip=maClip.getClipPoly();
+    basegfx::B2DHomMatrix aTranslate;
+    aTranslate.translate(rSize.Width(), rSize.Height());
+
+    aCurrClip.transform(aTranslate);
+    maClip = basegfx::tools::B2DClipState( aCurrClip );
 }
 
-void WinMtfClipPath::SetClipPath( const PolyPolygon& rPolyPolygon, sal_Int32 nClippingMode )
+basegfx::B2DPolyPolygon WinMtfClipPath::getClipPath() const
 {
-    if ( !rPolyPolygon.Count() )
-        aPolyPoly = rPolyPolygon;
-    else if ( nDepth < WIN_MTF_MAX_CLIP_DEPTH )
-    {
-        nDepth++;
-
-        PolyPolygon aNewClipPath;
-
-        // #115345# Watch out for empty aPolyPoly here - conceptually,
-        // an empty clip path is a rectangle of infinite size, but it
-        // is represented by an empty aPolyPoly. When intersecting
-        // rPolyPolygon with this _empty_ aPolyPoly, set algebra
-        // guarantees wrong results.
-        switch ( nClippingMode )
-        {
-            case RGN_OR :
-                // #115345# clip stays empty, when ORing an arbitrary
-                // rPolyPolygon. Thus, we can save us the unnecessary
-                // clipper call.
-                if( aPolyPoly.Count() )
-                    aPolyPoly.GetUnion( rPolyPolygon, aNewClipPath );
-            break;
-            case RGN_XOR :
-                // TODO:
-                // #115345# Cannot handle this case, for the time being
-                aPolyPoly.GetXOR( rPolyPolygon, aNewClipPath );
-            break;
-            case RGN_DIFF :
-                // TODO:
-                // #115345# Cannot handle this case, for the time being
-                aPolyPoly.GetDifference( rPolyPolygon, aNewClipPath );
-            break;
-            case RGN_AND :
-                // #115345# Clip becomes rPolyPolygon, when ANDing
-                // with an arbitrary rPolyPolygon
-                if( aPolyPoly.Count() )
-                    aPolyPoly.GetIntersection( rPolyPolygon, aNewClipPath );
-                else
-                    aNewClipPath = rPolyPolygon;
-            break;
-            case RGN_COPY :
-                aNewClipPath = rPolyPolygon;
-            break;
-        }
-        aPolyPoly = aNewClipPath;
-    }
-    ImpUpdateType();
-}
-
-void WinMtfClipPath::MoveClipRegion( const Size& rSize )
-{
-    aPolyPoly.Move( rSize.Width(), rSize.Height() );
-    bNeedsUpdate = sal_True;
+    return maClip.getClipPoly();
 }
 
 // ------------------------------------------------------------------------
@@ -196,11 +153,11 @@ WinMtfFontStyle::WinMtfFontStyle( LOGFONTW& rFont )
 {
     CharSet eCharSet;
     if ( ( rFont.lfCharSet == OEM_CHARSET ) || ( rFont.lfCharSet == DEFAULT_CHARSET ) )
-        eCharSet = gsl_getSystemTextEncoding();
+        eCharSet = RTL_TEXTENCODING_MS_1252;
     else
         eCharSet = rtl_getTextEncodingFromWindowsCharset( rFont.lfCharSet );
     if ( eCharSet == RTL_TEXTENCODING_DONTKNOW )
-        eCharSet = gsl_getSystemTextEncoding();
+        eCharSet = RTL_TEXTENCODING_MS_1252;
     aFont.SetCharSet( eCharSet );
     aFont.SetName( rFont.alfFaceName );
     FontFamily eFamily;
@@ -359,7 +316,7 @@ WinMtf::WinMtf( WinMtfOutput* pWinMtfOutput, SvStream& rStreamWMF, FilterConfigI
 
     SvLockBytes *pLB = pWMF->GetLockBytes();
     if ( pLB )
-        pLB->SetSynchronMode( TRUE );
+        pLB->SetSynchronMode( sal_True );
 
     nStartPos = pWMF->Tell();
 
@@ -387,7 +344,7 @@ WinMtf::~WinMtf()
 
 // ------------------------------------------------------------------------
 
-void WinMtf::Callback( USHORT nPercent )
+void WinMtf::Callback( sal_uInt16 nPercent )
 {
     if ( xStatusIndicator.is() )
         xStatusIndicator->setValue( nPercent );
@@ -397,9 +354,9 @@ void WinMtf::Callback( USHORT nPercent )
 
 Color WinMtf::ReadColor()
 {
-    UINT32 nColor;
+    sal_uInt32 nColor;
     *pWMF >> nColor;
-    return Color( (BYTE)nColor, (BYTE)( nColor >> 8 ), (BYTE)( nColor >> 16 ) );
+    return Color( (sal_uInt8)nColor, (sal_uInt8)( nColor >> 8 ), (sal_uInt8)( nColor >> 16 ) );
 };
 
 //-----------------------------------------------------------------------------------
@@ -420,6 +377,19 @@ Point WinMtfOutput::ImplMap( const Point& rPt )
         {
             switch( mnMapMode )
             {
+                case MM_TEXT:
+                    fX2 -= mnWinOrgX;
+                    fY2 -= mnWinOrgY;
+                    if( mnDevWidth != 1 || mnDevHeight != 1 ) {
+                        fX2 *= 2540.0/mnUnitsPerInch;
+                        fY2 *= 2540.0/mnUnitsPerInch;
+                    }
+                    fX2 += mnDevOrgX;
+                    fY2 += mnDevOrgY;
+                    fX2 *= (double)mnMillX * 100.0 / (double)mnPixX;
+                    fY2 *= (double)mnMillY * 100.0 / (double)mnPixY;
+
+                    break;
                 case MM_LOENGLISH :
                 {
                     fX2 -= mnWinOrgX;
@@ -495,6 +465,15 @@ Size WinMtfOutput::ImplMap( const Size& rSz )
         {
             switch( mnMapMode )
             {
+                case MM_TEXT:
+                if( mnDevWidth != 1 && mnDevHeight != 1 ) {
+                    fWidth *= 2540.0/mnUnitsPerInch;
+                    fHeight*= 2540.0/mnUnitsPerInch;
+                } else {
+                    fWidth *= (double)mnMillX * 100 / (double)mnPixX;
+                    fHeight *= (double)mnMillY * 100 / (double)mnPixY;
+                }
+                break;
                 case MM_LOENGLISH :
                 {
                     fWidth *= 25.40;
@@ -565,8 +544,8 @@ void WinMtfOutput::ImplMap( Font& rFont )
 
 Polygon& WinMtfOutput::ImplMap( Polygon& rPolygon )
 {
-    UINT16 nPoints = rPolygon.GetSize();
-    for ( UINT16 i = 0; i < nPoints; i++ )
+    sal_uInt16 nPoints = rPolygon.GetSize();
+    for ( sal_uInt16 i = 0; i < nPoints; i++ )
     {
         rPolygon[ i ] = ImplMap( rPolygon[ i ] );
     }
@@ -577,14 +556,14 @@ Polygon& WinMtfOutput::ImplMap( Polygon& rPolygon )
 
 PolyPolygon& WinMtfOutput::ImplMap( PolyPolygon& rPolyPolygon )
 {
-    UINT16 nPolys = rPolyPolygon.Count();
-    for ( UINT16 i = 0; i < nPolys; ImplMap( rPolyPolygon[ i++ ] ) ) ;
+    sal_uInt16 nPolys = rPolyPolygon.Count();
+    for ( sal_uInt16 i = 0; i < nPolys; ImplMap( rPolyPolygon[ i++ ] ) ) ;
     return rPolyPolygon;
 }
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::SelectObject( INT32 nIndex )
+void WinMtfOutput::SelectObject( sal_Int32 nIndex )
 {
     GDIObj* pGDIObj = NULL;
 
@@ -594,7 +573,7 @@ void WinMtfOutput::SelectObject( INT32 nIndex )
     {
         nIndex &= 0xffff;		// zur Sicherheit: mehr als 65535 nicht zulassen
 
-        if ( (UINT32)nIndex < vGDIObj.size() )
+        if ( (sal_uInt32)nIndex < vGDIObj.size() )
             pGDIObj = vGDIObj[ nIndex ];
     }
 
@@ -603,7 +582,7 @@ void WinMtfOutput::SelectObject( INT32 nIndex )
 
     if ( nIndex & ENHMETA_STOCK_OBJECT )
     {
-        UINT16 nStockId = (BYTE)nIndex;
+        sal_uInt16 nStockId = (sal_uInt8)nIndex;
         switch( nStockId )
         {
             case WHITE_BRUSH :
@@ -629,7 +608,7 @@ void WinMtfOutput::SelectObject( INT32 nIndex )
             break;
             case NULL_BRUSH :
             {
-                pGDIObj->Set( GDI_BRUSH, new WinMtfFillStyle( Color( COL_TRANSPARENT ), TRUE ) );
+                pGDIObj->Set( GDI_BRUSH, new WinMtfFillStyle( Color( COL_TRANSPARENT ), sal_True ) );
             }
             break;
             case WHITE_PEN :
@@ -644,7 +623,7 @@ void WinMtfOutput::SelectObject( INT32 nIndex )
             break;
             case NULL_PEN :
             {
-                pGDIObj->Set( GDI_PEN, new WinMtfLineStyle( Color( COL_TRANSPARENT ), TRUE ) );
+                pGDIObj->Set( GDI_PEN, new WinMtfLineStyle( Color( COL_TRANSPARENT ), sal_True ) );
             }
             break;
             default:
@@ -705,7 +684,7 @@ sal_uInt32 WinMtfOutput::GetTextLayoutMode() const
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::SetBkMode( UINT32 nMode )
+void WinMtfOutput::SetBkMode( sal_uInt32 nMode )
 {
     mnBkMode = nMode;
 }
@@ -726,14 +705,14 @@ void WinMtfOutput::SetTextColor( const Color& rColor )
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::SetTextAlign( UINT32 nAlign )
+void WinMtfOutput::SetTextAlign( sal_uInt32 nAlign )
 {
     mnTextAlign = nAlign;
 }
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::ImplResizeObjectArry( UINT32 nNewEntrys )
+void WinMtfOutput::ImplResizeObjectArry( sal_uInt32 nNewEntrys )
 {
     sal_uInt32 i = vGDIObj.size();
     vGDIObj.resize( nNewEntrys );
@@ -799,7 +778,7 @@ void WinMtfOutput::CreateObject( GDIObjectType eType, void* pStyle )
             }
         }
     }
-    UINT32 nIndex;
+    sal_uInt32 nIndex;
     for ( nIndex = 0; nIndex < vGDIObj.size(); nIndex++ )
     {
         if ( vGDIObj[ nIndex ] == NULL )
@@ -813,7 +792,7 @@ void WinMtfOutput::CreateObject( GDIObjectType eType, void* pStyle )
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::CreateObject( INT32 nIndex, GDIObjectType eType, void* pStyle )
+void WinMtfOutput::CreateObject( sal_Int32 nIndex, GDIObjectType eType, void* pStyle )
 {
     if ( ( nIndex & ENHMETA_STOCK_OBJECT ) == 0 )
     {
@@ -836,7 +815,7 @@ void WinMtfOutput::CreateObject( INT32 nIndex, GDIObjectType eType, void* pStyle
                 }
             }
         }
-        if ( (UINT32)nIndex >= vGDIObj.size() )
+        if ( (sal_uInt32)nIndex >= vGDIObj.size() )
             ImplResizeObjectArry( nIndex + 16 );
 
         if ( vGDIObj[ nIndex ] != NULL )
@@ -859,7 +838,7 @@ void WinMtfOutput::CreateObject( INT32 nIndex, GDIObjectType eType, void* pStyle
             break;
 
             default:
-                DBG_ERROR( "unsupported style not deleted" );
+                OSL_FAIL( "unsupported style not deleted" );
                 break;
         }
     }
@@ -883,31 +862,35 @@ void WinMtfOutput::DeleteObject( sal_Int32 nIndex )
 
 void WinMtfOutput::IntersectClipRect( const Rectangle& rRect )
 {
-    aClipPath.IntersectClipRect( ImplMap( rRect ) );
+    mbClipNeedsUpdate=true;
+    aClipPath.intersectClipRect( ImplMap( rRect ) );
 }
 
 //-----------------------------------------------------------------------------------
 
 void WinMtfOutput::ExcludeClipRect( const Rectangle& rRect )
 {
-    aClipPath.ExcludeClipRect( ImplMap( rRect ) );
+    mbClipNeedsUpdate=true;
+    aClipPath.excludeClipRect( ImplMap( rRect ) );
 }
 
 //-----------------------------------------------------------------------------------
 
 void WinMtfOutput::MoveClipRegion( const Size& rSize )
 {
-    aClipPath.MoveClipRegion( ImplMap( rSize ) );
+    mbClipNeedsUpdate=true;
+    aClipPath.moveClipRegion( ImplMap( rSize ) );
 }
 
 void WinMtfOutput::SetClipPath( const PolyPolygon& rPolyPolygon, sal_Int32 nClippingMode, sal_Bool bIsMapped )
 {
+    mbClipNeedsUpdate=true;
     if ( bIsMapped )
-        aClipPath.SetClipPath( rPolyPolygon, nClippingMode );
+        aClipPath.setClipPath( rPolyPolygon, nClippingMode );
     else
     {
         PolyPolygon aPP( rPolyPolygon );
-        aClipPath.SetClipPath( ImplMap( aPP ), nClippingMode );
+        aClipPath.setClipPath( ImplMap( aPP ), nClippingMode );
     }
 }
 
@@ -929,8 +912,11 @@ WinMtfOutput::WinMtfOutput( GDIMetaFile& rGDIMetaFile ) :
     maActPos			( Point() ),
     mbNopMode			( sal_False ),
     mbFillStyleSelected	( sal_False ),
+    mbClipNeedsUpdate   ( true ),
+    mbComplexClip       ( false ),
     mnGfxMode			( GM_COMPATIBLE ),
     mnMapMode           ( MM_TEXT ),
+    mnUnitsPerInch ( 96 ),
     mnDevOrgX			( 0 ),
     mnDevOrgY			( 0 ),
     mnDevWidth			( 1 ),
@@ -951,7 +937,7 @@ WinMtfOutput::WinMtfOutput( GDIMetaFile& rGDIMetaFile ) :
                                                                             // SetClipRgn( NULL ) and similar ClipRgn actions (SJ)
 
     maFont.SetName( String( RTL_CONSTASCII_USTRINGPARAM( "Arial" )) );	// sj: #i57205#, we do have some scaling problems if using
-    maFont.SetCharSet( gsl_getSystemTextEncoding() );						// the default font then most times a x11 font is used, we
+    maFont.SetCharSet( RTL_TEXTENCODING_MS_1252 );						// the default font then most times a x11 font is used, we
     maFont.SetHeight( 423 );												// will prevent this defining a font
 
     maLatestLineStyle.aLineColor = Color( 0x12, 0x34, 0x56 );
@@ -972,7 +958,7 @@ WinMtfOutput::~WinMtfOutput()
     else
         mpGDIMetaFile->SetPrefSize( mrclFrame.GetSize() );
 
-    for ( UINT32 i = 0; i < vGDIObj.size(); i++ )
+    for ( sal_uInt32 i = 0; i < vGDIObj.size(); i++ )
         delete vGDIObj[ i ];
 };
 
@@ -980,31 +966,25 @@ WinMtfOutput::~WinMtfOutput()
 
 void WinMtfOutput::UpdateClipRegion()
 {
-    if ( aClipPath.bNeedsUpdate )
+    if ( mbClipNeedsUpdate )
     {
-        aClipPath.bNeedsUpdate = sal_False;
+        mbClipNeedsUpdate = false;
+        mbComplexClip = false;
 
         mpGDIMetaFile->AddAction( new MetaPopAction() );                    // taking the orignal clipregion
         mpGDIMetaFile->AddAction( new MetaPushAction( PUSH_CLIPREGION ) );  // 
 
-        switch ( aClipPath.GetType() )
+        // skip for 'no clipping at all' case
+        if( !aClipPath.isEmpty() )
         {
-            case RECTANGLE :
-            case COMPLEX :
-            {
-//				we will not generate a RegionClipRegion Action, because this action
-//				cannot be saved to the wmf format - saving to wmf always happens
-//				if the placeholder graphic for ole objects is generated. (SJ)
+            const basegfx::B2DPolyPolygon& rClipPoly( aClipPath.getClipPath() );
+            mpGDIMetaFile->AddAction(
+                new MetaISectRectClipRegionAction(
+                    vcl::unotools::rectangleFromB2DRectangle(
+                        rClipPoly.getB2DRange())));
 
-//				Region aClipRegion( aClipPath.GetClipPath() );
-//				mpGDIMetaFile->AddAction( new MetaISectRegionClipRegionAction( aClipRegion ) );
-
-                Rectangle aClipRect( aClipPath.GetClipPath().GetBoundRect() );
-                mpGDIMetaFile->AddAction( new MetaISectRectClipRegionAction( aClipRect ) );
-            }
-            break;
-            case EMPTY:
-            break;  // -Wall not handled.
+            mbComplexClip = rClipPoly.count() > 1
+                || !basegfx::tools::isRectangle(rClipPoly);
         }
     }
 }
@@ -1014,7 +994,7 @@ void WinMtfOutput::UpdateClipRegion()
 void WinMtfOutput::ImplSetNonPersistentLineColorTransparenz()
 {
     Color aColor(  COL_TRANSPARENT);
-    WinMtfLineStyle aTransparentLine( aColor, TRUE );
+    WinMtfLineStyle aTransparentLine( aColor, sal_True );
     if ( ! ( maLatestLineStyle == aTransparentLine ) )
     {
         maLatestLineStyle = aTransparentLine;
@@ -1049,7 +1029,7 @@ void WinMtfOutput::UpdateFillStyle()
 
 //-----------------------------------------------------------------------------------
 
-sal_uInt32 WinMtfOutput::SetRasterOp( UINT32 nRasterOp )
+sal_uInt32 WinMtfOutput::SetRasterOp( sal_uInt32 nRasterOp )
 {
     sal_uInt32 nRetROP = mnRop;
     if ( nRasterOp != mnRop )
@@ -1082,8 +1062,8 @@ sal_uInt32 WinMtfOutput::SetRasterOp( UINT32 nRasterOp )
                 {
                     aNopFillStyle = maFillStyle;
                     aNopLineStyle = maLineStyle;
-                    maFillStyle = WinMtfFillStyle( Color( COL_TRANSPARENT ), TRUE );
-                    maLineStyle = WinMtfLineStyle( Color( COL_TRANSPARENT ), TRUE );
+                    maFillStyle = WinMtfFillStyle( Color( COL_TRANSPARENT ), sal_True );
+                    maLineStyle = WinMtfLineStyle( Color( COL_TRANSPARENT ), sal_True );
                     mbNopMode = sal_True;
                 }
             }
@@ -1113,7 +1093,7 @@ void WinMtfOutput::StrokeAndFillPath( sal_Bool bStroke, sal_Bool bFill )
             if ( !bStroke )
             {
                 mpGDIMetaFile->AddAction( new MetaPushAction( PUSH_LINECOLOR ) );
-                mpGDIMetaFile->AddAction( new MetaLineColorAction( Color(), FALSE ) );
+                mpGDIMetaFile->AddAction( new MetaLineColorAction( Color(), sal_False ) );
             }
             if ( aPathObj.Count() == 1 )
                 mpGDIMetaFile->AddAction( new MetaPolygonAction( aPathObj.GetObject( 0 ) ) );
@@ -1178,17 +1158,17 @@ void WinMtfOutput::DrawLine( const Point& rSource, const Point& rDest )
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::DrawRect( const Rectangle& rRect, BOOL bEdge )
+void WinMtfOutput::DrawRect( const Rectangle& rRect, sal_Bool bEdge )
 {
     UpdateClipRegion();
     UpdateFillStyle();
 
-    if ( aClipPath.GetType() == COMPLEX )
+    if ( mbComplexClip )
     {
         Polygon aPoly( ImplMap( rRect ) );
         PolyPolygon aPolyPolyRect( aPoly );
         PolyPolygon aDest;
-        aClipPath.GetClipPath().GetIntersection( aPolyPolyRect, aDest );
+        PolyPolygon(aClipPath.getClipPath()).GetIntersection( aPolyPolyRect, aDest );
         ImplDrawClippedPolyPolygon( aDest );
     }
     else
@@ -1252,7 +1232,7 @@ void WinMtfOutput::DrawEllipse( const Rectangle& rRect )
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::DrawArc( const Rectangle& rRect, const Point& rStart, const Point& rEnd, BOOL bTo )
+void WinMtfOutput::DrawArc( const Rectangle& rRect, const Point& rStart, const Point& rEnd, sal_Bool bTo )
 {
     UpdateClipRegion();
     UpdateLineStyle();
@@ -1343,18 +1323,18 @@ void WinMtfOutput::DrawPolygon( Polygon& rPolygon, sal_Bool bRecordPath )
     {
         UpdateFillStyle();
 
-        if ( aClipPath.GetType() == COMPLEX )
+        if ( mbComplexClip )
         {
             PolyPolygon aPolyPoly( rPolygon );
             PolyPolygon aDest;
-            aClipPath.GetClipPath().GetIntersection( aPolyPoly, aDest );
+            PolyPolygon(aClipPath.getClipPath()).GetIntersection( aPolyPoly, aDest );
             ImplDrawClippedPolyPolygon( aDest );
         }
         else
         {
             if ( maLineStyle.aLineInfo.GetWidth() || ( maLineStyle.aLineInfo.GetStyle() == LINE_DASH ) )
             {
-                USHORT nCount = rPolygon.GetSize();
+                sal_uInt16 nCount = rPolygon.GetSize();
                 if ( nCount )
                 {
                     if ( rPolygon[ nCount - 1 ] != rPolygon[ 0 ] )
@@ -1395,7 +1375,7 @@ void WinMtfOutput::DrawPolygon( Polygon& rPolygon, sal_Bool bRecordPath )
                     aMemStm << aFill;
 
                     mpGDIMetaFile->AddAction( new MetaCommentAction( "XPATHFILL_SEQ_BEGIN", 0,
-                                                            static_cast<const BYTE*>(aMemStm.GetData()),
+                                                            static_cast<const sal_uInt8*>(aMemStm.GetData()),
                                                             aMemStm.Seek( STREAM_SEEK_TO_END ) ) );
                     mpGDIMetaFile->AddAction( new MetaCommentAction( "XPATHFILL_SEQ_END" ) );
                 }
@@ -1419,10 +1399,10 @@ void WinMtfOutput::DrawPolyPolygon( PolyPolygon& rPolyPolygon, sal_Bool bRecordP
     {
         UpdateFillStyle();
 
-        if ( aClipPath.GetType() == COMPLEX )
+        if ( mbComplexClip )
         {
             PolyPolygon aDest;
-            aClipPath.GetClipPath().GetIntersection( rPolyPolygon, aDest );	
+            PolyPolygon(aClipPath.getClipPath()).GetIntersection( rPolyPolygon, aDest );
             ImplDrawClippedPolyPolygon( aDest );
         }
         else
@@ -1597,7 +1577,7 @@ void WinMtfOutput::DrawText( Point& rPosition, String& rText, sal_Int32* pDXArry
         pVDev->SetFont( maFont );
         if( pDXArry )
         {
-            UINT32 nLen = rText.Len();
+            sal_uInt32 nLen = rText.Len();
             nTextWidth = pVDev->GetTextWidth( rText.GetChar( (sal_uInt16)( nLen - 1 ) ) );
             if( nLen > 1 )
                 nTextWidth += pDXArry[ nLen - 2 ];
@@ -1657,7 +1637,7 @@ void WinMtfOutput::DrawText( Point& rPosition, String& rText, sal_Int32* pDXArry
 void WinMtfOutput::ImplDrawBitmap( const Point& rPos, const Size& rSize, const BitmapEx rBitmap )
 {
     BitmapEx aBmpEx( rBitmap );
-    if ( aClipPath.GetType() == COMPLEX )
+    if ( mbComplexClip )
     {
         VirtualDevice aVDev;
         MapMode aMapMode( MAP_100TH_MM );
@@ -1672,12 +1652,12 @@ void WinMtfOutput::ImplDrawBitmap( const Point& rPos, const Size& rSize, const B
         aVDev.SetMapMode( aMapMode );
         aVDev.SetOutputSizePixel( aSizePixel );
         aVDev.SetFillColor( Color( COL_BLACK ) );
-        const PolyPolygon aClip( aClipPath.GetClipPath() );
+        const PolyPolygon aClip( aClipPath.getClipPath() );
         aVDev.DrawPolyPolygon( aClip );
         const Point aEmptyPoint;
 
         // #i50672# Extract whole VDev content (to match size of rBitmap)
-        aVDev.EnableMapMode( FALSE );
+        aVDev.EnableMapMode( sal_False );
         Bitmap aMask( aVDev.GetBitmap( aEmptyPoint, aSizePixel ).CreateMask( Color( COL_WHITE ) ) );
 
         if ( aBmpEx.IsTransparent() )
@@ -1746,7 +1726,7 @@ void WinMtfOutput::ResolveBitmapActions( List& rSaveList )
             {	// patterns aren't well supported yet
                 sal_uInt32 nOldRop = SetRasterOp( ROP_OVERPAINT );	// in this case nRasterOperation is either 0 or 0xff
                 UpdateFillStyle();
-                DrawRect( aRect, FALSE );
+                DrawRect( aRect, sal_False );
                 SetRasterOp( nOldRop );
             }
             else
@@ -1811,7 +1791,7 @@ void WinMtfOutput::ResolveBitmapActions( List& rSaveList )
                             if ( nOperation == 0x1 )
                             {
                                 SetRasterOp( R2_NOT );
-                                DrawRect( aRect, FALSE );
+                                DrawRect( aRect, sal_False );
                             }
                         }
                         break;
@@ -1829,7 +1809,7 @@ void WinMtfOutput::ResolveBitmapActions( List& rSaveList )
                             if ( nOperation == 0x7 )
                             {
                                 SetRasterOp( R2_NOT );
-                                DrawRect( aRect, FALSE );
+                                DrawRect( aRect, sal_False );
                             }
                         }
                         break;
@@ -1838,7 +1818,7 @@ void WinMtfOutput::ResolveBitmapActions( List& rSaveList )
                         case 0xb :
                         {
                             SetRasterOp( R2_NOT );
-                            DrawRect( aRect, FALSE );
+                            DrawRect( aRect, sal_False );
                             SetRasterOp( R2_COPYPEN );
                             Bitmap	aMask( aBitmap );
                             aBitmap.Invert();
@@ -1849,7 +1829,7 @@ void WinMtfOutput::ResolveBitmapActions( List& rSaveList )
                             if ( nOperation == 0xb )
                             {
                                 SetRasterOp( R2_NOT );
-                                DrawRect( aRect, FALSE );
+                                DrawRect( aRect, sal_False );
                             }
                         }
                         break;
@@ -1866,7 +1846,7 @@ void WinMtfOutput::ResolveBitmapActions( List& rSaveList )
                             if ( nOperation == 0xd )
                             {
                                 SetRasterOp( R2_NOT );
-                                DrawRect( aRect, FALSE );
+                                DrawRect( aRect, sal_False );
                             }
                         }
                         break;
@@ -1878,7 +1858,7 @@ void WinMtfOutput::ResolveBitmapActions( List& rSaveList )
                             if ( nOperation == 0x9 )
                             {
                                 SetRasterOp( R2_NOT );
-                                DrawRect( aRect, FALSE );
+                                DrawRect( aRect, sal_False );
                             }
                         }
                         break;
@@ -1888,7 +1868,7 @@ void WinMtfOutput::ResolveBitmapActions( List& rSaveList )
                         {													// in this case nRasterOperation is either 0 or 0xff
                             maFillStyle = WinMtfFillStyle( Color( nRasterOperation, nRasterOperation, nRasterOperation ) );
                             UpdateFillStyle();
-                            DrawRect( aRect, FALSE );
+                            DrawRect( aRect, sal_False );
                         }
                         break;
 
@@ -1904,7 +1884,7 @@ void WinMtfOutput::ResolveBitmapActions( List& rSaveList )
                         case 0x5 :	// only destination is used
                         {
                             SetRasterOp( R2_NOT );
-                            DrawRect( aRect, FALSE );
+                            DrawRect( aRect, sal_False );
                         }
                         case 0xa :	// no operation
                         break;
@@ -1933,7 +1913,7 @@ void WinMtfOutput::SetDevOrg( const Point& rPoint )
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::SetDevOrgOffset( INT32 nXAdd, INT32 nYAdd )
+void WinMtfOutput::SetDevOrgOffset( sal_Int32 nXAdd, sal_Int32 nYAdd )
 {
     mnDevOrgX += nXAdd;
     mnDevOrgY += nYAdd;
@@ -1975,7 +1955,7 @@ void WinMtfOutput::SetWinOrg( const Point& rPoint )
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::SetWinOrgOffset( INT32 nXAdd, INT32 nYAdd )
+void WinMtfOutput::SetWinOrgOffset( sal_Int32 nXAdd, sal_Int32 nYAdd )
 {
     mnWinOrgX += nXAdd;
     mnWinOrgY += nYAdd;
@@ -2057,6 +2037,14 @@ void WinMtfOutput::SetMapMode( sal_uInt32 nMapMode )
 
 //-----------------------------------------------------------------------------------
 
+void WinMtfOutput::SetUnitsPerInch( sal_uInt16 nUnitsPerInch )
+{
+    if( nUnitsPerInch != 0 )
+    mnUnitsPerInch = nUnitsPerInch;
+}
+
+//-----------------------------------------------------------------------------------
+
 void WinMtfOutput::SetWorldTransform( const XForm& rXForm )
 {
     maXForm.eM11 = rXForm.eM11;
@@ -2069,7 +2057,7 @@ void WinMtfOutput::SetWorldTransform( const XForm& rXForm )
 
 //-----------------------------------------------------------------------------------
 
-void WinMtfOutput::ModifyWorldTransform( const XForm& rXForm, UINT32 nMode )
+void WinMtfOutput::ModifyWorldTransform( const XForm& rXForm, sal_uInt32 nMode )
 {
     switch( nMode )
     {
@@ -2221,7 +2209,7 @@ void WinMtfOutput::Pop()
         if ( ! ( aClipPath == pSave->aClipPath ) )
         {
             aClipPath = pSave->aClipPath;
-            aClipPath.bNeedsUpdate = sal_True;
+            mbClipNeedsUpdate = true;
         }
         if ( meLatestRasterOp != meRasterOp )
             mpGDIMetaFile->AddAction( new MetaRasterOpAction( meRasterOp ) );
@@ -2259,12 +2247,14 @@ void WinMtfOutput::PassEMFPlusHeaderInfo()
     // rotate and scale operations
     mem << one << zero << zero << one << zero << zero;
 
-    mpGDIMetaFile->AddAction( new MetaCommentAction( "EMF_PLUS_HEADER_INFO", 0, (const BYTE*) mem.GetData(), mem.GetEndOfData() ) );
-    mpGDIMetaFile->UseCanvas( TRUE );
+    mpGDIMetaFile->AddAction( new MetaCommentAction( "EMF_PLUS_HEADER_INFO", 0, (const sal_uInt8*) mem.GetData(), mem.GetEndOfData() ) );
+    mpGDIMetaFile->UseCanvas( sal_True );
 }
 
-void WinMtfOutput::PassEMFPlus( void* pBuffer, UINT32 nLength )
+void WinMtfOutput::PassEMFPlus( void* pBuffer, sal_uInt32 nLength )
 {
     EMFP_DEBUG(printf ("\t\t\tadd EMF_PLUS comment length %d\n", nLength));
-    mpGDIMetaFile->AddAction( new MetaCommentAction( "EMF_PLUS", 0, static_cast<const BYTE*>(pBuffer), nLength ) );
+    mpGDIMetaFile->AddAction( new MetaCommentAction( "EMF_PLUS", 0, static_cast<const sal_uInt8*>(pBuffer), nLength ) );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
