@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
  /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,10 +29,8 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_svtools.hxx"
 
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
-
-#include "rtfkeywd.hxx"
-#include "rtftoken.h"
+#include <svtools/rtfkeywd.hxx>
+#include <svtools/rtftoken.h>
 #include "tools/string.hxx"
 
 #include <string.h>
@@ -49,9 +48,9 @@ struct RTF_TokenEntry
 };
 
 // Flag: RTF-Token Tabelle wurde schon sortiert
-static int __FAR_DATA bSortKeyWords = FALSE;
+static int bSortKeyWords = sal_False;
 
-static RTF_TokenEntry __FAR_DATA aRTFTokenTab[] = {
+static RTF_TokenEntry aRTFTokenTab[] = {
 {{OOO_STRING_SVTOOLS_RTF_IGNORE},        RTF_IGNOREFLAG},
 {{OOO_STRING_SVTOOLS_RTF_RTF},           RTF_RTF},
 {{OOO_STRING_SVTOOLS_RTF_ANSI},          RTF_ANSITYPE},
@@ -778,6 +777,8 @@ static RTF_TokenEntry __FAR_DATA aRTFTokenTab[] = {
 {{OOO_STRING_SVTOOLS_RTF_BRDRDASHDD},	RTF_BRDRDASHDD},
 {{OOO_STRING_SVTOOLS_RTF_BRDRDASHDOTSTR},RTF_BRDRDASHDOTSTR},
 {{OOO_STRING_SVTOOLS_RTF_BRDRDASHSM},	RTF_BRDRDASHSM},
+{{OOO_STRING_SVTOOLS_RTF_BRDRINSET},	RTF_BRDRINSET},
+{{OOO_STRING_SVTOOLS_RTF_BRDROUTSET},	RTF_BRDROUTSET},
 {{OOO_STRING_SVTOOLS_RTF_BRDREMBOSS},	RTF_BRDREMBOSS},
 {{OOO_STRING_SVTOOLS_RTF_BRDRENGRAVE},	RTF_BRDRENGRAVE},
 {{OOO_STRING_SVTOOLS_RTF_BRDRFRAME},		RTF_BRDRFRAME},
@@ -1160,6 +1161,7 @@ static RTF_TokenEntry __FAR_DATA aRTFTokenTab[] = {
         */
         {{OOO_STRING_SVTOOLS_RTF_SN},       RTF_SN},
         {{OOO_STRING_SVTOOLS_RTF_SV},       RTF_SV},
+        {{OOO_STRING_SVTOOLS_RTF_SP},       RTF_SP},
 
 // Support for overline attributes
         {{OOO_STRING_SVTOOLS_RTF_OL}, 			RTF_OL},
@@ -1227,7 +1229,7 @@ int GetRTFToken( const String& rSearch )
                 sizeof( aRTFTokenTab ) / sizeof( RTF_TokenEntry ),
                 sizeof( RTF_TokenEntry ),
                 RTFKeyCompare );
-        bSortKeyWords = TRUE;
+        bSortKeyWords = sal_True;
     }
 
     int nRet = 0;
@@ -1245,4 +1247,4 @@ int GetRTFToken( const String& rSearch )
     return nRet;
 }
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
