@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -33,16 +34,13 @@
 #include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <com/sun/star/frame/XLayoutManager.hpp>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
-#include <imgdef.hxx>
+#include <svtools/imgdef.hxx>
 #include <svtools/miscopt.hxx>
-
-#ifndef _TOOLKIT_HELPER_VCLUNOHELPER_HXX_
 #include <toolkit/unohlp.hxx>
-#endif
 #include <vcl/toolbox.hxx>
-//shizhobo 
+//shizhobo
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 const int TOOLBARCONTROLLER_PROPHANDLE_SUPPORTSVISIABLE  = 1;
 const int TOOLBARCONTROLLER_PROPCOUNT               = 1;
@@ -88,7 +86,7 @@ struct ToolboxController_Impl
 };
 
 ToolboxController::ToolboxController(
-    
+
     const Reference< XMultiServiceFactory >& rServiceManager,
     const Reference< XFrame >& xFrame,
     const ::rtl::OUString& aCommandURL ) :
@@ -139,13 +137,13 @@ ToolboxController::~ToolboxController()
 
 Reference< XFrame > ToolboxController::getFrameInterface() const
 {
-    vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aSolarMutexGuard;
     return m_xFrame;
 }
 
 Reference< XMultiServiceFactory > ToolboxController::getServiceManager() const
 {
-    vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aSolarMutexGuard;
     return m_xServiceManager;
 }
 
@@ -154,7 +152,7 @@ Reference< XLayoutManager > ToolboxController::getLayoutManager() const
     Reference< XLayoutManager > xLayoutManager;
     Reference< XPropertySet > xPropSet;
     {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarMutexGuard;
         xPropSet = Reference< XPropertySet >( m_xFrame, UNO_QUERY );
     }
 
@@ -191,7 +189,7 @@ throw ( RuntimeException )
             ,static_cast<XMultiPropertySet*>(this)
             ,static_cast<XFastPropertySet*>(this));
         if (!a.hasValue())
-            return OWeakObject::queryInterface( rType );	
+            return OWeakObject::queryInterface( rType );
     }
     return a;
 }
@@ -210,9 +208,9 @@ void SAL_CALL ToolboxController::initialize( const Sequence< Any >& aArguments )
 throw ( Exception, RuntimeException )
 {
     bool bInitialized( true );
-    
+
     {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarMutexGuard;
 
         if ( m_bDisposed )
             throw DisposedException();
@@ -222,9 +220,9 @@ throw ( Exception, RuntimeException )
 
     if ( !bInitialized )
     {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarMutexGuard;
         m_bInitialized = sal_True;
-        //shizhoubo add 
+        //shizhoubo add
         m_bSupportVisiable = sal_False;
         PropertyValue aPropValue;
         for ( int i = 0; i < aArguments.getLength(); i++ )
@@ -262,13 +260,13 @@ throw ( Exception, RuntimeException )
 
 void SAL_CALL ToolboxController::update()
 throw ( RuntimeException )
-{ 
+{
     {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarMutexGuard;
         if ( m_bDisposed )
             throw DisposedException();
     }
-   
+
     // Bind all registered listeners to their dispatch objects
     bindListener();
 }
@@ -280,7 +278,7 @@ throw (::com::sun::star::uno::RuntimeException)
     Reference< XComponent > xThis( static_cast< OWeakObject* >(this), UNO_QUERY );
 
     {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarMutexGuard;
         if ( m_bDisposed )
             throw DisposedException();
     }
@@ -288,7 +286,7 @@ throw (::com::sun::star::uno::RuntimeException)
     com::sun::star::lang::EventObject aEvent( xThis );
     m_aListenerContainer.disposeAndClear( aEvent );
 
-    vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aSolarMutexGuard;
     Reference< XStatusListener > xStatusListener( static_cast< OWeakObject* >( this ), UNO_QUERY );
     URLToDispatchMap::iterator pIter = m_aListenerMap.begin();
     while ( pIter != m_aListenerMap.end() )
@@ -333,7 +331,7 @@ throw ( RuntimeException )
 {
     Reference< XInterface > xSource( Source.Source );
 
-    vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aSolarMutexGuard;
 
     if ( m_bDisposed )
         return;
@@ -368,7 +366,7 @@ throw (::com::sun::star::uno::RuntimeException)
     ::rtl::OUString                     aCommandURL;
 
     {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarMutexGuard;
 
         if ( m_bDisposed )
             throw DisposedException();
@@ -437,7 +435,7 @@ void ToolboxController::addStatusListener( const rtl::OUString& aCommandURL )
     com::sun::star::util::URL    aTargetURL;
 
     {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarMutexGuard;
         URLToDispatchMap::iterator pIter = m_aListenerMap.find( aCommandURL );
 
         // Already in the list of status listener. Do nothing.
@@ -448,7 +446,7 @@ void ToolboxController::addStatusListener( const rtl::OUString& aCommandURL )
         // intialize is called.
         if ( !m_bInitialized )
         {
-            // Put into the hash_map of status listener. Will be activated when initialized is called
+            // Put into the boost::unordered_map of status listener. Will be activated when initialized is called
             m_aListenerMap.insert( URLToDispatchMap::value_type( aCommandURL, Reference< XDispatch >() ));
             return;
         }
@@ -498,7 +496,7 @@ void ToolboxController::addStatusListener( const rtl::OUString& aCommandURL )
 
 void ToolboxController::removeStatusListener( const rtl::OUString& aCommandURL )
 {
-    vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aSolarMutexGuard;
 
     URLToDispatchMap::iterator pIter = m_aListenerMap.find( aCommandURL );
     if ( pIter != m_aListenerMap.end() )
@@ -529,7 +527,7 @@ void ToolboxController::bindListener()
     Reference< XStatusListener > xStatusListener;
 
     {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarMutexGuard;
 
         if ( !m_bInitialized )
             return;
@@ -618,7 +616,7 @@ void ToolboxController::bindListener()
 
 void ToolboxController::unbindListener()
 {
-    vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aSolarMutexGuard;
 
     if ( !m_bInitialized )
         return;
@@ -657,7 +655,7 @@ void ToolboxController::unbindListener()
 
 sal_Bool ToolboxController::isBound() const
 {
-    vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aSolarMutexGuard;
 
     if ( !m_bInitialized )
         return sal_False;
@@ -674,22 +672,6 @@ sal_Bool ToolboxController::hasBigImages() const
     return SvtMiscOptions().AreCurrentSymbolsLarge();
 }
 
-sal_Bool ToolboxController::isHighContrast() const
-{
-    sal_Bool bHighContrast( sal_False );
-
-    Reference< XWindow > xWindow = m_pImpl->m_xParentWindow;
-    if ( xWindow.is() )
-    {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
-        Window* pWindow = VCLUnoHelper::GetWindow( xWindow );
-        if ( pWindow )
-            bHighContrast = ( ((ToolBox *)pWindow)->GetSettings().GetStyleSettings().GetHighContrastMode() );
-    }
-
-    return bHighContrast;
-}
-
 void ToolboxController::updateStatus()
 {
     bindListener();
@@ -702,7 +684,7 @@ void ToolboxController::updateStatus( const rtl::OUString aCommandURL )
     com::sun::star::util::URL aTargetURL;
 
     {
-        vos::OGuard aSolarMutexGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarMutexGuard;
 
         if ( !m_bInitialized )
             return;
@@ -756,7 +738,7 @@ void ToolboxController::dispatchCommand( const OUString& sCommandURL, const Sequ
     try
     {
         Reference< XDispatchProvider > xDispatchProvider( m_xFrame, UNO_QUERY_THROW );
-        URL aURL;       
+        URL aURL;
         aURL.Complete = sCommandURL;
         getURLTransformer()->parseStrict( aURL );
 
@@ -806,7 +788,7 @@ sal_Bool SAL_CALL ToolboxController::convertFastPropertyValue( com::sun::star::u
     {
         case TOOLBARCONTROLLER_PROPHANDLE_SUPPORTSVISIABLE:
         {
-            sal_Bool aNewValue;
+            sal_Bool aNewValue(sal_False);
             aValue >>= aNewValue;
             if (aNewValue != m_bSupportVisiable)
             {
@@ -827,7 +809,7 @@ throw( com::sun::star::uno::Exception)
 {
     OPropertyContainer::setFastPropertyValue_NoBroadcast(nHandle, aValue);
     if (TOOLBARCONTROLLER_PROPHANDLE_SUPPORTSVISIABLE == nHandle)
-    {   
+    {
         sal_Bool rValue(sal_False);
         if (( aValue >>= rValue ) && m_bInitialized)
             this->setSupportVisiableProperty( rValue );
@@ -849,7 +831,7 @@ void ToolboxController::enable( bool bEnable )
     sal_uInt16 nItemId = 0;
     if( getToolboxId( nItemId, &pToolBox ) )
     {
-        pToolBox->EnableItem( nItemId, bEnable ? TRUE : FALSE );
+        pToolBox->EnableItem( nItemId, bEnable ? sal_True : sal_False );
     }
 }
 
@@ -884,3 +866,5 @@ bool ToolboxController::getToolboxId( sal_uInt16& rItemId, ToolBox** ppToolBox )
 //end
 
 } // svt
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
