@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -42,6 +43,7 @@
 
 #include <rtl/ref.hxx>
 #include <vcl/graph.hxx>
+#include <vcl/svapp.hxx>
 #include <svtools/svtreebx.hxx>
 
 #include <map>
@@ -81,7 +83,7 @@ public:
 class ImplGraphicItem : public SvLBoxBmp
 {
 public:
-    ImplGraphicItem( SvLBoxEntry* pEntry, USHORT nFlags, Image& aImage ) : SvLBoxBmp( pEntry, nFlags, aImage ) {}
+    ImplGraphicItem( SvLBoxEntry* pEntry, sal_uInt16 nFlags, Image& aImage ) : SvLBoxBmp( pEntry, nFlags, aImage ) {}
 
     OUString msGraphicURL;
 };
@@ -91,7 +93,7 @@ public:
 class ImplContextGraphicItem : public SvLBoxContextBmp
 {
 public:
-    ImplContextGraphicItem( SvLBoxEntry* pEntry,USHORT nFlags,Image& rI1,Image& rI2, USHORT nEntryFlagsBmp1)
+    ImplContextGraphicItem( SvLBoxEntry* pEntry,sal_uInt16 nFlags,Image& rI1,Image& rI2, sal_uInt16 nEntryFlagsBmp1)
         : SvLBoxContextBmp( pEntry, nFlags, rI1, rI2, nEntryFlagsBmp1 ) {}
 
     OUString msExpandedGraphicURL;
@@ -106,12 +108,12 @@ public:
     UnoTreeListBoxImpl( TreeControlPeer* pPeer, Window* pParent, WinBits nWinStyle );
     ~UnoTreeListBoxImpl();
 
-    sal_uInt32 insert( SvLBoxEntry* pEntry,SvLBoxEntry* pParent,ULONG nPos=LIST_APPEND );
+    sal_uInt32 insert( SvLBoxEntry* pEntry,SvLBoxEntry* pParent,sal_uLong nPos=LIST_APPEND );
 
     virtual void	RequestingChilds( SvLBoxEntry* pParent );
 
-    virtual BOOL	EditingEntry( SvLBoxEntry* pEntry, Selection& );
-    virtual BOOL	EditedEntry( SvLBoxEntry* pEntry, const XubString& rNewText );
+    virtual sal_Bool	EditingEntry( SvLBoxEntry* pEntry, Selection& );
+    virtual sal_Bool	EditedEntry( SvLBoxEntry* pEntry, const XubString& rNewText );
 
     DECL_LINK( OnSelectionChangeHdl, UnoTreeListBoxImpl* );
     DECL_LINK( OnExpandingHdl, UnoTreeListBoxImpl* );
@@ -129,7 +131,7 @@ public:
                     UnoTreeListItem( SvLBoxEntry* );
                     UnoTreeListItem();
     virtual			~UnoTreeListItem();
-    virtual USHORT	IsA();
+    virtual sal_uInt16	IsA();
     void			InitViewData( SvLBox*,SvLBoxEntry*,SvViewDataItem* );
     OUString		GetText() const;
     void 			SetText( const OUString& rText );
@@ -137,7 +139,7 @@ public:
     void			SetImage( const Image& rImage );
     OUString		GetGraphicURL() const;
     void			SetGraphicURL( const OUString& rGraphicURL );
-    void			Paint( const Point&, SvLBox& rDev, USHORT nFlags,SvLBoxEntry* );
+    void			Paint( const Point&, SvLBox& rDev, sal_uInt16 nFlags,SvLBoxEntry* );
     SvLBoxItem* 	Create() const;
     void 			Clone( SvLBoxItem* pSource );
 
@@ -259,7 +261,7 @@ void TreeControlPeer::SetWindow( Window* pWindow )
 
 // --------------------------------------------------------------------
 
-UnoTreeListEntry* TreeControlPeer::createEntry( const Reference< XTreeNode >& xNode, UnoTreeListEntry* pParent, ULONG nPos /* = LIST_APPEND */ )
+UnoTreeListEntry* TreeControlPeer::createEntry( const Reference< XTreeNode >& xNode, UnoTreeListEntry* pParent, sal_uLong nPos /* = LIST_APPEND */ )
 {
     UnoTreeListEntry* pEntry = 0;
     if( mpTreeImpl )
@@ -326,9 +328,9 @@ bool TreeControlPeer::updateEntry( UnoTreeListEntry* pEntry )
             }
         }
 
-        if( (pEntry->mxNode->hasChildrenOnDemand() == sal_True) != (pEntry->HasChildsOnDemand() == TRUE) )
+        if( (pEntry->mxNode->hasChildrenOnDemand() == sal_True) != (pEntry->HasChildsOnDemand() == sal_True) )
         {
-            pEntry->EnableChildsOnDemand( pEntry->mxNode->hasChildrenOnDemand() ? TRUE : FALSE );
+            pEntry->EnableChildsOnDemand( pEntry->mxNode->hasChildrenOnDemand() ? sal_True : sal_False );
             bChanged = true;
         }
 
@@ -486,7 +488,7 @@ UnoTreeListBoxImpl& TreeControlPeer::getTreeListBoxOrThrow() const throw (Runtim
 
 void TreeControlPeer::ChangeNodesSelection( const Any& rSelection, bool bSelect, bool bSetSelection ) throw( RuntimeException, IllegalArgumentException )
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
 
@@ -530,14 +532,14 @@ void TreeControlPeer::ChangeNodesSelection( const Any& rSelection, bool bSelect,
     }
 
     if( bSetSelection )
-        rTree.SelectAll( FALSE );
+        rTree.SelectAll( sal_False );
 
     if( pNodes && nCount )
     {
         while( nCount-- )
         {
             UnoTreeListEntry* pEntry = getEntry( *pNodes++ );
-            rTree.Select( pEntry, bSelect ? TRUE : FALSE );
+            rTree.Select( pEntry, bSelect ? sal_True : sal_False );
         }
     }
 }
@@ -548,7 +550,7 @@ void TreeControlPeer::ChangeNodesSelection( const Any& rSelection, bool bSelect,
 
 sal_Bool SAL_CALL TreeControlPeer::select( const Any& rSelection ) throw (IllegalArgumentException, RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     ChangeNodesSelection( rSelection, true, true );
     return sal_True;
 }
@@ -557,13 +559,13 @@ sal_Bool SAL_CALL TreeControlPeer::select( const Any& rSelection ) throw (Illega
 
 Any SAL_CALL TreeControlPeer::getSelection() throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
 
     Any aRet;
 
-    ULONG nSelectionCount = rTree.GetSelectionCount();
+    sal_uLong nSelectionCount = rTree.GetSelectionCount();
     if( nSelectionCount == 1 )
     {
         UnoTreeListEntry* pEntry = dynamic_cast< UnoTreeListEntry* >( rTree.FirstSelected() );
@@ -624,15 +626,15 @@ void SAL_CALL TreeControlPeer::removeSelection( const Any& rSelection ) throw (I
 
 void SAL_CALL TreeControlPeer::clearSelection() throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
-    getTreeListBoxOrThrow().SelectAll( FALSE );
+    SolarMutexGuard aGuard;
+    getTreeListBoxOrThrow().SelectAll( sal_False );
 }
 
 // -------------------------------------------------------------------
 
 sal_Int32 SAL_CALL TreeControlPeer::getSelectionCount() throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     return getTreeListBoxOrThrow().GetSelectionCount();
 }
 
@@ -678,7 +680,7 @@ Any SAL_CALL TreeSelectionEnumeration::nextElement() throw (NoSuchElementExcepti
 
 Reference< XEnumeration > SAL_CALL TreeControlPeer::createSelectionEnumeration() throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     
@@ -702,7 +704,7 @@ Reference< XEnumeration > SAL_CALL TreeControlPeer::createSelectionEnumeration()
 
 Reference< XEnumeration > SAL_CALL TreeControlPeer::createReverseSelectionEnumeration() throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     
@@ -728,7 +730,7 @@ Reference< XEnumeration > SAL_CALL TreeControlPeer::createReverseSelectionEnumer
 
 OUString SAL_CALL TreeControlPeer::getDefaultExpandedGraphicURL() throw (::com::sun::star::uno::RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     return msDefaultExpandedGraphicURL;
 }
 
@@ -736,7 +738,7 @@ OUString SAL_CALL TreeControlPeer::getDefaultExpandedGraphicURL() throw (::com::
 
 void SAL_CALL TreeControlPeer::setDefaultExpandedGraphicURL( const ::rtl::OUString& sDefaultExpandedGraphicURL ) throw (::com::sun::star::uno::RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     if( msDefaultExpandedGraphicURL != sDefaultExpandedGraphicURL )
     {
         if( sDefaultExpandedGraphicURL.getLength() )
@@ -766,7 +768,7 @@ void SAL_CALL TreeControlPeer::setDefaultExpandedGraphicURL( const ::rtl::OUStri
 
 OUString SAL_CALL TreeControlPeer::getDefaultCollapsedGraphicURL() throw (::com::sun::star::uno::RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     return msDefaultCollapsedGraphicURL;
 }
 
@@ -774,7 +776,7 @@ OUString SAL_CALL TreeControlPeer::getDefaultCollapsedGraphicURL() throw (::com:
 
 void SAL_CALL TreeControlPeer::setDefaultCollapsedGraphicURL( const ::rtl::OUString& sDefaultCollapsedGraphicURL ) throw (::com::sun::star::uno::RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     if( msDefaultCollapsedGraphicURL != sDefaultCollapsedGraphicURL )
     {
         if( sDefaultCollapsedGraphicURL.getLength() )
@@ -804,7 +806,7 @@ void SAL_CALL TreeControlPeer::setDefaultCollapsedGraphicURL( const ::rtl::OUStr
 
 sal_Bool SAL_CALL TreeControlPeer::isNodeExpanded( const Reference< XTreeNode >& xNode ) throw (RuntimeException, IllegalArgumentException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     UnoTreeListEntry* pEntry = getEntry( xNode );
@@ -815,7 +817,7 @@ sal_Bool SAL_CALL TreeControlPeer::isNodeExpanded( const Reference< XTreeNode >&
 
 sal_Bool SAL_CALL TreeControlPeer::isNodeCollapsed( const Reference< XTreeNode >& xNode ) throw (RuntimeException, IllegalArgumentException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     return !isNodeExpanded( xNode );
 }
 
@@ -823,7 +825,7 @@ sal_Bool SAL_CALL TreeControlPeer::isNodeCollapsed( const Reference< XTreeNode >
 
 void SAL_CALL TreeControlPeer::makeNodeVisible( const Reference< XTreeNode >& xNode ) throw (RuntimeException, ExpandVetoException, IllegalArgumentException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     UnoTreeListEntry* pEntry = getEntry( xNode );
@@ -835,7 +837,7 @@ void SAL_CALL TreeControlPeer::makeNodeVisible( const Reference< XTreeNode >& xN
 
 sal_Bool SAL_CALL TreeControlPeer::isNodeVisible( const Reference< XTreeNode >& xNode ) throw (RuntimeException, IllegalArgumentException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     UnoTreeListEntry* pEntry = getEntry( xNode );
@@ -846,7 +848,7 @@ sal_Bool SAL_CALL TreeControlPeer::isNodeVisible( const Reference< XTreeNode >&
 
 void SAL_CALL TreeControlPeer::expandNode( const Reference< XTreeNode >& xNode ) throw (RuntimeException, ExpandVetoException, IllegalArgumentException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     UnoTreeListEntry* pEntry = getEntry( xNode );
@@ -858,7 +860,7 @@ void SAL_CALL TreeControlPeer::expandNode( const Reference< XTreeNode >& xNode )
 
 void SAL_CALL TreeControlPeer::collapseNode( const Reference< XTreeNode >& xNode ) throw (RuntimeException, ExpandVetoException, IllegalArgumentException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     UnoTreeListEntry* pEntry = getEntry( xNode );
@@ -884,14 +886,14 @@ void SAL_CALL TreeControlPeer::removeTreeExpansionListener( const Reference< XTr
 
 Reference< XTreeNode > SAL_CALL TreeControlPeer::getNodeForLocation( sal_Int32 x, sal_Int32 y ) throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
 
     Reference< XTreeNode > xNode;
 
     const Point aPos( x, y );
-    UnoTreeListEntry* pEntry = dynamic_cast< UnoTreeListEntry* >( rTree.GetEntry( aPos, TRUE ) );
+    UnoTreeListEntry* pEntry = dynamic_cast< UnoTreeListEntry* >( rTree.GetEntry( aPos, sal_True ) );
     if( pEntry )
         xNode = pEntry->mxNode;
 
@@ -902,14 +904,14 @@ Reference< XTreeNode > SAL_CALL TreeControlPeer::getNodeForLocation( sal_Int32 x
 
 Reference< XTreeNode > SAL_CALL TreeControlPeer::getClosestNodeForLocation( sal_Int32 x, sal_Int32 y ) throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
 
     Reference< XTreeNode > xNode;
 
     const Point aPos( x, y );
-    UnoTreeListEntry* pEntry = dynamic_cast< UnoTreeListEntry* >( rTree.GetEntry( aPos, TRUE ) );
+    UnoTreeListEntry* pEntry = dynamic_cast< UnoTreeListEntry* >( rTree.GetEntry( aPos, sal_True ) );
     if( pEntry )
         xNode = pEntry->mxNode;
 
@@ -920,7 +922,7 @@ Reference< XTreeNode > SAL_CALL TreeControlPeer::getClosestNodeForLocation( sal_
 
 awt::Rectangle SAL_CALL TreeControlPeer::getNodeRect( const Reference< XTreeNode >& i_Node ) throw (IllegalArgumentException, RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     UnoTreeListEntry* pEntry = getEntry( i_Node, true );
@@ -933,7 +935,7 @@ awt::Rectangle SAL_CALL TreeControlPeer::getNodeRect( const Reference< XTreeNode
 
 sal_Bool SAL_CALL TreeControlPeer::isEditing(  ) throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     return rTree.IsEditingActive() ? sal_True : sal_False;
@@ -943,12 +945,12 @@ sal_Bool SAL_CALL TreeControlPeer::isEditing(  ) throw (RuntimeException)
 
 sal_Bool SAL_CALL TreeControlPeer::stopEditing() throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     if( rTree.IsEditingActive() )
     {
-        rTree.EndEditing(FALSE);
+        rTree.EndEditing(sal_False);
         return sal_True;
     }
     else
@@ -961,17 +963,17 @@ sal_Bool SAL_CALL TreeControlPeer::stopEditing() throw (RuntimeException)
 
 void SAL_CALL TreeControlPeer::cancelEditing(  ) throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
-    rTree.EndEditing(FALSE);
+    rTree.EndEditing(sal_False);
 }
 
 // -------------------------------------------------------------------
 
 void SAL_CALL TreeControlPeer::startEditingAtNode( const Reference< XTreeNode >& xNode ) throw (IllegalArgumentException, RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     UnoTreeListEntry* pEntry = getEntry( xNode );
@@ -1041,7 +1043,7 @@ bool TreeControlPeer::onEditedEntry( UnoTreeListEntry* pEntry, const XubString&
 
 void SAL_CALL TreeControlPeer::treeNodesChanged( const ::com::sun::star::awt::tree::TreeDataModelEvent& rEvent ) throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     if( mnEditLock != 0 )
         return;
@@ -1051,7 +1053,7 @@ void SAL_CALL TreeControlPeer::treeNodesChanged( const ::com::sun::star::awt::tr
 
 void SAL_CALL TreeControlPeer::treeNodesInserted( const ::com::sun::star::awt::tree::TreeDataModelEvent& rEvent ) throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     if( mnEditLock != 0 )
         return;
@@ -1061,7 +1063,7 @@ void SAL_CALL TreeControlPeer::treeNodesInserted( const ::com::sun::star::awt::t
 
 void SAL_CALL TreeControlPeer::treeNodesRemoved( const ::com::sun::star::awt::tree::TreeDataModelEvent& rEvent ) throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     if( mnEditLock != 0 )
         return;
@@ -1071,7 +1073,7 @@ void SAL_CALL TreeControlPeer::treeNodesRemoved( const ::com::sun::star::awt::tr
 
 void SAL_CALL TreeControlPeer::treeStructureChanged( const ::com::sun::star::awt::tree::TreeDataModelEvent& rEvent ) throw (RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     if( mnEditLock != 0 )
         return;
@@ -1104,7 +1106,7 @@ void TreeControlPeer::updateNode( UnoTreeListBoxImpl& rTree, const Reference< XT
         {
             Reference< XTreeNode > xParentNode( xNode->getParent() );
             UnoTreeListEntry* pParentEntry = 0;
-            ULONG nChild = LIST_APPEND;
+            sal_uLong nChild = LIST_APPEND;
             
             if( xParentNode.is() )
             {
@@ -1241,7 +1243,7 @@ OUString TreeControlPeer::getEntryString( const Any& rValue )
 void SAL_CALL TreeControlPeer::disposing( const ::com::sun::star::lang::EventObject& ) throw(::com::sun::star::uno::RuntimeException)
 {
     // model is disposed, so we clear our tree
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
     rTree.Clear();
     mxDataModel.clear();
@@ -1281,7 +1283,7 @@ void TreeControlPeer::onChangeDataModel( UnoTreeListBoxImpl& rTree, const Refere
 
 ::com::sun::star::awt::Size TreeControlPeer::getMinimumSize() throw(RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Size aSz;
 /* todo
@@ -1299,7 +1301,7 @@ void TreeControlPeer::onChangeDataModel( UnoTreeListBoxImpl& rTree, const Refere
 
 ::com::sun::star::awt::Size TreeControlPeer::calcAdjustedSize( const ::com::sun::star::awt::Size& rNewSize ) throw(RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     ::com::sun::star::awt::Size aSz = rNewSize;
 /* todo
@@ -1316,7 +1318,7 @@ void TreeControlPeer::onChangeDataModel( UnoTreeListBoxImpl& rTree, const Refere
 
 void TreeControlPeer::setProperty( const ::rtl::OUString& PropertyName, const Any& aValue) throw(RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     UnoTreeListBoxImpl& rTree = getTreeListBoxOrThrow();
 
@@ -1327,12 +1329,12 @@ void TreeControlPeer::setProperty( const ::rtl::OUString& PropertyName, const An
             sal_Bool bEnabled = sal_False;
             if ( aValue >>= bEnabled )
             {
-                WinBits nStyle = rTree.GetWindowBits();
+                WinBits nStyle = rTree.GetStyle();
                 if ( bEnabled )
                     nStyle |= WB_HIDESELECTION;
                 else
                     nStyle &= ~WB_HIDESELECTION;
-                rTree.SetWindowBits( nStyle );
+                rTree.SetStyle( nStyle );
             }
         }
         break;
@@ -1360,7 +1362,7 @@ void TreeControlPeer::setProperty( const ::rtl::OUString& PropertyName, const An
         case BASEPROPERTY_TREE_DATAMODEL:			
             onChangeDataModel( rTree, Reference< XTreeDataModel >( aValue, UNO_QUERY ) );
             break;
-        case BASEPROPERTY_TREE_ROWHEIGHT:
+        case BASEPROPERTY_ROW_HEIGHT:
         {
             sal_Int32 nHeight = 0;
             if( aValue >>= nHeight )
@@ -1371,7 +1373,7 @@ void TreeControlPeer::setProperty( const ::rtl::OUString& PropertyName, const An
         {
             sal_Bool bEnabled = false;
             if( aValue >>= bEnabled )
-                rTree.EnableInplaceEditing( bEnabled ? TRUE : FALSE );
+                rTree.EnableInplaceEditing( bEnabled ? sal_True : sal_False );
             break;
         }
         case BASEPROPERTY_TREE_INVOKESSTOPNODEEDITING:
@@ -1390,11 +1392,11 @@ void TreeControlPeer::setProperty( const ::rtl::OUString& PropertyName, const An
             sal_Bool bEnabled = false;
             if( aValue >>= bEnabled )
             {
-                WinBits nBits = rTree.GetWindowBits() & (~WB_HASLINES);
+                WinBits nBits = rTree.GetStyle() & (~WB_HASLINES);
                 if( bEnabled )
                     nBits |= WB_HASLINES;
-                if( nBits != rTree.GetWindowBits() )
-                    rTree.SetWindowBits( nBits );
+                if( nBits != rTree.GetStyle() )
+                    rTree.SetStyle( nBits );
             }
             break;
         }
@@ -1403,11 +1405,11 @@ void TreeControlPeer::setProperty( const ::rtl::OUString& PropertyName, const An
             sal_Bool bEnabled = false;
             if( aValue >>= bEnabled )
             {
-                WinBits nBits = rTree.GetWindowBits() & (~WB_HASLINESATROOT);
+                WinBits nBits = rTree.GetStyle() & (~WB_HASLINESATROOT);
                 if( bEnabled )
                     nBits |= WB_HASLINESATROOT;
-                if( nBits != rTree.GetWindowBits() )
-                    rTree.SetWindowBits( nBits );
+                if( nBits != rTree.GetStyle() )
+                    rTree.SetStyle( nBits );
             }
             break;
         }
@@ -1419,7 +1421,7 @@ void TreeControlPeer::setProperty( const ::rtl::OUString& PropertyName, const An
 
 Any TreeControlPeer::getProperty( const ::rtl::OUString& PropertyName ) throw(RuntimeException)
 {
-    ::vos::OGuard aGuard( GetMutex() );
+    SolarMutexGuard aGuard;
 
     const sal_uInt16 nPropId = GetPropertyId( PropertyName );
     if( (nPropId >= BASEPROPERTY_TREE_START) && (nPropId <= BASEPROPERTY_TREE_END) )
@@ -1428,7 +1430,7 @@ Any TreeControlPeer::getProperty( const ::rtl::OUString& PropertyName ) throw(Ru
         switch(nPropId)
         {
         case BASEPROPERTY_HIDEINACTIVESELECTION:
-            return Any( ( rTree.GetWindowBits() & WB_HIDESELECTION ) != 0 ? sal_True : sal_False );
+            return Any( ( rTree.GetStyle() & WB_HIDESELECTION ) != 0 ? sal_True : sal_False );
 
         case BASEPROPERTY_TREE_SELECTIONTYPE:
         {
@@ -1445,7 +1447,7 @@ Any TreeControlPeer::getProperty( const ::rtl::OUString& PropertyName ) throw(Ru
             }
             return Any( eSelectionType );
         }
-        case BASEPROPERTY_TREE_ROWHEIGHT:
+        case BASEPROPERTY_ROW_HEIGHT:
             return Any( (sal_Int32)rTree.GetEntryHeight() );
         case BASEPROPERTY_TREE_DATAMODEL:
             return Any( mxDataModel );
@@ -1456,9 +1458,9 @@ Any TreeControlPeer::getProperty( const ::rtl::OUString& PropertyName ) throw(Ru
         case BASEPROPERTY_TREE_ROOTDISPLAYED:
             return Any( mbIsRootDisplayed );
         case BASEPROPERTY_TREE_SHOWSHANDLES:
-            return Any( (rTree.GetWindowBits() & WB_HASLINES) != 0 ? sal_True : sal_False );
+            return Any( (rTree.GetStyle() & WB_HASLINES) != 0 ? sal_True : sal_False );
         case BASEPROPERTY_TREE_SHOWSROOTHANDLES:
-            return Any( (rTree.GetWindowBits() & WB_HASLINESATROOT) != 0 ? sal_True : sal_False );
+            return Any( (rTree.GetStyle() & WB_HASLINESATROOT) != 0 ? sal_True : sal_False );
         }
     }
     return VCLXWindow::getProperty( PropertyName );
@@ -1527,7 +1529,7 @@ UnoTreeListBoxImpl::UnoTreeListBoxImpl( TreeControlPeer* pPeer, Window* pParent,
 : SvTreeListBox( pParent, nWinStyle )
 , mxPeer( pPeer )
 {
-    SetWindowBits( WB_BORDER | WB_HASLINES |WB_HASBUTTONS | WB_HASLINESATROOT | WB_HASBUTTONSATROOT | WB_HSCROLL );
+    SetStyle( WB_BORDER | WB_HASLINES |WB_HASBUTTONS | WB_HASLINESATROOT | WB_HASBUTTONSATROOT | WB_HSCROLL );
     SetNodeDefaultImages();
     SetSelectHdl( LINK(this, UnoTreeListBoxImpl, OnSelectionChangeHdl) );
     SetDeselectHdl( LINK(this, UnoTreeListBoxImpl, OnSelectionChangeHdl) );
@@ -1581,7 +1583,7 @@ IMPL_LINK(UnoTreeListBoxImpl, OnExpandedHdl, UnoTreeListBoxImpl*, EMPTYARG )
 
 // --------------------------------------------------------------------
 
-sal_uInt32 UnoTreeListBoxImpl::insert( SvLBoxEntry* pEntry,SvLBoxEntry* pParent,ULONG nPos )
+sal_uInt32 UnoTreeListBoxImpl::insert( SvLBoxEntry* pEntry,SvLBoxEntry* pParent,sal_uLong nPos )
 {
     if( pParent )
         return SvTreeListBox::Insert( pEntry, pParent, nPos );
@@ -1600,14 +1602,14 @@ void UnoTreeListBoxImpl::RequestingChilds( SvLBoxEntry* pParent )
 
 // --------------------------------------------------------------------
 
-BOOL UnoTreeListBoxImpl::EditingEntry( SvLBoxEntry* pEntry, Selection& )
+sal_Bool UnoTreeListBoxImpl::EditingEntry( SvLBoxEntry* pEntry, Selection& )
 {
     return mxPeer.is() ? mxPeer->onEditingEntry( dynamic_cast< UnoTreeListEntry* >( pEntry ) ) : false;
 }
 
 // --------------------------------------------------------------------
 
-BOOL UnoTreeListBoxImpl::EditedEntry( SvLBoxEntry* pEntry, const XubString& rNewText )
+sal_Bool UnoTreeListBoxImpl::EditedEntry( SvLBoxEntry* pEntry, const XubString& rNewText )
 {
     return mxPeer.is() ? mxPeer->onEditedEntry( dynamic_cast< UnoTreeListEntry* >( pEntry ), rNewText ) : false;
 }
@@ -1636,14 +1638,14 @@ UnoTreeListItem::~UnoTreeListItem()
 
 // --------------------------------------------------------------------
 
-USHORT UnoTreeListItem::IsA()
+sal_uInt16 UnoTreeListItem::IsA()
 {
     return 0;
 }
 
 // --------------------------------------------------------------------
 
-void UnoTreeListItem::Paint( const Point& rPos, SvLBox& rDev, USHORT /* nFlags */, SvLBoxEntry* _pEntry)
+void UnoTreeListItem::Paint( const Point& rPos, SvLBox& rDev, sal_uInt16 /* nFlags */, SvLBoxEntry* _pEntry)
 {
     Point aPos( rPos );
     if( _pEntry )
@@ -1763,3 +1765,5 @@ UnoTreeListEntry::~UnoTreeListEntry()
     if( mpPeer )
         mpPeer->removeEntry( this );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
