@@ -51,7 +51,8 @@ namespace toolkit
     //= UnoSpinButtonModel
     //====================================================================
     //--------------------------------------------------------------------
-    UnoSpinButtonModel::UnoSpinButtonModel()
+    UnoSpinButtonModel::UnoSpinButtonModel( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& i_factory )
+        :UnoControlModel( i_factory )
     {
         ImplRegisterProperty( BASEPROPERTY_BACKGROUNDCOLOR );
         ImplRegisterProperty( BASEPROPERTY_BORDER );
@@ -138,15 +139,16 @@ namespace toolkit
     //= UnoSpinButtonControl
     //====================================================================
     //--------------------------------------------------------------------
-    UnoSpinButtonControl::UnoSpinButtonControl()
-        :maAdjustmentListeners( *this )
+    UnoSpinButtonControl::UnoSpinButtonControl( const Reference< XMultiServiceFactory >& i_factory )
+        :UnoControlBase( i_factory )
+        ,maAdjustmentListeners( *this )
     {
     }
 
     //--------------------------------------------------------------------
     ::rtl::OUString UnoSpinButtonControl::GetComponentServiceName()
     {
-        return ::rtl::OUString::createFromAscii( "SpinButton" );
+        return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("SpinButton"));
     }
 
     //--------------------------------------------------------------------
@@ -217,7 +219,7 @@ namespace toolkit
                 ImplSetPropertyValue( GetPropertyName( BASEPROPERTY_SPINVALUE ), makeAny( rEvent.Value ), sal_False );
                 break;
             default:
-                DBG_ERROR( "UnoSpinButtonControl::adjustmentValueChanged - unknown Type" );
+                OSL_FAIL( "UnoSpinButtonControl::adjustmentValueChanged - unknown Type" );
         }
 
         if ( maAdjustmentListeners.getLength() )
