@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #/*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,17 +32,17 @@
 
 #ifdef DBG_UTIL
 
-static BOOL ImplDbgCheckAsciiStr( const sal_Char* pAsciiStr, sal_Int32 nLen )
+static sal_Bool ImplDbgCheckAsciiStr( const sal_Char* pAsciiStr, sal_Int32 nLen )
 {
     while ( nLen && *pAsciiStr )
     {
         if ( ((unsigned char)*pAsciiStr) > 127 )
-            return FALSE;
+            return sal_False;
         ++pAsciiStr,
         --nLen;
     }
 
-    return TRUE;
+    return sal_True;
 }
 
 #endif
@@ -260,7 +261,7 @@ UniString& UniString::AssignAscii( const sal_Char* pAsciiStr, xub_StrLen nLen )
         {
             if ( !pAsciiStr[i] )
             {
-                DBG_ERROR( "UniString::AssignAscii() : nLen is wrong" );
+                OSL_FAIL( "UniString::AssignAscii() : nLen is wrong" );
             }
         }
     }
@@ -337,7 +338,7 @@ UniString& UniString::AppendAscii( const sal_Char* pAsciiStr, xub_StrLen nLen )
         {
             if ( !pAsciiStr[i] )
             {
-                DBG_ERROR( "UniString::AppendAscii() : nLen is wrong" );
+                OSL_FAIL( "UniString::AppendAscii() : nLen is wrong" );
             }
         }
     }
@@ -504,7 +505,7 @@ StringCompare UniString::CompareIgnoreCaseToAscii( const sal_Char* pAsciiStr,
 
 // -----------------------------------------------------------------------
 
-BOOL UniString::EqualsAscii( const sal_Char* pAsciiStr ) const
+sal_Bool UniString::EqualsAscii( const sal_Char* pAsciiStr ) const
 {
     DBG_CHKTHIS( UniString, DbgCheckUniString );
     DBG_ASSERT( ImplDbgCheckAsciiStr( pAsciiStr, STRING_LEN ),
@@ -515,7 +516,7 @@ BOOL UniString::EqualsAscii( const sal_Char* pAsciiStr ) const
 
 // -----------------------------------------------------------------------
 
-BOOL UniString::EqualsIgnoreCaseAscii( const sal_Char* pAsciiStr ) const
+sal_Bool UniString::EqualsIgnoreCaseAscii( const sal_Char* pAsciiStr ) const
 {
     DBG_CHKTHIS( UniString, DbgCheckUniString );
     DBG_ASSERT( ImplDbgCheckAsciiStr( pAsciiStr, STRING_LEN ),
@@ -526,7 +527,7 @@ BOOL UniString::EqualsIgnoreCaseAscii( const sal_Char* pAsciiStr ) const
 
 // -----------------------------------------------------------------------
 
-BOOL UniString::EqualsAscii( const sal_Char* pAsciiStr,
+sal_Bool UniString::EqualsAscii( const sal_Char* pAsciiStr,
                              xub_StrLen nIndex, xub_StrLen nLen ) const
 {
     DBG_CHKTHIS( UniString, DbgCheckUniString );
@@ -542,7 +543,7 @@ BOOL UniString::EqualsAscii( const sal_Char* pAsciiStr,
 
 // -----------------------------------------------------------------------
 
-BOOL UniString::EqualsIgnoreCaseAscii( const sal_Char* pAsciiStr,
+sal_Bool UniString::EqualsIgnoreCaseAscii( const sal_Char* pAsciiStr,
                                        xub_StrLen nIndex, xub_StrLen nLen ) const
 {
     DBG_CHKTHIS( UniString, DbgCheckUniString );
@@ -635,3 +636,5 @@ void UniString::SearchAndReplaceAllAscii( const sal_Char* pAsciiStr, const UniSt
         nSPos = SearchAscii( pAsciiStr, nSPos );
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
