@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,7 +34,7 @@
 
  *************************************************************************/
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <com/sun/star/ucb/ContentAction.hpp>
 #include <com/sun/star/ucb/CommandInfoChange.hpp>
 #include <com/sun/star/ucb/XPersistentPropertySet.hpp>
@@ -101,7 +102,7 @@ struct hashPtr
     }
 };
 
-typedef std::hash_map
+typedef boost::unordered_map
 <
     XPropertiesChangeListenerPtr,
     PropertyEventSequence*,
@@ -596,20 +597,17 @@ void SAL_CALL ContentImplHelper::addProperty(
             }
             catch ( beans::PropertyExistException const & )
             {
-                OSL_ENSURE( sal_False,
-                            "ContentImplHelper::addProperty - Exists!" );
+                OSL_FAIL( "ContentImplHelper::addProperty - Exists!" );
                 throw;
             }
             catch ( beans::IllegalTypeException const & )
             {
-                OSL_ENSURE( sal_False,
-                            "ContentImplHelper::addProperty - Wrong Type!" );
+                OSL_FAIL( "ContentImplHelper::addProperty - Wrong Type!" );
                 throw;
             }
             catch ( lang::IllegalArgumentException const & )
             {
-                OSL_ENSURE( sal_False,
-                            "ContentImplHelper::addProperty - Illegal Arg!" );
+                OSL_FAIL( "ContentImplHelper::addProperty - Illegal Arg!" );
                 throw;
             }
 
@@ -663,7 +661,7 @@ void SAL_CALL ContentImplHelper::removeProperty( const rtl::OUString& Name )
     }
     catch ( beans::UnknownPropertyException const & )
     {
-        OSL_ENSURE( sal_False, "ContentImplHelper::removeProperty - Unknown!" );
+        OSL_FAIL( "ContentImplHelper::removeProperty - Unknown!" );
         throw;
     }
 
@@ -691,14 +689,12 @@ void SAL_CALL ContentImplHelper::removeProperty( const rtl::OUString& Name )
             }
             catch ( beans::UnknownPropertyException const & )
             {
-                OSL_ENSURE( sal_False,
-                            "ContentImplHelper::removeProperty - Unknown!" );
+                OSL_FAIL( "ContentImplHelper::removeProperty - Unknown!" );
                 throw;
             }
             catch ( beans::NotRemoveableException const & )
             {
-                OSL_ENSURE( 
-                    sal_False,
+                OSL_FAIL( 
                     "ContentImplHelper::removeProperty - Unremoveable!" );
                 throw;
             }
@@ -1125,3 +1121,5 @@ ContentImplHelper::getPropertySetInfo(
 }
 
 } // namespace ucbhelper
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
