@@ -50,12 +50,16 @@
 //-----------------------------------------------------------------------------
 
 using namespace utl;
-using namespace rtl;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::beans;
 using namespace com::sun::star::container;
 
+using ::rtl::OUString;
+#if OSL_DEBUG_LEVEL > 0
+using ::rtl::OString;
+#endif
+
 #define UNISTRING(s) rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(s))
 
 //-----------------------------------------------------------------------------
@@ -101,29 +105,27 @@ struct utl::ConfigMgr_Impl
     ConfigItemList 							aItemList;
 };
 
-/* -----------------------------28.08.00 15:35--------------------------------
-
- ---------------------------------------------------------------------------*/
 ConfigManager::ConfigManager() :
     pMgrImpl(new utl::ConfigMgr_Impl)
 {
     GetConfigurationProvider(); // attempt to create the provider early
 }
-/* -----------------------------17.11.00 13:51--------------------------------
 
- ---------------------------------------------------------------------------*/
 ConfigManager::ConfigManager(Reference< XMultiServiceFactory > xConfigProv) :
     xConfigurationProvider(xConfigProv),
     pMgrImpl(new utl::ConfigMgr_Impl)
 {
 }
-/* -----------------------------28.08.00 15:35--------------------------------
 
- ---------------------------------------------------------------------------*/
 ConfigManager::~ConfigManager()
 {
     //check list content -> should be empty!
+#if OSL_DEBUG_LEVEL > 1
+    // I think this is a pointless assertion, the code seems to cope
+    // fine with it being empty, no need to crash in a dbglevel=1
+    // build.
     OSL_ENSURE(pMgrImpl->aItemList.empty(), "some ConfigItems are still alive");
+#endif
     if(!pMgrImpl->aItemList.empty())
     {
         ConfigItemList::iterator aListIter;
@@ -137,9 +139,7 @@ ConfigManager::~ConfigManager()
     delete pMgrImpl;
 
 }
-/* -----------------------------28.08.00 16:17--------------------------------
 
- ---------------------------------------------------------------------------*/
 Reference< XMultiServiceFactory > ConfigManager::GetConfigurationProvider()
 {
     if(!xConfigurationProvider.is())
@@ -154,7 +154,7 @@ Reference< XMultiServiceFactory > ConfigManager::GetConfigurationProvider()
                         UNISTRING("com.sun.star.configuration.ConfigurationProvider")),
                      UNO_QUERY);
             }
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     catch(Exception& rEx)
     {
         static sal_Bool bMessage = sal_True;
@@ -165,7 +165,7 @@ Reference< XMultiServiceFactory > ConfigManager::GetConfigurationProvider()
             sMsg += OString(rEx.Message.getStr(),
                         rEx.Message.getLength(),
                         RTL_TEXTENCODING_ASCII_US);
-            OSL_ENSURE(sal_False, sMsg.getStr());
+            OSL_FAIL(sMsg.getStr());
         }
     }
 #else
@@ -175,9 +175,7 @@ Reference< XMultiServiceFactory > ConfigManager::GetConfigurationProvider()
     }
     return xConfigurationProvider;
 }
-/* -----------------------------03.12.02 -------------------------------------
 
- ---------------------------------------------------------------------------*/
 namespace
 {
     // helper to achieve exception - safe registration of a ConfigItem under construction
@@ -201,16 +199,12 @@ namespace
         void keep() { pCfgItem = 0; }
     };
 }
-/* -----------------------------12.12.00 17:19--------------------------------
 
- ---------------------------------------------------------------------------*/
 Reference< XMultiServiceFactory > ConfigManager::GetLocalConfigurationProvider()
 {
     return GetConfigurationProvider();
 }
-/* -----------------------------29.08.00 12:35--------------------------------
 
- ---------------------------------------------------------------------------*/
 Reference< XHierarchicalNameAccess > ConfigManager::AddConfigItem(utl::ConfigItem& rCfgItem)
 {
     RegisterConfigItemHelper registeredItem(*this,rCfgItem);
@@ -218,30 +212,26 @@ Reference< XHierarchicalNameAccess > ConfigManager::AddConfigItem(utl::ConfigIte
     registeredItem.keep();
     return xTree;
 }
-/* -----------------------------21.06.01 12:20--------------------------------
 
- ---------------------------------------------------------------------------*/
 void    ConfigManager::RegisterConfigItem(utl::ConfigItem& rCfgItem)
 {
     ConfigItemList::iterator aListIter = pMgrImpl->aItemList.begin();
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     for(aListIter = pMgrImpl->aItemList.begin(); aListIter != pMgrImpl->aItemList.end(); ++aListIter)
     {
         ConfigItemListEntry_Impl& rEntry = *aListIter;
         if(rEntry.pConfigItem == &rCfgItem)
-            OSL_ENSURE(sal_False, "RegisterConfigItem: already inserted!");
+            OSL_FAIL("RegisterConfigItem: already inserted!");
     }
 #endif
     pMgrImpl->aItemList.insert(aListIter, ConfigItemListEntry_Impl(&rCfgItem));
 }
-/* -----------------------------21.06.01 12:20--------------------------------
 
- ---------------------------------------------------------------------------*/
 Reference< XHierarchicalNameAccess> ConfigManager::AcquireTree(utl::ConfigItem& rCfgItem)
 {
-    ConfigItemList::iterator aListIter = pMgrImpl->aItemList.begin();
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     sal_Bool bFound = sal_False;
+    ConfigItemList::iterator aListIter = pMgrImpl->aItemList.begin();
     for(aListIter = pMgrImpl->aItemList.begin(); aListIter != pMgrImpl->aItemList.end(); ++aListIter)
     {
         ConfigItemListEntry_Impl& rEntry = *aListIter;
@@ -300,23 +290,21 @@ Reference< XHierarchicalNameAccess> ConfigManager::AcquireTree(utl::ConfigItem&
 
                 throw;
             }
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
             if(0 == (CONFIG_MODE_IGNORE_ERRORS & rCfgItem.GetMode()))
             {
                 OString sMsg("CreateInstance exception: ");
                 sMsg += OString(rEx.Message.getStr(),
                             rEx.Message.getLength(),
                             RTL_TEXTENCODING_ASCII_US);
-                OSL_ENSURE(sal_False, sMsg.getStr());
+                OSL_FAIL(sMsg.getStr());
             }
 #endif
         }
     }
     return Reference<XHierarchicalNameAccess>(xIFace, UNO_QUERY);
 }
-/* -----------------------------29.08.00 12:35--------------------------------
 
- ---------------------------------------------------------------------------*/
 void ConfigManager::RemoveConfigItem(utl::ConfigItem& rCfgItem)
 {
     if( !pMgrImpl->aItemList.empty() )
@@ -333,9 +321,7 @@ void ConfigManager::RemoveConfigItem(utl::ConfigItem& rCfgItem)
         }
     }
 }
-/* -----------------------------30.08.00 15:04--------------------------------
 
- ---------------------------------------------------------------------------*/
 void ConfigManager::StoreConfigItems()
 {
     if(!pMgrImpl->aItemList.empty())
@@ -352,47 +338,37 @@ void ConfigManager::StoreConfigItems()
         }
     }
 }
-/* -----------------------------07.09.00 11:06--------------------------------
 
- ---------------------------------------------------------------------------*/
 struct theConfigManager : public rtl::Static<ConfigManager, theConfigManager> {};
 
 ConfigManager& ConfigManager::GetConfigManager()
 {
     return theConfigManager::get();
 }
-/* -----------------------------08.09.00 13:22--------------------------------
 
- ---------------------------------------------------------------------------*/
 rtl::OUString ConfigManager::GetConfigBaseURL()
 {
     return OUString::createFromAscii(pConfigBaseURL);
 }
-/* -----------------------------25.09.00 16:34--------------------------------
 
- ---------------------------------------------------------------------------*/
 Any ConfigManager::GetDirectConfigProperty(ConfigProperty eProp)
 {
     switch(eProp)
     {
         case INSTALLPATH:
-            OSL_ENSURE( false,
-                        "ConfigManager::GetDirectConfigProperty: "
+            OSL_FAIL( "ConfigManager::GetDirectConfigProperty: "
                         "INSTALLPATH no longer supported." );
             return Any();
         case USERINSTALLURL:
-            OSL_ENSURE( false,
-                        "ConfigManager::GetDirectConfigProperty: "
+            OSL_FAIL( "ConfigManager::GetDirectConfigProperty: "
                         "USERINSTALLURL no longer supported." );
             return Any();
         case OFFICEINSTALL:
-            OSL_ENSURE( false,
-                        "ConfigManager::GetDirectConfigProperty: "
+            OSL_FAIL( "ConfigManager::GetDirectConfigProperty: "
                         "OFFICEINSTALL no longer supported." );
             return Any();
         case OFFICEINSTALLURL:
-            OSL_ENSURE( false,
-                        "ConfigManager::GetDirectConfigProperty: "
+            OSL_FAIL( "ConfigManager::GetDirectConfigProperty: "
                         "OFFICEINSTALLURL no longer supported." );
             return Any();
         default:
@@ -405,7 +381,7 @@ Any ConfigManager::GetDirectConfigProperty(ConfigProperty eProp)
 #ifdef ENABLE_BROFFICE
     LanguageType nType = MsLangId::getRealLanguage( LANGUAGE_NONE );
     if ( nType == LANGUAGE_PORTUGUESE_BRAZILIAN )
-        sBrandName = OUString::createFromAscii("BrOffice");
+        sBrandName = OUString(RTL_CONSTASCII_USTRINGPARAM("BrOffice"));
     else
 #endif
         sBrandName = BrandName::get();
@@ -475,9 +451,8 @@ Any ConfigManager::GetDirectConfigProperty(ConfigProperty eProp)
 
     if (eProp == PRODUCTEXTENSION) {
         rtl::OUString name(
-            rtl::OUString(
                 RTL_CONSTASCII_USTRINGPARAM(
-                    "${BRAND_BASE_DIR}/program/edition/edition.ini")));
+                    "${BRAND_BASE_DIR}/program/edition/edition.ini"));
         rtl::Bootstrap::expandMacros(name);
         if (rtl::Bootstrap(name).getFrom(
                 rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("EDITIONNAME")),
@@ -555,7 +530,7 @@ Any ConfigManager::GetDirectConfigProperty(ConfigProperty eProp)
             aBuf.append( "\" under \"" );
             aBuf.append( rtl::OUStringToOString( sPath, RTL_TEXTENCODING_ASCII_US ) );
             aBuf.append( "\" (caught an exception)!" );
-            OSL_ENSURE( sal_False, aBuf.getStr() );
+            OSL_FAIL( aBuf.getStr() );
             #endif
         }
     }
@@ -636,9 +611,6 @@ void ConfigManager::getBasisAboutBoxProductVersion( OUString& rVersion )
     }
 }
 
-/* -----------------------------12.12.00 17:22--------------------------------
-
- ---------------------------------------------------------------------------*/
 Reference< XHierarchicalNameAccess> ConfigManager::GetHierarchyAccess(const OUString& rFullPath)
 {
     Sequence< Any > aArgs(1);
@@ -653,14 +625,14 @@ Reference< XHierarchicalNameAccess> ConfigManager::GetHierarchyAccess(const OUSt
                     OUString::createFromAscii(pAccessSrvc),
                     aArgs);
         }
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
         catch(Exception& rEx)
         {
             OString sMsg("CreateInstance exception: ");
             sMsg += OString(rEx.Message.getStr(),
                         rEx.Message.getLength(),
                          RTL_TEXTENCODING_ASCII_US);
-            OSL_ENSURE(sal_False, sMsg.getStr());
+            OSL_FAIL(sMsg.getStr());
         }
 #else
         catch(Exception&){}
@@ -668,9 +640,7 @@ Reference< XHierarchicalNameAccess> ConfigManager::GetHierarchyAccess(const OUSt
     }
     return Reference<XHierarchicalNameAccess>(xIFace, UNO_QUERY);
 }
-/* -----------------------------12.12.00 17:17--------------------------------
 
- ---------------------------------------------------------------------------*/
 Any ConfigManager::GetLocalProperty(const OUString& rProperty)
 {
     OUString sPath(OUString::createFromAscii(pConfigBaseURL));
@@ -686,23 +656,21 @@ Any ConfigManager::GetLocalProperty(const OUString& rProperty)
         if(xAccess.is())
             aRet = xAccess->getByName(sProperty);
     }
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     catch(Exception& rEx)
     {
         OString sMsg("GetLocalProperty: ");
         sMsg += OString(rEx.Message.getStr(),
                     rEx.Message.getLength(),
                      RTL_TEXTENCODING_ASCII_US);
-        OSL_ENSURE(sal_False, sMsg.getStr());
+        OSL_FAIL(sMsg.getStr());
     }
 #else
     catch(Exception&){}
 #endif
     return aRet;
 }
-/* -----------------------------12.12.00 17:17--------------------------------
 
- ---------------------------------------------------------------------------*/
 void ConfigManager::PutLocalProperty(const OUString& rProperty, const Any& rValue)
 {
     OUString sPath(OUString::createFromAscii(pConfigBaseURL));
@@ -718,23 +686,21 @@ void ConfigManager::PutLocalProperty(const OUString& rProperty, const Any& rValu
         {
             xNodeReplace->replaceByName(sProperty, rValue);
         }
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
         catch(Exception& rEx)
         {
             OString sMsg("PutLocalProperty: ");
             sMsg += OString(rEx.Message.getStr(),
                         rEx.Message.getLength(),
                          RTL_TEXTENCODING_ASCII_US);
-            OSL_ENSURE(sal_False, sMsg.getStr());
+            OSL_FAIL(sMsg.getStr());
         }
 #else
         catch(Exception& ){}
 #endif
     }
 }
-/* -----------------------------13.12.00 08:47--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Bool	ConfigManager::IsLocalConfigProvider()
 {
     return false;
