@@ -47,10 +47,10 @@
 
 using namespace osl;
 using namespace utl;
-using namespace rtl;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
 
+using ::rtl::OUString;
 
 SvtSysLocaleOptions_Impl*   SvtSysLocaleOptions::pOptions = NULL;
 sal_Int32                   SvtSysLocaleOptions::nRefCount = 0;
@@ -89,7 +89,7 @@ class SvtSysLocaleOptions_Impl : public utl::ConfigItem
         OUString                m_aLocaleString;    // en-US or de-DE or empty for SYSTEM
         OUString                m_aUILocaleString;    // en-US or de-DE or empty for SYSTEM
         OUString                m_aCurrencyString;  // USD-en-US or EUR-de-DE
-        ULONG                   m_nBlockedHint;     // pending hints
+        sal_uLong                   m_nBlockedHint;     // pending hints
         sal_Bool                m_bDecimalSeparator; //use decimal separator same as locale
 
         sal_Bool                m_bROLocale;
@@ -387,7 +387,7 @@ void SvtSysLocaleOptions_Impl::SetLocaleString( const OUString& rStr )
         MakeRealLocale();
         MsLangId::setConfiguredSystemLanguage( m_eRealLanguage );
         SetModified();
-        ULONG nHint = SYSLOCALEOPTIONS_HINT_LOCALE;
+        sal_uLong nHint = SYSLOCALEOPTIONS_HINT_LOCALE;
         if ( !m_aCurrencyString.getLength() )
             nHint |= SYSLOCALEOPTIONS_HINT_CURRENCY;
         NotifyListeners( nHint );
@@ -431,7 +431,7 @@ void SvtSysLocaleOptions_Impl::SetDecimalSeparatorAsLocale( sal_Bool bSet)
 
 void SvtSysLocaleOptions_Impl::Notify( const Sequence< rtl::OUString >& seqPropertyNames )
 {
-    ULONG nHint = 0;
+    sal_uLong nHint = 0;
     Sequence< Any > seqValues = GetProperties( seqPropertyNames );
     Sequence< sal_Bool > seqROStates = GetReadOnlyStates( seqPropertyNames );
     sal_Int32 nCount = seqPropertyNames.getLength();
@@ -578,19 +578,12 @@ void SvtSysLocaleOptions::SetCurrencyConfigString( const OUString& rStr )
     pOptions->SetCurrencyString( rStr );
 }
 
-
-
-/*-- 11.02.2004 13:31:41---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 sal_Bool SvtSysLocaleOptions::IsDecimalSeparatorAsLocale() const
 {
     MutexGuard aGuard( GetMutex() );
     return pOptions->IsDecimalSeparatorAsLocale();
 }
-/*-- 11.02.2004 13:31:41---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SvtSysLocaleOptions::SetDecimalSeparatorAsLocale( sal_Bool bSet)
 {
     MutexGuard aGuard( GetMutex() );
