@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -104,7 +105,7 @@ bool AquaSalBitmap::Create( CGLayerRef xLayer, int nBitmapBits,
 
 // ------------------------------------------------------------------
 
-bool AquaSalBitmap::Create( const Size& rSize, USHORT nBits, const BitmapPalette& rBitmapPalette )
+bool AquaSalBitmap::Create( const Size& rSize, sal_uInt16 nBits, const BitmapPalette& rBitmapPalette )
 {
     if( !isValidBitCount( nBits ) )
         return false;
@@ -131,7 +132,7 @@ bool AquaSalBitmap::Create( const SalBitmap& rSalBmp, SalGraphics* pGraphics )
 
 // ------------------------------------------------------------------
 
-bool AquaSalBitmap::Create( const SalBitmap& rSalBmp, USHORT nNewBitCount )
+bool AquaSalBitmap::Create( const SalBitmap& rSalBmp, sal_uInt16 nNewBitCount )
 {
     const AquaSalBitmap& rSourceBitmap = static_cast<const AquaSalBitmap&>(rSalBmp);
 
@@ -264,7 +265,7 @@ bool AquaSalBitmap::AllocateUserData()
         case 24:	mnBytesPerRow = (mnWidth << 1) + mnWidth; break;
         case 32:	mnBytesPerRow = mnWidth << 2; break;
         default:
-            DBG_ERROR("vcl::AquaSalBitmap::AllocateUserData(), illegal bitcount!");
+            OSL_FAIL("vcl::AquaSalBitmap::AllocateUserData(), illegal bitcount!");
         }
     }
     
@@ -275,7 +276,7 @@ bool AquaSalBitmap::AllocateUserData()
     }
     catch( const std::bad_alloc& )
     {
-        DBG_ERROR( "vcl::AquaSalBitmap::AllocateUserData: bad alloc" );
+        OSL_FAIL( "vcl::AquaSalBitmap::AllocateUserData: bad alloc" );
         maUserBuffer.reset( NULL );
         mnBytesPerRow = 0;
     }
@@ -567,7 +568,7 @@ Size AquaSalBitmap::GetSize() const
 
 // ------------------------------------------------------------------
 
-USHORT AquaSalBitmap::GetBitCount() const
+sal_uInt16 AquaSalBitmap::GetBitCount() const
 {
     return mnBits;
 }
@@ -576,9 +577,9 @@ USHORT AquaSalBitmap::GetBitCount() const
 
 static struct pal_entry
 {
-    BYTE mnRed;
-    BYTE mnGreen;
-    BYTE mnBlue;
+    sal_uInt8 mnRed;
+    sal_uInt8 mnGreen;
+    sal_uInt8 mnBlue;
 }
 const aImplSalSysPalEntryAry[ 16 ] =
 {
@@ -633,9 +634,9 @@ const BitmapPalette& GetDefaultPalette( int mnBits, bool bMonochrome )
 
         // own palette (6/6/6)
         const int DITHER_PAL_STEPS = 6;
-        const BYTE DITHER_PAL_DELTA = 51;
+        const sal_uInt8 DITHER_PAL_DELTA = 51;
         int nB, nG, nR;
-        BYTE nRed, nGreen, nBlue;
+        sal_uInt8 nRed, nGreen, nBlue;
         for( nB=0, nBlue=0; nB < DITHER_PAL_STEPS; nB++, nBlue += DITHER_PAL_DELTA )
         {
             for( nG=0, nGreen=0; nG < DITHER_PAL_STEPS; nG++, nGreen += DITHER_PAL_DELTA )
@@ -909,3 +910,5 @@ bool AquaSalBitmap::GetSystemData( BitmapSystemData& rData )
     
     return bRet;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
