@@ -35,7 +35,7 @@
 static ::rtl::OString polyToString( const Polygon& rPoly )
 {
     ::rtl::OString aStr;
-    USHORT nVertex;
+    sal_uInt16 nVertex;
     for(nVertex=0; nVertex<rPoly.GetSize(); ++nVertex)
     {
         aStr += "(";
@@ -52,7 +52,7 @@ static ::rtl::OString polyToString( const Polygon& rPoly )
                 break;
 
             default:
-                DBG_ERROR( "SvtGraphicStroke::polyToString invalid flag");
+                OSL_FAIL( "SvtGraphicStroke::polyToString invalid flag");
                 break;
         }
         aStr += ::rtl::OString::valueOf( static_cast< double >( rPoly[nVertex].getX() ) );
@@ -67,7 +67,7 @@ static ::rtl::OString polyToString( const Polygon& rPoly )
 static ::rtl::OString polyPolyToString( const PolyPolygon& rPolyPoly )
 {
     ::rtl::OString aStr;
-    USHORT nPoly;
+    sal_uInt16 nPoly;
     for(nPoly=0; nPoly<rPolyPoly.Count(); ++nPoly)
     {
         const Polygon& rPoly = rPolyPoly[nPoly];
@@ -227,7 +227,7 @@ void SvtGraphicStroke::getDashArray( DashArray& rDashArray ) const
             break;
 
         default:
-            DBG_ERROR( "SvtGraphicStroke::toString missing cap type");
+            OSL_FAIL( "SvtGraphicStroke::toString missing cap type");
             break;
     }
     aStr += " join: ";
@@ -250,7 +250,7 @@ void SvtGraphicStroke::getDashArray( DashArray& rDashArray ) const
             break;
 
         default:
-            DBG_ERROR( "SvtGraphicStroke::toString missing join type");
+            OSL_FAIL( "SvtGraphicStroke::toString missing join type");
             break;
     }
     aStr += " ";
@@ -328,9 +328,9 @@ SvStream& operator<<( SvStream& rOStm, const SvtGraphicStroke& rClass )
     rClass.maEndArrow.Write( rOStm );
     rOStm << rClass.mfTransparency;
     rOStm << rClass.mfStrokeWidth;
-    UINT16 nTmp = sal::static_int_cast<UINT16>( rClass.maCapType );
+    sal_uInt16 nTmp = sal::static_int_cast<sal_uInt16>( rClass.maCapType );
     rOStm << nTmp;
-    nTmp = sal::static_int_cast<UINT16>( rClass.maJoinType );
+    nTmp = sal::static_int_cast<sal_uInt16>( rClass.maJoinType );
     rOStm << nTmp;
     rOStm << rClass.mfMiterLimit;
 
@@ -351,7 +351,7 @@ SvStream& operator>>( SvStream& rIStm, SvtGraphicStroke& rClass )
     rClass.maEndArrow.Read( rIStm );
     rIStm >> rClass.mfTransparency;
     rIStm >> rClass.mfStrokeWidth;
-    UINT16 nTmp;
+    sal_uInt16 nTmp;
     rIStm >> nTmp;
     rClass.maCapType = SvtGraphicStroke::CapType(nTmp);
     rIStm >> nTmp;
@@ -515,7 +515,7 @@ void SvtGraphicFill::getGraphic( Graphic& rGraphic ) const
             break;
 
         default:
-            DBG_ERROR( "SvtGraphicFill::toString missing fill rule");
+            OSL_FAIL( "SvtGraphicFill::toString missing fill rule");
             break;
     }
     aStr += " type: ";
@@ -538,7 +538,7 @@ void SvtGraphicFill::getGraphic( Graphic& rGraphic ) const
             break;
 
         default:
-            DBG_ERROR( "SvtGraphicStroke::toString missing fill type");
+            OSL_FAIL( "SvtGraphicStroke::toString missing fill type");
             break;
     }
 
@@ -564,7 +564,7 @@ void SvtGraphicFill::getGraphic( Graphic& rGraphic ) const
             break;
 
         default:
-            DBG_ERROR( "SvtGraphicStroke::toString missing hatch type");
+            OSL_FAIL( "SvtGraphicStroke::toString missing hatch type");
             break;
     }
 
@@ -587,7 +587,7 @@ void SvtGraphicFill::getGraphic( Graphic& rGraphic ) const
             break;
 
         default:
-            DBG_ERROR( "SvtGraphicStroke::toString missing gradient type");
+            OSL_FAIL( "SvtGraphicStroke::toString missing gradient type");
             break;
     }
 
@@ -618,7 +618,7 @@ void SvtGraphicFill::getGraphic( Graphic& rGraphic ) const
                 break;
 
             default:
-                DBG_ERROR( "SvtGraphicStroke::toString missing graphic type");
+                OSL_FAIL( "SvtGraphicStroke::toString missing graphic type");
                 break;
         }
 
@@ -707,19 +707,19 @@ SvStream& operator<<( SvStream& rOStm, const SvtGraphicFill& rClass )
     rClass.maPath.Write( rOStm );
     rOStm << rClass.maFillColor;
     rOStm << rClass.mfTransparency;
-    UINT16 nTmp = sal::static_int_cast<UINT16>( rClass.maFillRule );
+    sal_uInt16 nTmp = sal::static_int_cast<sal_uInt16>( rClass.maFillRule );
     rOStm << nTmp;
-    nTmp = sal::static_int_cast<UINT16>( rClass.maFillType );
+    nTmp = sal::static_int_cast<sal_uInt16>( rClass.maFillType );
     rOStm << nTmp;
     int i;
     for(i=0; i<SvtGraphicFill::Transform::MatrixSize; ++i)
         rOStm << rClass.maFillTransform.matrix[i];
     nTmp = rClass.mbTiling;
     rOStm << nTmp;
-    nTmp = sal::static_int_cast<UINT16>( rClass.maHatchType );
+    nTmp = sal::static_int_cast<sal_uInt16>( rClass.maHatchType );
     rOStm << nTmp;
     rOStm << rClass.maHatchColor;
-    nTmp = sal::static_int_cast<UINT16>( rClass.maGradientType );
+    nTmp = sal::static_int_cast<sal_uInt16>( rClass.maGradientType );
     rOStm << nTmp;
     rOStm << rClass.maGradient1stColor;
     rOStm << rClass.maGradient2ndColor;
@@ -736,7 +736,7 @@ SvStream& operator>>( SvStream& rIStm, SvtGraphicFill& rClass )
     rClass.maPath.Read( rIStm );
     rIStm >> rClass.maFillColor;
     rIStm >> rClass.mfTransparency;
-    UINT16 nTmp;
+    sal_uInt16 nTmp;
     rIStm >> nTmp;
     rClass.maFillRule = SvtGraphicFill::FillRule( nTmp );
     rIStm >> nTmp;
