@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -41,7 +42,7 @@
 #include <limits.h>
 #include <errno.h>
 #include <poll.h>
-#ifdef FREEBSD
+#if defined(FREEBSD) || defined(NETBSD)
 #include <sys/types.h>
 #include <sys/time.h>
 #include <unistd.h>
@@ -53,6 +54,7 @@
 #include <osl/thread.h>
 #include <osl/process.h>
 
+#include <osl/conditn.h>
 #include <tools/debug.hxx>
 #include "i18n_im.hxx"
 #include "i18n_xkb.hxx"
@@ -62,9 +64,10 @@
 
 #include <vcl/svapp.hxx>
 
-using namespace rtl;
 using namespace vcl_sal;
 
+using ::rtl::OUString;
+
 /***************************************************************************
  * class GtkDisplay                                                        *
  ***************************************************************************/
@@ -114,7 +117,7 @@ GdkFilterReturn call_filterGdkEvent( GdkXEvent* sys_event,
 void signalKeysChanged( GdkKeymap*, gpointer data )
 {
     GtkSalDisplay* pDisp = (GtkSalDisplay*)data;
-    pDisp->GetKeyboardName(TRUE);
+    pDisp->GetKeyboardName(true);
 }
 
 void signalScreenSizeChanged( GdkScreen* pScreen, gpointer data )
@@ -201,7 +204,7 @@ void GtkSalDisplay::screenSizeChanged( GdkScreen* pScreen )
         }
         else
         {
-            DBG_ERROR( "unknown screen changed size" );
+            OSL_FAIL( "unknown screen changed size" );
         }
     }
 }
@@ -217,11 +220,12 @@ void GtkSalDisplay::monitorsChanged( GdkScreen* pScreen )
             {
                 gint nMonitors = gdk_screen_get_n_monitors(pScreen);
                 m_aXineramaScreens = std::vector<Rectangle>();
+                m_aXineramaScreenIndexMap = std::vector<int>(nMonitors);
                 for (gint i = 0; i < nMonitors; ++i)
                 {
                     GdkRectangle dest;
                     gdk_screen_get_monitor_geometry(pScreen, i, &dest);
-                    addXineramaScreenUnique( dest.x, dest.y, dest.width, dest.height );
+                    addXineramaScreenUnique( i, dest.x, dest.y, dest.width, dest.height );
                 }
                 m_bXinerama = m_aXineramaScreens.size() > 1;
                 if( ! m_aFrames.empty() )
@@ -229,12 +233,45 @@ void GtkSalDisplay::monitorsChanged( GdkScreen* pScreen )
             }
             else
             {
-                DBG_ERROR( "monitors for non-default screen changed, extend-me" );
+                OSL_FAIL( "monitors for non-default screen changed, extend-me" );
             }
         }
     }
 }
 
+extern "C"
+{
+    typedef gint(* screen_get_primary_monitor)(GdkScreen *screen);
+}
+
+int GtkSalDisplay::GetDefaultMonitorNumber() const
+{
+    int n = 0;
+    GdkScreen* pScreen = gdk_display_get_screen( m_pGdkDisplay, m_nDefaultScreen );
+#if GTK_CHECK_VERSION(2,20,0)
+    n = gdk_screen_get_primary_monitor(pScreen);
+#else
+    static screen_get_primary_monitor sym_gdk_screen_get_primary_monitor =
+        (screen_get_primary_monitor)osl_getAsciiFunctionSymbol( GetSalData()->m_pPlugin, "gdk_screen_get_primary_monitor" );
+    if (sym_gdk_screen_get_primary_monitor)
+        n = sym_gdk_screen_get_primary_monitor( pScreen );
+#if GTK_CHECK_VERSION(2,14,0)
+    //gdk_screen_get_primary_monitor unavailable, take the first laptop monitor
+    //as the default
+    gint nMonitors = gdk_screen_get_n_monitors(pScreen);
+    for (gint i = 0; i < nMonitors; ++i)
+    {
+        if (g_ascii_strncasecmp (gdk_screen_get_monitor_plug_name(pScreen, i), "LVDS", 4) == 0)
+            return m_aXineramaScreenIndexMap[i];
+    }
+#endif
+    return 0;
+#endif
+    if( n >= 0 && size_t(n) < m_aXineramaScreenIndexMap.size() )
+        n = m_aXineramaScreenIndexMap[n];
+    return n;
+}
+
 void GtkSalDisplay::initScreen( int nScreen ) const
 {
     if( nScreen < 0 || nScreen >= static_cast<int>(m_aScreens.size()) )
@@ -284,17 +321,17 @@ long GtkSalDisplay::Dispatch( XEvent* pEvent )
     return GDK_FILTER_CONTINUE;
 }
 
-GdkCursor* GtkSalDisplay::getFromXPM( const char *pBitmap,
-                                      const char *pMask,
+GdkCursor* GtkSalDisplay::getFromXPM( const unsigned char *pBitmap,
+                                      const unsigned char *pMask,
                                       int nWidth, int nHeight,
                                       int nXHot, int nYHot )
 {
     GdkScreen *pScreen = gdk_display_get_default_screen( m_pGdkDisplay );
     GdkDrawable *pDrawable = GDK_DRAWABLE( gdk_screen_get_root_window (pScreen) );
     GdkBitmap *pBitmapPix = gdk_bitmap_create_from_data
-            ( pDrawable, pBitmap, nWidth, nHeight );
+            ( pDrawable, reinterpret_cast<const char*>(pBitmap), nWidth, nHeight );
     GdkBitmap *pMaskPix = gdk_bitmap_create_from_data
-            ( pDrawable, pMask, nWidth, nHeight );
+            ( pDrawable, reinterpret_cast<const char*>(pMask), nWidth, nHeight );
     GdkColormap *pColormap = gdk_drawable_get_colormap( pDrawable );
 
     GdkColor aWhite = { 0, 0xffff, 0xffff, 0xffff };
@@ -359,7 +396,7 @@ GdkCursor *GtkSalDisplay::getCursor( PointerStyle ePointerStyle )
             MAP_BUILTIN( POINTER_HSIZEBAR, GDK_SB_H_DOUBLE_ARROW );
             MAP_BUILTIN( POINTER_VSIZEBAR, GDK_SB_V_DOUBLE_ARROW );
 
-            MAP_BUILTIN( POINTER_REFHAND, GDK_HAND1 );
+            MAP_BUILTIN( POINTER_REFHAND, GDK_HAND2 );
             MAP_BUILTIN( POINTER_HAND, GDK_HAND2 );
             MAP_BUILTIN( POINTER_PEN, GDK_PENCIL );
 
@@ -489,6 +526,7 @@ class GtkXLib : public SalXLib
     GSource				*m_pUserEvent;
     oslMutex             m_aDispatchMutex;
     oslCondition         m_aDispatchCondition;
+    XIOErrorHandler      m_aOrigGTKXIOErrorHandler;
 
 public:
     static gboolean      timeoutFn(gpointer data);
@@ -505,7 +543,7 @@ public:
                             YieldFunc	handle );
     virtual void    Remove( int fd );
 
-    virtual void    StartTimer( ULONG nMS );
+    virtual void    StartTimer( sal_uLong nMS );
     virtual void    StopTimer();
     virtual void    Wakeup();
     virtual void    PostUserEvent();
@@ -522,6 +560,7 @@ GtkXLib::GtkXLib()
     m_pUserEvent = NULL;
     m_aDispatchCondition = osl_createCondition();
     m_aDispatchMutex = osl_createMutex();
+    m_aOrigGTKXIOErrorHandler = NULL;
 }
 
 GtkXLib::~GtkXLib()
@@ -529,12 +568,16 @@ GtkXLib::~GtkXLib()
 #if OSL_DEBUG_LEVEL > 1
     fprintf( stderr, "GtkXLib::~GtkXLib()\n" );
 #endif
+    Yield( true, true );
     StopTimer();
      // sanity check: at this point nobody should be yielding, but wake them
      // up anyway before the condition they're waiting on gets destroyed.
     osl_setCondition( m_aDispatchCondition );
     osl_destroyCondition( m_aDispatchCondition );
     osl_destroyMutex( m_aDispatchMutex );
+
+    PopXErrorLevel();
+    XSetIOErrorHandler (m_aOrigGTKXIOErrorHandler);
 }
 
 void GtkXLib::Init()
@@ -571,7 +614,7 @@ void GtkXLib::Init()
         osl_getCommandArg(i, &aParam.pData );
         OString aBParam( OUStringToOString( aParam, aEnc ) );
 
-        if( aParam.equalsAscii( "-display" ) || aParam.equalsAscii( "--display" ) )
+        if( aParam.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "-display" ) ) || aParam.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "--display" ) ) )
         {
             pCmdLineAry[i+1] = g_strdup( "--display" );
             osl_getCommandArg(i+1, &aParam.pData );
@@ -596,6 +639,10 @@ void GtkXLib::Init()
     // init gtk/gdk
     gtk_init_check( &nParams, &pCmdLineAry );
 
+    //gtk_init_check sets XError/XIOError handlers, we want our own one
+    m_aOrigGTKXIOErrorHandler = XSetIOErrorHandler ( (XIOErrorHandler)X11SalData::XIOErrorHdl );
+    PushXErrorLevel( !!getenv( "SAL_IGNOREXERRORS" ) );
+
     for (i = 0; i < nParams; i++ )
         g_free( pCmdLineAry[i] );
     delete [] pCmdLineAry;
@@ -630,9 +677,10 @@ void GtkXLib::Init()
      * the clipboard build another connection
      * to the xserver using $DISPLAY
      */
-    char *pPutEnvIsBroken = g_strdup_printf( "DISPLAY=%s",
-                                             gdk_display_get_name( pGdkDisp ) );
-    putenv( pPutEnvIsBroken );
+    rtl::OUString envVar(RTL_CONSTASCII_USTRINGPARAM("DISPLAY"));
+    const gchar *name = gdk_display_get_name( pGdkDisp );
+    rtl::OUString envValue(name, strlen(name), aEnc);
+    osl_setEnvironment(envVar.pData, envValue.pData);
 
     Display *pDisp = gdk_x11_display_get_xdisplay( pGdkDisp );
 
@@ -644,7 +692,7 @@ void GtkXLib::Init()
     SalI18N_KeyboardExtension *pKbdExtension = new SalI18N_KeyboardExtension( pDisp );
     XSync( pDisp, False );
 
-    pKbdExtension->UseExtension( ! HasXErrorOccured() );
+    pKbdExtension->UseExtension( ! HasXErrorOccurred() );
     PopXErrorLevel();
 
     m_pGtkSalDisplay->SetKbdExtension( pKbdExtension );
@@ -696,7 +744,7 @@ gboolean GtkXLib::timeoutFn(gpointer data)
     return FALSE;
 }
 
-void GtkXLib::StartTimer( ULONG nMS )
+void GtkXLib::StartTimer( sal_uLong nMS )
 {
     m_nTimeoutMS = nMS; // for restarting
 
@@ -986,3 +1034,5 @@ void GtkData::Init()
     pXLib_ = new GtkXLib();
     pXLib_->Init();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
