@@ -1,6 +1,6 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
- *
+ * 
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * Copyright 2000, 2010 Oracle and/or its affiliates.
@@ -34,9 +34,14 @@
 #include <vcl/salgdi.hxx>
 #include <vcl/outfont.hxx>
 #include <vcl/impfont.hxx>
+#include <vcl/fontcapabilities.hxx>
 
 #include "boost/scoped_ptr.hpp"
-#include <hash_set>
+#include <boost/unordered_set.hpp>
+
+#ifdef ENABLE_GRAPHITE
+#include <graphite2/Font.h>
+#endif
 
 class ImplFontSelectData;
 class ImplWinFontEntry;
@@ -54,14 +59,34 @@ class ImplFontAttrCache;
 #define GCP_KERN_HACK
 #define GNG_VERT_HACK
 
+#ifdef ENABLE_GRAPHITE
+class RawFontData;
+class GrFontData
+{
+public:
+    GrFontData(HDC hDC);
+    ~GrFontData();
+    const void * getTable(unsigned int name, size_t *len) const;
+    const gr_face * getFace() const { return mpFace; }
+    void AddReference() { ++mnRefCount; }
+    void DeReference() { if (--mnRefCount == 0) delete this; }
+private:
+    GrFontData(GrFontData &) {};
+    HDC mhDC;
+    mutable std::vector<RawFontData*> mvData;
+    gr_face * mpFace;
+    unsigned int mnRefCount;
+};
+#endif
+
 // win32 specific physically available font face
 class ImplWinFontData : public ImplFontData
 {
 public:
-                            ImplWinFontData( const ImplDevFontAttributes&,
-                                int nFontHeight, WIN_BYTE eWinCharSet,
-                                WIN_BYTE nPitchAndFamily  );
-                            ~ImplWinFontData();
+    explicit                ImplWinFontData( const ImplDevFontAttributes&,
+                                int nFontHeight, BYTE eWinCharSet,
+                                BYTE nPitchAndFamily  );
+    virtual                 ~ImplWinFontData();
 
     virtual ImplFontData*   Clone() const;
     virtual ImplFontEntry*  CreateFontInstance( ImplFontSelectData& ) const;
@@ -71,8 +96,8 @@ public:
 
     bool                    HasChar( sal_uInt32 cChar ) const;
 
-    WIN_BYTE                GetCharSet() const          { return meWinCharSet; }
-    WIN_BYTE                GetPitchAndFamily() const   { return mnPitchAndFamily; }
+    BYTE                GetCharSet() const          { return meWinCharSet; }
+    BYTE                GetPitchAndFamily() const   { return mnPitchAndFamily; }
     bool                    IsGlyphApiDisabled() const  { return mbDisableGlyphApi; }
     bool                    SupportsKorean() const      { return mbHasKoreanRange; }
     bool                    SupportsCJK() const         { return mbHasCJKSupport; }
@@ -81,9 +106,11 @@ public:
     bool                    AliasSymbolsLow() const     { return mbAliasSymbolsLow; }
 #ifdef ENABLE_GRAPHITE
     bool                    SupportsGraphite() const    { return mbHasGraphiteSupport; }
+    const gr_face*          GraphiteFace() const;
 #endif
 
-    ImplFontCharMap*        GetImplFontCharMap() const;
+    const ImplFontCharMap*  GetImplFontCharMap() const;
+    bool GetImplFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const;
     const Ucs2SIntMap* GetEncodingVector() const { return mpEncodingVector; }
     void SetEncodingVector( const Ucs2SIntMap* pNewVec ) const
     {
@@ -99,27 +126,30 @@ private:
     mutable bool                    mbHasKoreanRange;
     mutable bool                    mbHasCJKSupport;
 #ifdef ENABLE_GRAPHITE
+    mutable GrFontData*             mpGraphiteData;
     mutable bool                    mbHasGraphiteSupport;
 #endif
     mutable bool                    mbHasArabicSupport;
+    mutable bool                    mbFontCapabilitiesRead;
     mutable ImplFontCharMap*        mpUnicodeMap;
     mutable const Ucs2SIntMap*      mpEncodingVector;
+    mutable vcl::FontCapabilities   maFontCapabilities;
 
     // TODO: get rid of the members below needed to work with the Win9x non-unicode API
     BYTE*                   mpFontCharSets;     // all Charsets for the current font (used on W98 for kerning)
     BYTE                    mnFontCharSetCount; // Number of Charsets of the current font; 0 - if not queried
-    WIN_BYTE                meWinCharSet;
-    WIN_BYTE                mnPitchAndFamily;
+    BYTE                meWinCharSet;
+    BYTE                mnPitchAndFamily;
     bool                    mbAliasSymbolsHigh;
     bool                    mbAliasSymbolsLow;
 private:
     void                    ReadCmapTable( HDC ) const;
-    void                    ReadOs2Table( HDC ) const;
+    void                    GetFontCapabilities( HDC hDC ) const;
 
 #ifdef GNG_VERT_HACK
     void                    ReadGsubTable( HDC ) const;
 
-    typedef std::hash_set<sal_UCS4> UcsHashSet;
+    typedef boost::unordered_set<sal_UCS4> UcsHashSet;
     mutable UcsHashSet      maGsubTable;
     mutable bool            mbGsubRead;
 public:
@@ -128,9 +158,9 @@ public:
 #endif // GNG_VERT_HACK
 };
 
-// -------------------
-// - SalGraphicsData -
-// -------------------
+// ------------------
+// - WinSalGraphics -
+// ------------------
 
 class WinSalGraphics : public SalGraphics
 {
@@ -140,7 +170,8 @@ public:
     HFONT					mhFonts[ MAX_FALLBACK ];        // Font + Fallbacks
     const ImplWinFontData*  mpWinFontData[ MAX_FALLBACK ];  // pointer to the most recent font face
     ImplWinFontEntry*       mpWinFontEntry[ MAX_FALLBACK ]; // pointer to the most recent font instance
-    float                   mfFontScale;        // allows metrics emulation of huge font sizes
+    float                   mfFontScale[ MAX_FALLBACK ];        // allows metrics emulation of huge font sizes
+    float                   mfCurrentFontScale;
     HPEN					mhPen;				// Pen
     HBRUSH					mhBrush;			// Brush
     HRGN					mhRegion;			// Region Handle
@@ -153,24 +184,22 @@ public:
     COLORREF				mnTextColor;		// TextColor
     RGNDATA*				mpClipRgnData;		// ClipRegion-Data
     RGNDATA*				mpStdClipRgnData;	// Cache Standard-ClipRegion-Data
-    RECT*					mpNextClipRect; 	// Naechstes ClipRegion-Rect
-    BOOL					mbFirstClipRect;	// Flag for first cliprect to insert
     LOGFONTA*				mpLogFont;			// LOG-Font which is currently selected (only W9x)
     ImplFontAttrCache*		mpFontAttrCache;	// Cache font attributes from files in so/share/fonts
     BYTE*					mpFontCharSets; 	// All Charsets for the current font
     BYTE					mnFontCharSetCount; // Number of Charsets of the current font; 0 - if not queried
-    BOOL					mbFontKernInit; 	// FALSE: FontKerns must be queried
+    sal_Bool					mbFontKernInit; 	// FALSE: FontKerns must be queried
     KERNINGPAIR*			mpFontKernPairs;	// Kerning Pairs of the current Font
-    ULONG					mnFontKernPairCount;// Number of Kerning Pairs of the current Font
+    sal_uIntPtr					mnFontKernPairCount;// Number of Kerning Pairs of the current Font
     int 					mnPenWidth; 		// Linienbreite
-    BOOL					mbStockPen; 		// is Pen a stockpen
-    BOOL					mbStockBrush;		// is Brush a stcokbrush
-    BOOL					mbPen;				// is Pen (FALSE == NULL_PEN)
-    BOOL					mbBrush;			// is Brush (FALSE == NULL_BRUSH)
-    BOOL					mbPrinter;			// is Printer
-    BOOL					mbVirDev;			// is VirDev
-    BOOL					mbWindow;			// is Window
-    BOOL					mbScreen;			// is Screen compatible
+    sal_Bool					mbStockPen; 		// is Pen a stockpen
+    sal_Bool					mbStockBrush;		// is Brush a stcokbrush
+    sal_Bool					mbPen;				// is Pen (FALSE == NULL_PEN)
+    sal_Bool					mbBrush;			// is Brush (FALSE == NULL_BRUSH)
+    sal_Bool					mbPrinter;			// is Printer
+    sal_Bool					mbVirDev;			// is VirDev
+    sal_Bool					mbWindow;			// is Window
+    sal_Bool					mbScreen;			// is Screen compatible
     bool					mbXORMode;			// _every_ output with RasterOp XOR
 
     // remember RGB values for SetLineColor/SetFillColor
@@ -180,29 +209,28 @@ public:
     HFONT                   ImplDoSetFont( ImplFontSelectData* i_pFont, float& o_rFontScale, HFONT& o_rOldFont );
 
 public:
-    WinSalGraphics();
+    explicit WinSalGraphics();
     virtual ~WinSalGraphics();
 
 protected:
-    virtual BOOL		unionClipRegion( long nX, long nY, long nWidth, long nHeight );
-    virtual bool                unionClipRegion( const ::basegfx::B2DPolyPolygon& );
+    virtual bool        setClipRegion( const Region& );
     // draw --> LineColor and FillColor and RasterOp and ClipRegion
     virtual void		drawPixel( long nX, long nY );
     virtual void		drawPixel( long nX, long nY, SalColor nSalColor );
     virtual void		drawLine( long nX1, long nY1, long nX2, long nY2 );
     virtual void		drawRect( long nX, long nY, long nWidth, long nHeight );
-    virtual void		drawPolyLine( ULONG nPoints, const SalPoint* pPtAry );
-    virtual void		drawPolygon( ULONG nPoints, const SalPoint* pPtAry );
+    virtual void		drawPolyLine( sal_uIntPtr nPoints, const SalPoint* pPtAry );
+    virtual void		drawPolygon( sal_uIntPtr nPoints, const SalPoint* pPtAry );
     virtual void		drawPolyPolygon( sal_uInt32 nPoly, const sal_uInt32* pPoints, PCONSTSALPOINT* pPtAry );
     virtual bool        drawPolyPolygon( const ::basegfx::B2DPolyPolygon&, double fTransparency );
     virtual bool        drawPolyLine( const ::basegfx::B2DPolygon&, double fTransparency, const ::basegfx::B2DVector& rLineWidth, basegfx::B2DLineJoin );
-    virtual sal_Bool	drawPolyLineBezier( ULONG nPoints, const SalPoint* pPtAry, const BYTE* pFlgAry );
-    virtual sal_Bool	drawPolygonBezier( ULONG nPoints, const SalPoint* pPtAry, const BYTE* pFlgAry );
+    virtual sal_Bool	drawPolyLineBezier( sal_uIntPtr nPoints, const SalPoint* pPtAry, const sal_uInt8* pFlgAry );
+    virtual sal_Bool	drawPolygonBezier( sal_uIntPtr nPoints, const SalPoint* pPtAry, const sal_uInt8* pFlgAry );
     virtual sal_Bool	drawPolyPolygonBezier( sal_uInt32 nPoly, const sal_uInt32* pPoints, const SalPoint* const* pPtAry, const BYTE* const* pFlgAry );
 
     // CopyArea --> No RasterOp, but ClipRegion
     virtual void		copyArea( long nDestX, long nDestY, long nSrcX, long nSrcY, long nSrcWidth,
-                                  long nSrcHeight, USHORT nFlags );
+                                  long nSrcHeight, sal_uInt16 nFlags );
 
     // CopyBits and DrawBitmap --> RasterOp and ClipRegion
     // CopyBits() --> pSrcGraphics == NULL, then CopyBits on same Graphics
@@ -223,20 +251,20 @@ protected:
 
     // invert --> ClipRegion (only Windows or VirDevs)
     virtual void		invert( long nX, long nY, long nWidth, long nHeight, SalInvert nFlags);
-    virtual void		invert( ULONG nPoints, const SalPoint* pPtAry, SalInvert nFlags );
+    virtual void		invert( sal_uIntPtr nPoints, const SalPoint* pPtAry, SalInvert nFlags );
 
-    virtual BOOL		drawEPS( long nX, long nY, long nWidth, long nHeight, void* pPtr, ULONG nSize );
+    virtual sal_Bool		drawEPS( long nX, long nY, long nWidth, long nHeight, void* pPtr, sal_uIntPtr nSize );
 
     // native widget rendering methods that require mirroring
-    virtual BOOL        hitTestNativeControl( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion,
-                                              const Point& aPos, BOOL& rIsInside );
-    virtual BOOL        drawNativeControl( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion,
+    virtual sal_Bool        hitTestNativeControl( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion,
+                                              const Point& aPos, sal_Bool& rIsInside );
+    virtual sal_Bool        drawNativeControl( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion,
                                            ControlState nState, const ImplControlValue& aValue,
                                            const rtl::OUString& aCaption );
-    virtual BOOL        drawNativeControlText( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion,
+    virtual sal_Bool        drawNativeControlText( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion,
                                                ControlState nState, const ImplControlValue& aValue,
                                                const rtl::OUString& aCaption );
-    virtual BOOL        getNativeControlRegion( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion, ControlState nState,
+    virtual sal_Bool        getNativeControlRegion( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion, ControlState nState,
                                                 const ImplControlValue& aValue, const rtl::OUString& aCaption,
                                                 Rectangle &rNativeBoundingRegion, Rectangle &rNativeContentRegion );
 
@@ -251,17 +279,12 @@ public:
     // get device resolution
     virtual void			GetResolution( long& rDPIX, long& rDPIY );
     // get the depth of the device
-    virtual USHORT			GetBitCount();
+    virtual sal_uInt16			GetBitCount() const;
     // get the width of the device
     virtual long			GetGraphicsWidth() const;
 
     // set the clip region to empty
     virtual void			ResetClipRegion();
-    // begin setting the clip region, add rectangles to the
-    // region with the UnionClipRegion call
-    virtual void			BeginSetClipRegion( ULONG nCount );
-    // all rectangles were added and the clip region should be set now
-    virtual void			EndSetClipRegion();
 
     // set the line color to transparent (= don't draw lines)
     virtual void			SetLineColor();
@@ -281,14 +304,16 @@ public:
     // set the text color to a specific color
     virtual void			SetTextColor( SalColor nSalColor );
     // set the font
-    virtual USHORT         SetFont( ImplFontSelectData*, int nFallbackLevel );
+    virtual sal_uInt16         SetFont( ImplFontSelectData*, int nFallbackLevel );
     // get the current font's etrics
     virtual void			GetFontMetric( ImplFontMetricData*, int nFallbackLevel );
     // get kernign pairs of the current font
     // return only PairCount if (pKernPairs == NULL)
-    virtual ULONG			GetKernPairs( ULONG nPairs, ImplKernPairData* pKernPairs );
+    virtual sal_uLong			GetKernPairs( sal_uLong nPairs, ImplKernPairData* pKernPairs );
     // get the repertoire of the current font
-    virtual ImplFontCharMap* GetImplFontCharMap() const;
+    virtual const ImplFontCharMap* GetImplFontCharMap() const;
+    // get the layout capabilities of the current font
+    virtual bool GetImplFontCapabilities(vcl::FontCapabilities &rGetFontCapabilities) const;
     // graphics must fill supplied font list
     virtual void			GetDevFontList( ImplDevFontList* );
     // graphics should call ImplAddDevFontSubstitute on supplied
@@ -307,7 +332,7 @@ public:
     //             rInfo: additional outgoing information
     // implementation note: encoding 0 with glyph id 0 should be added implicitly
     // as "undefined character"
-    virtual BOOL			CreateFontSubset( const rtl::OUString& rToFile,
+    virtual sal_Bool			CreateFontSubset( const rtl::OUString& rToFile,
                                               const ImplFontData*,
                                               long* pGlyphIDs,
                                               sal_uInt8* pEncoding,
@@ -345,33 +370,33 @@ public:
                                             Ucs2UIntMap& rUnicodeEnc );
     virtual int             GetMinKashidaWidth();
 
-    virtual BOOL                    GetGlyphBoundRect( long nIndex, Rectangle& );
-    virtual BOOL                    GetGlyphOutline( long nIndex, ::basegfx::B2DPolyPolygon& );
+    virtual sal_Bool                    GetGlyphBoundRect( long nIndex, Rectangle& );
+    virtual sal_Bool                    GetGlyphOutline( long nIndex, ::basegfx::B2DPolyPolygon& );
 
     virtual SalLayout*              GetTextLayout( ImplLayoutArgs&, int nFallbackLevel );
     virtual void					 DrawServerFontLayout( const ServerFontLayout& );
 
     virtual bool            supportsOperation( OutDevSupportType ) const;
     // Query the platform layer for control support
-    virtual BOOL IsNativeControlSupported( ControlType nType, ControlPart nPart );
+    virtual sal_Bool IsNativeControlSupported( ControlType nType, ControlPart nPart );
 
     virtual SystemGraphicsData GetGraphicsData() const;
     virtual SystemFontData     GetSysFontData( int nFallbacklevel ) const;
 };
 
 // Init/Deinit Graphics
-void	ImplSalInitGraphics( WinSalGraphics* mpData );
-void	ImplSalDeInitGraphics( WinSalGraphics* mpData );
+void	ImplSalInitGraphics( WinSalGraphics* );
+void	ImplSalDeInitGraphics( WinSalGraphics* );
 void	ImplUpdateSysColorEntries();
 int 	ImplIsSysColorEntry( SalColor nSalColor );
-void    ImplGetLogFontFromFontSelect( HDC hDC, const ImplFontSelectData*,
+void    ImplGetLogFontFromFontSelect( HDC, const ImplFontSelectData*,
             LOGFONTW&, bool bTestVerticalAvail );
 
 // -----------
 // - Defines -
 // -----------
 
-#define MAX_64KSALPOINTS	((((USHORT)0xFFFF)-8)/sizeof(POINTS))
+#define MAX_64KSALPOINTS	((((sal_uInt16)0xFFFF)-8)/sizeof(POINTS))
 
 // -----------
 // - Inlines -
@@ -398,6 +423,8 @@ inline bool ImplWinFontData::HasChar( sal_uInt32 cChar ) const
         cChar -= 0xF000;
     else if( mbAliasSymbolsHigh && (cChar <= 0xFF) )
         cChar += 0xF000;
+    else
+        return false;
     return mpUnicodeMap->HasChar( cChar );
 }
 
